#
# spec file for package systemd
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define bootstrap 0
%define mini %nil

%bcond_without  compat_libs
%bcond_with     networkd
%bcond_with     python
%bcond_with     parentpathid
%if 0%{?suse_version} > 1315
%bcond_without  permission
%bcond_without  blkrrpart
%bcond_without  udevsettle
%else
%bcond_with     permission
%bcond_with     blkrrpart
%bcond_with     udevsettle
%endif
%bcond_with     systemgrps
# systemd-firstboot is only shipped on SLE12 distros
# Note %sle_version is not defined on SLE12 and %suse_version will
# always evaluate to 1315 for all SLE12 distros.
%if 0%{?suse_version} == 1315
%bcond_without     firstboot
%else
%bcond_with        firstboot
%endif

Name:           systemd
Url:            http://www.freedesktop.org/wiki/Software/systemd
Version:        210
Release:        70.48.1
Summary:        A System and Session Manager
License:        LGPL-2.1+
Group:          System/Base
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  acl
BuildRequires:  audit-devel
BuildRequires:  config(suse-module-tools)
%if ! 0%{?bootstrap}
BuildRequires:  docbook-xsl-stylesheets
%endif
BuildRequires:  fdupes
%if ! 0%{?bootstrap}
BuildRequires:  gobject-introspection-devel
%endif
BuildRequires:  gperf
%if ! 0%{?bootstrap}
BuildRequires:  gtk-doc
%endif
BuildRequires:  intltool
BuildRequires:  libacl-devel
BuildRequires:  libcap-devel
BuildRequires:  libkmod-devel
BuildRequires:  libsepol-devel
BuildRequires:  libtool
%if ! 0%{?bootstrap}
BuildRequires:  libxslt-tools
%endif
BuildRequires:  pam-devel
%if 0%{?suse_version} > 1310
BuildRequires:  systemd-rpm-macros
%endif
%if 0%{?suse_version} <= 1315
BuildRequires:  tcpd-devel
%endif
BuildRequires:  xz
BuildRequires:  pkgconfig(blkid) >= 2.20
%if ! 0%{?bootstrap}
BuildRequires:  libgcrypt-devel
%if %{with python}
BuildRequires:  python
%endif
BuildRequires:  pkgconfig(glib-2.0) >= 2.22.0
BuildRequires:  pkgconfig(libcryptsetup) >= 1.6.0
%endif
%if 0%{?suse_version} <= 1310
BuildRequires:  pkgconfig(libkmod) >= 14
%else
BuildRequires:  pkgconfig(libkmod) >= 15
%endif
BuildRequires:  pkgconfig(liblzma)
%if ! 0%{?bootstrap}
BuildRequires:  pkgconfig(libmicrohttpd)
%endif
BuildRequires:  pkgconfig(libpci) >= 3
BuildRequires:  pkgconfig(libpcre)
%if ! 0%{?bootstrap}
BuildRequires:  pkgconfig(libqrencode)
%endif
%if 0%{?suse_version} >= 1315
%ifarch %ix86 x86_64 x32 %arm ppc64le s390x
BuildRequires:  pkgconfig(libseccomp)
%endif
%else
%if 0%{?suse_version} >= 1310
%ifarch %ix86 x86_64 x32 %arm
BuildRequires:  pkgconfig(libseccomp)
%endif
%endif
%endif
%if ! 0%{?bootstrap}
BuildRequires:  libapparmor-devel
%endif
BuildRequires:  pkgconfig(libselinux) >= 2.1.9
BuildRequires:  pkgconfig(libsepol)
%if 0%{?suse_version} > 1310
Conflicts:      sysvinit
%endif
%if 0%{?bootstrap}
#!BuildIgnore:  dbus-1
Requires:       this-is-only-for-build-envs
Provides:       systemd = %{version}-%{release}
Conflicts:      systemd
Conflicts:      kiwi
%else
# the buildignore is important for bootstrapping
#!BuildIgnore:  udev
Requires:       udev = %{version}
Recommends:     %{name}-bash-completion
Requires:       dbus-1 >= 1.4.0
Requires:       kbd
%if 0%{?suse_version} <= 1310
Requires:       kmod >= 14
%else
Requires:       kmod >= 15
%endif
Requires:       netcfg
Requires:       pam-config >= 0.79-5
Requires:       pwdutils
Requires:       systemd-presets-branding
Requires:       sysvinit-tools
Requires:       util-linux >= 2.21
Requires(post): coreutils
Requires(post): findutils
%endif
%if ! 0%{?bootstrap}
Requires(post): pam-config >= 0.79-5
%endif
Requires(pre):  /usr/bin/getent
Requires(pre):  /usr/sbin/groupadd
Requires(post): /usr/bin/awk
Requires(post): /usr/bin/getent
Requires(post): /usr/bin/setfacl
Conflicts:      filesystem < 11.5
Conflicts:      mkinitrd < 2.7.0
Obsoletes:      systemd-analyze < 201
Provides:       systemd-analyze = %{version}
Source0:        systemd-%{version}.tar.xz
Source1:        %{name}-rpmlintrc
Source2:        localfs.service
Source3:        systemd-sysv-convert
Source6:        baselibs.conf
Source7:        libgcrypt.m4
Source9:        nss-myhostname-config
Source10:       macros.systemd.upstream
Source11:       after-local.service

Source1063:     udev-generate-persistent-rule.sh
Source1064:     systemd-sleep-grub
Source1065:     systemd-remount-tmpfs

%description
Systemd is a system and service manager, compatible with SysV and LSB
init scripts for Linux. systemd provides aggressive parallelization
capabilities, uses socket and D-Bus activation for starting services,
offers on-demand starting of daemons, keeps track of processes using
Linux cgroups, supports snapshotting and restoring of the system state,
maintains mount and automount points and implements an elaborate
transactional dependency-based service control logic. It can work as a
drop-in replacement for sysvinit.


%package bash-completion
Summary:        Bash completion support for systemd
License:        LGPL-2.1+
Group:          System/Base
Requires:       bash-completion
BuildArch:      noarch

%description bash-completion
Some systemd commands offer bash completion, but it is an optional dependency.

%package devel
Summary:        Development headers for systemd
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       systemd-rpm-macros
%if 0%{?bootstrap}
Conflicts:      systemd-devel
%endif

%description devel
Development headers and auxiliary files for developing applications for systemd.

%package sysvinit
Summary:        System V init tools
License:        LGPL-2.1+
Group:          System/Base
Requires:       %{name} = %{version}
Provides:       sbin_init
Conflicts:      otherproviders(sbin_init)
Provides:       sysvinit:/sbin/init

%description sysvinit
Drop-in replacement of System V init tools.

%package -n udev%{?mini}
Summary:        A rule-based device node and kernel event manager
License:        GPL-2.0
Group:          System/Kernel
Url:            http://www.kernel.org/pub/linux/utils/kernel/hotplug/udev.html
Requires(pre):  /usr/bin/stat
Requires(pre):  /usr/sbin/groupadd
Requires(pre):  /usr/bin/getent
Requires(post): sed
Requires(post): /usr/bin/systemctl
%if %{defined regenerate_initrd_post}
Requires(post): coreutils
Requires(post): /usr/bin/stat
Requires(postun): coreutils
Requires(postun): %insserv_prereq
Requires(posttrans): suse-module-tools
Requires(posttrans): /sbin/mkinitrd
%else
Requires(post): /sbin/mkinitrd
Requires(postun): /sbin/mkinitrd
%endif
Conflicts:      systemd < 39
Conflicts:      aaa_base < 11.5
Conflicts:      filesystem < 11.5
Conflicts:      mkinitrd < 2.7.0
Conflicts:      util-linux < 2.16
Conflicts:      ConsoleKit < 0.4.1
Requires:       filesystem
%if 0%{?bootstrap}
Provides:       udev = %{version}
Conflicts:      libudev1
Conflicts:      udev
# avoid kiwi picking it for bootstrap
Requires:       this-is-only-for-build-envs
%endif

%description -n udev%{?mini}
Udev creates and removes device nodes in /dev for devices discovered or
removed from the system. It receives events via kernel netlink messages
and dispatches them according to rules in /lib/udev/rules.d/. Matching
rules may name a device node, create additional symlinks to the node,
call tools to initialize a device, or load needed kernel modules.



%package -n libudev%{?mini}1
Summary:        Dynamic library to access udev device information
License:        LGPL-2.1+
Group:          System/Libraries
%if 0%{?bootstrap}
Conflicts:      libudev1
Conflicts:      kiwi
# avoid kiwi picking it for bootstrap
Requires:       this-is-only-for-build-envs
%endif

%description -n libudev%{?mini}1
This package contains the dynamic library libudev, which provides
access to udev device information

%package -n libudev%{?mini}-devel
Summary:        Development files for libudev
License:        LGPL-2.1+
Group:          Development/Libraries/Other
Requires:       libudev%{?mini}1 = %{version}-%{release}
%if 0%{?bootstrap}
Provides:       libudev-devel = %{version}
Conflicts:      libudev1 = %{version}
Conflicts:      libudev-devel
%endif

%description -n libudev%{?mini}-devel
This package contains the development files for the library libudev, a
dynamic library, which provides access to udev device information.

%if ! 0%{?bootstrap}
%package -n libgudev-1_0-0
Summary:        GObject library, to access udev device information
License:        LGPL-2.1+
Group:          System/Libraries
Requires:       libudev1 = %{version}-%{release}

%description -n libgudev-1_0-0
This package contains the GObject library libgudev, which provides
access to udev device information.

%package -n typelib-1_0-GUdev-1_0
Summary:        GObject library, to access udev device information -- Introspection bindings
License:        LGPL-2.1+
Group:          System/Libraries

%description -n typelib-1_0-GUdev-1_0
This package provides the GObject Introspection bindings for libgudev, which
provides access to udev device information.

%package -n libgudev-1_0-devel
Summary:        Devel package for libgudev
License:        LGPL-2.1+
Group:          Development/Libraries/Other
Requires:       glib2-devel
Requires:       libgudev-1_0-0 = %{version}-%{release}
Requires:       libudev-devel = %{version}-%{release}
Requires:       typelib-1_0-GUdev-1_0 = %{version}-%{release}

%description -n libgudev-1_0-devel
This is the devel package for the GObject library libgudev, which
provides GObject access to udev device information.

%package logger
Summary:        Journal only logging
License:        LGPL-2.1+
Group:          System/Base
Provides:       syslog
Provides:       sysvinit(syslog)
Requires(pre):  /usr/bin/getent
Requires(pre):  /usr/sbin/groupadd
Requires(post): /usr/bin/getent 
Requires(post): /usr/bin/setfacl
Requires(post): /usr/bin/systemctl
Requires(post): permissions
Conflicts:      otherproviders(syslog)

%description logger
This package marks the installation to not use syslog but only the journal.

%package -n nss-myhostname
Summary:        Plugin for local system host name resolution
License:        LGPL-2.1+
Group:          System/Libraries

%description -n nss-myhostname
nss-myhostname is a plugin for the GNU Name Service Switch (NSS)
functionality of the GNU C Library (glibc) providing host name
resolution for the locally configured system hostname as returned by
gethostname(2). Various software relies on an always resolvable local
host name. When using dynamic hostnames this is usually achieved by
patching /etc/hosts at the same time as changing the host name. This
however is not ideal since it requires a writable /etc file system and
is fragile because the file might be edited by the administrator at
the same time. nss-myhostname simply returns all locally
configured public IP addresses, or -- if none are configured --
the IPv4 address 127.0.0.2 (wich is on the local loopback) and the
IPv6 address ::1 (which is the local host) for whatever system
hostname is configured locally. Patching /etc/hosts is thus no
longer necessary.

Note that nss-myhostname only provides a workaround for broken
software. If nss-myhostname is trigged by an application a message
is logged to /var/log/messages. Please check whether that is worth
a bug report then.
This package marks the installation to not use syslog but only the journal.

%package journal-gateway
Summary:        Gateway for serving journal events over the network using HTTP
License:        LGPL-2.1+
Group:          System/Base
Requires:       %{name} = %{version}-%{release}
Requires(post):   systemd
Requires(preun):  systemd
Requires(postun): systemd

%description journal-gateway
systemd-journal-gatewayd serves journal events over the network using HTTP.

%endif

%prep
%setup -q -n systemd-%{version}
echo "Checking whether upstream rpm macros changed..."
[ -z "`diff -Naru "%{S:10}" src/core/macros.systemd.in`" ] || exit 1

# only needed for bootstrap
%if 0%{?bootstrap}
cp %{SOURCE7} m4/
%endif

# ensure generate files are removed
rm -f units/emergency.service

# disable "-l" option for fsck if it does not support new locking scheme
# compare with commit c343be283b7152554bac0c02493a4e1759c163f7
PATH=${PATH}:/sbin:/usr/sbin
PATH_FSCK=$(type -p fsck)
if grep -q /run/fsck/%%s\\.lock $PATH_FSCK
then
  echo Found new $PATH_FSCK that is allow private locking
else
  echo Found old $PATH_FSCK that is disable flock for this one
  sed -ri 's@^([[:blank:]]+)(cmdline\[i\+\+\][[:blank:]]+=[[:blank:]]+"-l")(;)@\1/* \2 */\3@' src/fsck/fsck.c
fi

%if 0%{?suse_version} <= 1310
#
# Older versions like oS 13.1 do not distinguish between
# network.target and network-online.target
#
for f in src/core/service.c src/insserv-generator/insserv-generator.c
do
  sed -ri '/"network",.*SPECIAL_NETWORK_ONLINE_TARGET,/{ s/SPECIAL_NETWORK_ONLINE_TARGET/SPECIAL_NETWORK_TARGET/}' $f
done
%endif

#
# In combination with Patch352 set-and-use-default-logconsole.patch
# Ensure that journald log on tty10
#
%ifarch %ix86 x86_64 x32
sed -ri 's:#TTYPath=/dev/console:#TTYPath=/dev/tty10:' src/journal/journald.conf
%endif

%build
#
# Be sure that fresh build libudev is found and used at linkage time
#
sed -ri '/^systemd_cryptsetup_CFLAGS/,/^systemd_cryptsetup_LDADD/{ /^$/a\
systemd_cryptsetup_LDFLAGS =\\\
	$(AM_LDFLAGS)\\\
	-Wl,-rpath-link=$(top_srcdir)/.libs\

}' Makefile.am

./autogen.sh

export CFLAGS="%{optflags}"
%if 0%{?suse_version} == 1315
  CFLAGS="$CFLAGS -DNET_IFNAMES=1"
%else
  CFLAGS="$CFLAGS -DNET_IFNAMES=0"
  for rules in 75-persistent-net-generator
  do
    sed -ri '/^ENV\{net.ifnames\}=="1", GOTO="[^"]*"$/{ s/=="1"/!="0"/ }' src/udev/rule_generator/${rules}.rules
  done
%endif

# keep split-usr until all packages have moved their systemd rules to /usr
%configure \
  --docdir=%{_docdir}/systemd \
  --with-pamlibdir=/%{_lib}/security \
  --with-dbuspolicydir=%{_sysconfdir}/dbus-1/system.d \
  --with-dbussessionservicedir=%{_datadir}/dbus-1/services \
  --with-dbussystemservicedir=%{_datadir}/dbus-1/system-services \
  --with-dbusinterfacedir=%{_datadir}/dbus-1/interfaces \
%if 0%{?bootstrap}
  --disable-gudev \
  --disable-myhostname \
  --disable-manpages \
%else
  --enable-manpages \
%if %{with python}
  --with-python \
%endif
  --enable-gtk-doc \
  --with-nss-my-hostname-warning \
%endif
%if %{with compat_libs}
  --enable-compat-libs \
%endif
  --enable-selinux \
  --enable-split-usr \
  --disable-static \
  --disable-tests \
  --with-rc-local-script-path-start=/etc/init.d/boot.local \
  --with-rc-local-script-path-stop=/etc/init.d/halt.local \
  --with-debug-shell=/bin/bash \
  --disable-smack \
  --disable-ima \
%if 0%{?suse_version} > 1310
  --disable-multi-seat-x \
%endif
%if %{without networkd}
  --disable-networkd \
%endif
  --disable-kdbus

make %{?_smp_mflags} V=e
%if ! 0%{?bootstrap}
make %{?_smp_mflags} V=e update-man-list man
%endif

%install
%make_install

# move to %{_lib}
%if ! 0%{?bootstrap}
mv %{buildroot}%{_libdir}/libnss_myhostname.so.2 %{buildroot}/%{_lib}
%endif

mkdir -p %{buildroot}/{sbin,lib,bin}
ln -sf %{_bindir}/udevadm %{buildroot}/sbin/udevadm
ln -sf %{_bindir}/systemd-ask-password %{buildroot}/bin/systemd-ask-password
ln -sf %{_bindir}/systemctl %{buildroot}/bin/systemctl
ln -sf %{_prefix}/lib/systemd/systemd-udevd %{buildroot}/sbin/udevd
%if ! 0%{?bootstrap}
ln -sf systemd-udevd.8 %{buildroot}/%{_mandir}/man8/udevd.8
%endif
%if ! 0%{?bootstrap}
install -D -m 755 %{S:9} %{buildroot}%{_sbindir}/nss-myhostname-config
%endif

install -m755 -D %{S:1063} %{buildroot}/%{_prefix}/lib/udev/udev-generate-persistent-rule
install -m755 -D %{S:1064} %{buildroot}/%{_bindir}/systemd-sleep-grub
install -m755 -D %{S:1065} %{buildroot}/%{_prefix}/lib/udev/remount-tmpfs
mkdir -p %{buildroot}/%{_prefix}/lib/systemd/system/basic.target.wants
rm -rf %{buildroot}%{_sysconfdir}/rpm
find %{buildroot} -type f -name '*.la' -delete
mkdir -p %{buildroot}/{sbin,var/lib/systemd/sysv-convert,var/lib/systemd/migrated} %{buildroot}/usr/lib/systemd/{system-generators,user-generators,system-preset,user-preset,system/halt.target.wants,system/kexec.target.wants,system/poweroff.target.wants,system/reboot.target.wants,system/shutdown.target.wants}

install -m755 %{S:3} -D %{buildroot}%{_sbindir}/systemd-sysv-convert
ln -s ../usr/lib/systemd/systemd %{buildroot}/bin/systemd
ln -s ../usr/lib/systemd/systemd %{buildroot}/sbin/init
ln -s ../usr/bin/systemctl %{buildroot}/sbin/reboot
ln -s ../usr/bin/systemctl %{buildroot}/sbin/halt
ln -s ../usr/bin/systemctl %{buildroot}/sbin/shutdown
ln -s ../usr/bin/systemctl %{buildroot}/sbin/poweroff
ln -s ../usr/bin/systemctl %{buildroot}/sbin/telinit
ln -s ../usr/bin/systemctl %{buildroot}/sbin/runlevel
rm -rf %{buildroot}/etc/systemd/system/*.target.wants
rm -f %{buildroot}/etc/systemd/system/default.target
# aliases for /etc/init.d/*
ln -s /dev/null %{buildroot}/%{_prefix}/lib/systemd/system/cgroup.service
ln -s systemd-tmpfiles-setup.service %{buildroot}/%{_prefix}/lib/systemd/system/cleanup.service
ln -s /dev/null %{buildroot}/%{_prefix}/lib/systemd/system/clock.service
ln -s /dev/null %{buildroot}/%{_prefix}/lib/systemd/system/crypto.service
ln -s /dev/null %{buildroot}/%{_prefix}/lib/systemd/system/crypto-early.service
ln -s /dev/null %{buildroot}/%{_prefix}/lib/systemd/system/device-mapper.service
ln -s /dev/null %{buildroot}/%{_prefix}/lib/systemd/system/earlysyslog.service
ln -s /dev/null %{buildroot}/%{_prefix}/lib/systemd/system/kbd.service
ln -s /dev/null %{buildroot}/%{_prefix}/lib/systemd/system/ldconfig.service
ln -s /dev/null %{buildroot}/%{_prefix}/lib/systemd/system/loadmodules.service
install -m644 %{S:2} %{buildroot}/%{_prefix}/lib/systemd/system/localfs.service
ln -s /dev/null %{buildroot}/%{_prefix}/lib/systemd/system/localnet.service
ln -s /dev/null %{buildroot}/%{_prefix}/lib/systemd/system/proc.service
ln -s systemd-fsck-root.service %{buildroot}/%{_prefix}/lib/systemd/system/rootfsck.service
ln -s /dev/null %{buildroot}/%{_prefix}/lib/systemd/system/single.service
ln -s /dev/null %{buildroot}/%{_prefix}/lib/systemd/system/swap.service
ln -s /dev/null %{buildroot}/%{_prefix}/lib/systemd/system/startpreload.service
ln -s /dev/null %{buildroot}/%{_prefix}/lib/systemd/system/stoppreload.service
ln -s /dev/null %{buildroot}/%{_prefix}/lib/systemd/system/earlyxdm.service
ln -s systemd-sysctl.service %{buildroot}/%{_prefix}/lib/systemd/system/sysctl.service
ln -s systemd-random-seed.service %{buildroot}/%{_prefix}/lib/systemd/system/random.service
# don't mount /tmp as tmpfs for now
rm %{buildroot}/%{_prefix}/lib/systemd/system/local-fs.target.wants/tmp.mount

# don't enable wall ask password service, it spams every console (bnc#747783)
rm %{buildroot}%{_prefix}/lib/systemd/system/multi-user.target.wants/systemd-ask-password-wall.path

# create %{_libexecdir}/modules-load.d
mkdir -p %{buildroot}%{_libexecdir}/modules-load.d
cat << EOF > %{buildroot}%{_libexecdir}/modules-load.d/sg.conf
# load sg module at boot time
sg
EOF

# To avoid making life hard for Factory developers, don't package the
# kernel.core_pattern setting until systemd-coredump is a part of an actual
# systemd release and it's made clear how to get the core dumps out of the
# journal.
rm -f %{buildroot}%{_prefix}/lib/sysctl.d/50-coredump.conf

# do not ship sysctl defaults in systemd package, will be part of
# aaa_base (in procps for now)
rm -f %{buildroot}%{_prefix}/lib/sysctl.d/50-default.conf

# remove README file for now
rm -f %{buildroot}/etc/init.d/README
%if 0%{?bootstrap}
rm -f %{buildroot}%{_localstatedir}/log/README
rm -rf %{buildroot}%{_datadir}/bash-completion
%endif

# legacy links
for f in loginctl journalctl ; do
  ln -s $f %{buildroot}%{_bindir}/systemd-$f
%if ! 0%{?bootstrap}
  ln -s $f.1 %{buildroot}%{_mandir}/man1/systemd-$f.1
%endif
done
ln -s /usr/lib/udev %{buildroot}/lib/udev

# Create the /var/log/journal directory to change the volatile journal to a persistent one
mkdir -p %{buildroot}%{_localstatedir}/log/journal/

# Make sure directories in /var exist
mkdir -p %{buildroot}%{_localstatedir}/lib/systemd/coredump
mkdir -p %{buildroot}%{_localstatedir}/lib/systemd/catalog
#create ghost databases
touch %{buildroot}%{_localstatedir}/lib/systemd/catalog/database
touch %{buildroot}%{_sysconfdir}/udev/hwdb.bin

# Make sure the NTP units dir exists
mkdir -p %{buildroot}%{_prefix}/lib/systemd/ntp-units.d/

# Make sure the shutdown/sleep drop-in dirs exist
mkdir -p %{buildroot}%{_prefix}/lib/systemd/system-shutdown/
mkdir -p %{buildroot}%{_prefix}/lib/systemd/system-sleep/

# Make sure these directories are properly owned
mkdir -p %{buildroot}%{_prefix}/lib/systemd/system/default.target.wants
mkdir -p %{buildroot}%{_prefix}/lib/systemd/system/dbus.target.wants

# create drop-in to prevent tty1 to be cleared (bnc#804158)
mkdir -p %{buildroot}%{_prefix}/lib/systemd/system/getty@tty1.service.d/
cat << EOF > %{buildroot}%{_prefix}/lib/systemd/system/getty@tty1.service.d/noclear.conf
[Service]
# ensure tty1 isn't cleared (bnc#804158)
TTYVTDisallocate=no
EOF

# ensure after.local wrapper is called
install -m 644 %{S:11} %{buildroot}/%{_prefix}/lib/systemd/system/
ln -s ../after-local.service %{buildroot}/%{_prefix}/lib/systemd/system/multi-user.target.wants/

mkdir -p %{buildroot}%{_localstatedir}/lib/systemd/backlight
mkdir -p %{buildroot}%{_localstatedir}/lib/systemd/random-seed

%fdupes -s %{buildroot}%{_mandir}

%if 0%{suse_version} >= 1310
# packaged in systemd-rpm-macros
rm -f %{buildroot}/%{_prefix}/lib/rpm/macros.d/macros.systemd
%endif

%if %{without compat_libs}
lib=%{_libdir}/libsystemd.so
for lnk in daemon login id128 journal
do
    lnk=%{buildroot}%{_libdir}/libsystemd-${lnk}.so
    echo '/* GNU ld script */' >  ${lnk}
    echo 'INPUT('${lib}')'     >> ${lnk}
done
%endif

# Some files which may created by us or by the admin later on
mkdir -p %{buildroot}%{_sysconfdir}/X11/xorg.conf.d
for ghost in X11/xorg.conf.d/00-keyboard.conf vconsole.conf locale.conf \
	     machine-id machine-info \
	     systemd/system/runlevel2.target \
	     systemd/system/runlevel3.target \
	     systemd/system/runlevel4.target \
	     systemd/system/runlevel4.target \
	     systemd/system/runlevel5.target
do
  > %{buildroot}%{_sysconfdir}/$ghost
done

# Workaround for bug #882393
for runlevel in poweroff rescue multi-user graphical reboot
do
  mkdir -p %{buildroot}%{_prefix}/lib/systemd/system/${runlevel}.target.wants
  ln -sf ../systemd-update-utmp-runlevel.service %{buildroot}%{_prefix}/lib/systemd/system/${runlevel}.target.wants/
done

%find_lang systemd

%pre
getent group systemd-journal >/dev/null || groupadd -r systemd-journal || :
exit 0

%post
%if ! 0%{?bootstrap}
/usr/sbin/pam-config -a --systemd || :
%endif
/sbin/ldconfig
[ -e %{_localstatedir}/lib/random-seed ] && mv %{_localstatedir}/lib/random-seed %{_localstatedir}/lib/systemd/ > /dev/null || :
/usr/bin/systemd-machine-id-setup >/dev/null 2>&1 || :
/usr/lib/systemd/systemd-random-seed save >/dev/null 2>&1 || :
/usr/bin/systemctl daemon-reexec >/dev/null 2>&1 || :
/usr/bin/journalctl --update-catalog >/dev/null 2>&1 || :
# Make sure new journal files
chgrp systemd-journal %{_localstatedir}/log/journal/ > /dev/null 2>&1 || :
chmod g+s             %{_localstatedir}/log/journal/ > /dev/null 2>&1 || :
if read ID < /etc/machine-id > /dev/null 2>&1 ; then
  chgrp systemd-journal %{_localstatedir}/log/journal/$ID > /dev/null 2>&1 || :
  chmod g+s             %{_localstatedir}/log/journal/$ID > /dev/null 2>&1 || :
fi
%if %{with systemgrps}
getent group wheel && setfacl -Rnm g:wheel:rx,d:g:wheel:rx %{_localstatedir}/log/journal/ > /dev/null 2>&1 || :
getent group adm   && setfacl -Rnm g:adm:rx,d:g:adm:rx     %{_localstatedir}/log/journal/ > /dev/null 2>&1 || :
%endif

# Make sure the journals have the right permissions (boo#972612).
# Note that the journals might no be present yet.
MID=$(cat /etc/machine-id)
chmod 0640 %{_localstatedir}/log/journal/$MID/*.journal  2>/dev/null || :
chmod 0640 %{_localstatedir}/log/journal/$MID/*.journal~ 2>/dev/null || :
chmod o-rx %{_rundir}/log/journal/$MID                   2>/dev/null || :

# Try to read default runlevel from the old inittab if it exists
if [ ! -e /etc/systemd/system/default.target -a -e /etc/inittab ]; then
  runlevel=$(awk -F ':' '$3 == "initdefault" && $1 !~ "^#" { print $2 }' /etc/inittab 2> /dev/null)
  if [ -n "$runlevel" ] ; then
    /bin/ln -sf /usr/lib/systemd/system/runlevel$runlevel.target /etc/systemd/system/default.target 2>&1 || :
  fi
fi
# Create default config in /etc at first install.
# Later package updates should not overwrite these settings.
if [ "$1" -eq 1 ]; then
  # Enable these services by default.
  /usr/bin/systemctl enable \
    getty@tty1.service \
    systemd-readahead-collect.service \
    systemd-readahead-replay.service \
    remote-fs.target >/dev/null 2>&1 || :
fi

# since v207 /etc/sysctl.conf is no longer parsed, however
# backward compatibility is provided by /etc/sysctl.d/99-sysctl.conf
if [ ! -L /etc/sysctl.d/99-sysctl.conf -a -e /etc/sysctl.conf ]; then
    /bin/ln -sf /etc/sysctl.conf /etc/sysctl.d/99-sysctl.conf || :
fi

# migrate any symlink which may refer to the old path
for f in $(find /etc/systemd/system -type l -xtype l); do
  new_target="/usr$(readlink $f)"
  [ -f "$new_target" ] && ln -s -f $new_target $f || :
done

%postun
/sbin/ldconfig
if [ $1 -ge 1 ]; then
        /usr/bin/systemctl daemon-reload >/dev/null 2>&1 || :
        # Avoid restarting logind [bnc#934901] until fixed upstream
        #/usr/bin/systemctl try-restart systemd-logind.service >/dev/null 2>&1 || :
fi
%if ! 0%{?bootstrap}
if [ $1 -eq 0 ]; then
  /usr/sbin/pam-config -d --systemd || :
fi
%endif

%preun
if [ $1 -eq 0 ]; then
  /usr/bin/systemctl disable \
    getty@.service \
    systemd-readahead-collect.service \
    systemd-readahead-replay.service \
    remote-fs.target >/dev/null 2>&1 || :
  rm -f /etc/systemd/system/default.target 2>&1 || :
fi

%pretrans -n udev%{?mini} -p <lua>
if posix.stat("/lib/udev") and not posix.stat("/usr/lib/udev") then
  posix.symlink("/lib/udev", "/usr/lib/udev")
end

%pre -n udev%{?mini}
if test -L /usr/lib/udev -a /lib/udev -ef /usr/lib/udev ; then
  rm /usr/lib/udev
  mv /lib/udev /usr/lib
  ln -s /usr/lib/udev /lib/udev
elif [ ! -e /lib/udev ]; then
  ln -s /usr/lib/udev /lib/udev
fi
# Create "tape" group which is referenced by 50-udev-default.rules and 60-persistent-storage-tape.rules
getent group tape >/dev/null || groupadd -r tape 2> /dev/null || :
# kill daemon if we are not in a chroot
if test -f /proc/1/exe -a -d /proc/1/root ; then
        if test "$(stat -Lc '%%D-%%i' /)" = "$(stat -Lc '%%D-%%i' /proc/1/root)"; then
                systemctl stop systemd-udevd-control.socket systemd-udevd-kernel.socket systemd-udevd.service udev-control.socket udev-kernel.socket >/dev/null 2>&1 || :
                udevadm control --exit 2>&1 || :
        fi
fi

%post -n udev%{?mini}
/usr/bin/udevadm hwdb --update >/dev/null 2>&1 || :
# add KERNEL name match to existing persistent net rules
sed -ri '/KERNEL/ ! { s/NAME="(eth|wlan|ath)([0-9]+)"/KERNEL=="\1*", NAME="\1\2"/}' \
    /etc/udev/rules.d/70-persistent-net.rules >/dev/null 2>&1 || :
# cleanup old stuff
rm -f /etc/sysconfig/udev
rm -f /etc/udev/rules.d/20-cdrom.rules
rm -f /etc/udev/rules.d/55-cdrom.rules
rm -f /etc/udev/rules.d/65-cdrom.rules
systemctl daemon-reload >/dev/null 2>&1 || :
# start daemon if we are not in a chroot
if test -f /proc/1/exe -a -d /proc/1/root; then
	if test "$(stat -Lc '%%D-%%i' /)" = "$(stat -Lc '%%D-%%i' /proc/1/root)"; then
		if ! systemctl start systemd-udevd.service >/dev/null 2>&1; then
                        /usr/lib/systemd/systemd-udevd --daemon >/dev/null 2>&1 || :
                fi
	fi
fi

if [ "${YAST_IS_RUNNING}" != "instsys" ]; then
 if [ -e %{_localstatedir}/lib/no_initrd_recreation_by_suspend ]; then
   echo "Skipping recreation of existing initial ramdisks, due"
   echo "to presence of %{_localstatedir}/lib/no_initrd_recreation_by_suspend"
%if %{defined regenerate_initrd_post}
 else
   %regenerate_initrd_post
%else
 elif [ -x /sbin/mkinitrd ]; then
   [ -x /sbin/mkinitrd_setup ] && /sbin/mkinitrd_setup
   /sbin/mkinitrd || :
%endif
 fi
fi

%postun -n udev%{?mini}
%insserv_cleanup
systemctl daemon-reload >/dev/null 2>&1 || :

if [ "${YAST_IS_RUNNING}" != "instsys" ]; then
 if [ -e %{_localstatedir}/lib/no_initrd_recreation_by_suspend ]; then
   echo "Skipping recreation of existing initial ramdisks, due"
   echo "to presence of %{_localstatedir}/lib/no_initrd_recreation_by_suspend"
%if %{defined regenerate_initrd_post}
 else
   %regenerate_initrd_post
%else
 elif [ -x /sbin/mkinitrd ]; then
   [ -x /sbin/mkinitrd_setup ] && /sbin/mkinitrd_setup
   /sbin/mkinitrd || :
%endif
 fi
fi

%if %{defined regenerate_initrd_post}
%posttrans -n udev%{?mini}
%regenerate_initrd_posttrans
%endif

%post -n libudev%{?mini}1 -p /sbin/ldconfig

%postun -n libudev%{?mini}1 -p /sbin/ldconfig

%if ! 0%{?bootstrap}

%post -n libgudev-1_0-0 -p /sbin/ldconfig

%postun -n libgudev-1_0-0 -p /sbin/ldconfig

%if %{with permission}
%verifyscript logger
%verify_permissions -e %{_localstatedir}/log/journal/
%endif

%pre logger
getent group systemd-journal >/dev/null || groupadd -r systemd-journal || :
exit 0

%post logger
%if %{with permission}
%set_permissions %{_localstatedir}/log/journal/
%endif
%if %{with systemgrps}
getent group wheel && setfacl -Rnm g:wheel:rx,d:g:wheel:rx %{_localstatedir}/log/journal/ > /dev/null 2>&1 || :
getent group adm   && setfacl -Rnm g:adm:rx,d:g:adm:rx     %{_localstatedir}/log/journal/ > /dev/null 2>&1 || :
%endif
if [ "$1" -eq 1 ]; then
# tell journal to start logging on disk if directory didn't exist before
  systemctl --no-block restart systemd-journal-flush.service >/dev/null 2>&1 || :
fi

%preun -n nss-myhostname
if [ "$1" -eq 0 -a -f /etc/nsswitch.conf ] ; then
        %{_sbindir}/nss-myhostname-config --disable
fi

%post -n nss-myhostname -p /sbin/ldconfig

%postun -n nss-myhostname -p /sbin/ldconfig

%pre journal-gateway
getent passwd systemd-journal-gateway >/dev/null || useradd -r -l -g systemd-journal-gateway -d %{_localstatedir}/log/journal/ -s /usr/sbin/nologin -c "Journal Gateway" systemd-journal-gateway >/dev/null 2>&1 || :
getent group systemd-journal-gateway >/dev/null || groupadd -r systemd-journal-gateway || :
%service_add_pre systemd-journal-gatewayd.socket systemd-journal-gatewayd.service
exit 0

%post journal-gateway
%service_add_post systemd-journal-gatewayd.socket systemd-journal-gatewayd.service

%preun  journal-gateway
%service_del_preun systemd-journal-gatewayd.socket systemd-journal-gatewayd.service

%postun journal-gateway
%service_del_postun systemd-journal-gatewayd.socket systemd-journal-gatewayd.service

%endif

%files -f systemd.lang
%defattr(-,root,root)
/bin/systemd
/bin/systemd-ask-password
/bin/systemctl
%{_bindir}/systemd-sleep-grub
%{_bindir}/busctl
%{_bindir}/bootctl
%{_bindir}/kernel-install
%{_bindir}/hostnamectl
%{_bindir}/localectl
%{_bindir}/machinectl
%{_bindir}/systemctl
%{_bindir}/systemd-analyze
%{_bindir}/systemd-coredumpctl
%{_bindir}/systemd-delta
%if %{with firstboot}
%{_bindir}/systemd-firstboot
%endif
%{_bindir}/systemd-notify
%{_bindir}/systemd-run
%{_bindir}/systemd-journalctl
%{_bindir}/journalctl
%{_bindir}/systemd-ask-password
%{_bindir}/loginctl
%{_bindir}/systemd-loginctl
%{_bindir}/systemd-inhibit
%{_bindir}/systemd-tty-ask-password-agent
%{_bindir}/systemd-tmpfiles
%{_bindir}/systemd-machine-id-setup
%{_bindir}/systemd-nspawn
%{_bindir}/systemd-stdio-bridge
%{_bindir}/systemd-detect-virt
%{_bindir}/timedatectl
%{_sbindir}/systemd-sysv-convert
%{_libdir}/libsystemd.so.*
%if %{with compat_libs}
%{_libdir}/libsystemd-daemon.so.*
%{_libdir}/libsystemd-login.so.*
%{_libdir}/libsystemd-id128.so.*
%{_libdir}/libsystemd-journal.so.*
%endif
%{_bindir}/systemd-cgls
%{_bindir}/systemd-cgtop
%{_bindir}/systemd-cat
%dir %{_prefix}/lib/kernel
%dir %{_prefix}/lib/kernel/install.d
%{_prefix}/lib/kernel/install.d/50-depmod.install
%{_prefix}/lib/kernel/install.d/90-loaderentry.install
%dir %{_prefix}/lib/systemd
%dir %{_prefix}/lib/systemd/user
%dir %{_prefix}/lib/systemd/system
%exclude %{_prefix}/lib/systemd/system/systemd-udev*.*
%exclude %{_prefix}/lib/systemd/system/systemd-udev-root-symlink.service
%exclude %{_prefix}/lib/systemd/system/*.target.wants/systemd-udev*.*
%exclude %{_prefix}/lib/systemd/system/sysinit.target.wants/systemd-udev-root-symlink.service
%if ! 0%{?bootstrap}
%exclude %{_prefix}/lib/systemd/system/systemd-journal-gatewayd.*
%endif
%{_prefix}/lib/systemd/system/*.automount
%{_prefix}/lib/systemd/system/*.busname
%{_prefix}/lib/systemd/system/*.service
%{_prefix}/lib/systemd/system/*.slice
%{_prefix}/lib/systemd/system/*.target
%{_prefix}/lib/systemd/system/*.mount
%{_prefix}/lib/systemd/system/*.timer
%{_prefix}/lib/systemd/system/*.socket
%{_prefix}/lib/systemd/system/*.wants
%{_prefix}/lib/systemd/system/*.path
%{_prefix}/lib/systemd/user/*.target
%{_prefix}/lib/systemd/user/*.service
%exclude %{_prefix}/lib/systemd/systemd-udevd
%if ! 0%{?bootstrap}
%exclude %{_prefix}/lib/systemd/systemd-journal-gatewayd
%endif
%{_prefix}/lib/systemd/systemd-*
%{_prefix}/lib/systemd/systemd
%dir %{_prefix}/lib/systemd/catalog
%{_prefix}/lib/systemd/catalog/systemd.catalog
%{_prefix}/lib/systemd/catalog/systemd.*.catalog
%dir %{_prefix}/lib/systemd/system-shutdown
%dir %{_prefix}/lib/systemd/system-preset
%dir %{_prefix}/lib/systemd/user-preset
%dir %{_prefix}/lib/systemd/system-generators
%dir %{_prefix}/lib/systemd/user-generators
%dir %{_prefix}/lib/systemd/ntp-units.d/
%dir %{_prefix}/lib/systemd/system-shutdown/
%dir %{_prefix}/lib/systemd/system-sleep/
%dir %{_prefix}/lib/systemd/system/default.target.wants
%dir %{_prefix}/lib/systemd/system/dbus.target.wants
%dir %{_prefix}/lib/systemd/system/getty@tty1.service.d
%{_prefix}/lib/systemd/system/getty@tty1.service.d/noclear.conf
%if ! 0%{?bootstrap}
%{_prefix}/lib/systemd/system-generators/systemd-cryptsetup-generator
%endif
%{_prefix}/lib/systemd/system-generators/systemd-efi-boot-generator
%{_prefix}/lib/systemd/system-generators/systemd-getty-generator
%{_prefix}/lib/systemd/system-generators/systemd-rc-local-generator
%{_prefix}/lib/systemd/system-generators/systemd-fstab-generator
%{_prefix}/lib/systemd/system-generators/systemd-system-update-generator
%{_prefix}/lib/systemd/system-generators/systemd-insserv-generator
%{_prefix}/lib/systemd/system-generators/systemd-gpt-auto-generator
/%{_lib}/security/pam_systemd.so
%config /etc/pam.d/systemd-user

%dir %{_libexecdir}/modules-load.d
%dir %{_sysconfdir}/modules-load.d
%{_libexecdir}/modules-load.d/sg.conf

%dir %{_libexecdir}/tmpfiles.d
%dir %{_sysconfdir}/tmpfiles.d
%{_libexecdir}/tmpfiles.d/*.conf

%dir %{_libexecdir}/binfmt.d
%dir %{_sysconfdir}/binfmt.d

%dir %{_libexecdir}/sysctl.d
%dir %{_sysconfdir}/sysctl.d

%dir %{_sysconfdir}/systemd
%dir %{_sysconfdir}/systemd/system
%dir %{_sysconfdir}/systemd/user
%dir %{_sysconfdir}/xdg/systemd
%dir %{_sysconfdir}/dbus-1
%dir %{_sysconfdir}/dbus-1/system.d
%{_sysconfdir}/xdg/systemd/user
%dir %{_datadir}/dbus-1
%dir %{_datadir}/dbus-1/services
%dir %{_datadir}/dbus-1/system-services
%config(noreplace) %{_sysconfdir}/systemd/bootchart.conf
%config(noreplace) %{_sysconfdir}/systemd/system.conf
%config(noreplace) %{_sysconfdir}/systemd/logind.conf
%config(noreplace) %{_sysconfdir}/systemd/journald.conf
%config(noreplace) %{_sysconfdir}/systemd/user.conf
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/org.freedesktop.locale1.conf
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/org.freedesktop.login1.conf
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/org.freedesktop.machine1.conf
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/org.freedesktop.systemd1.conf
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/org.freedesktop.hostname1.conf
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/org.freedesktop.timedate1.conf

# Some files which may created by us
%dir %{_sysconfdir}/X11/xorg.conf.d
%ghost %config(noreplace) %{_sysconfdir}/X11/xorg.conf.d/00-keyboard.conf
%ghost %config(noreplace) %{_sysconfdir}/vconsole.conf
%ghost %config(noreplace) %{_sysconfdir}/locale.conf
%ghost %config(noreplace) %{_sysconfdir}/machine-id
%ghost %config(noreplace) %{_sysconfdir}/machine-info
%ghost %config(noreplace) %{_sysconfdir}/systemd/system/runlevel2.target
%ghost %config(noreplace) %{_sysconfdir}/systemd/system/runlevel3.target
%ghost %config(noreplace) %{_sysconfdir}/systemd/system/runlevel4.target
%ghost %config(noreplace) %{_sysconfdir}/systemd/system/runlevel5.target

%{_datadir}/dbus-1/services/org.freedesktop.systemd1.service
%{_datadir}/dbus-1/system-services/org.freedesktop.systemd1.service
%{_datadir}/dbus-1/system-services/org.freedesktop.locale1.service
%{_datadir}/dbus-1/system-services/org.freedesktop.login1.service
%{_datadir}/dbus-1/system-services/org.freedesktop.hostname1.service
%{_datadir}/dbus-1/system-services/org.freedesktop.machine1.service
%{_datadir}/dbus-1/system-services/org.freedesktop.timedate1.service
%dir %{_datadir}/polkit-1
%dir %{_datadir}/polkit-1/actions
%{_datadir}/polkit-1/actions/org.freedesktop.systemd1.policy
%{_datadir}/polkit-1/actions/org.freedesktop.hostname1.policy
%{_datadir}/polkit-1/actions/org.freedesktop.locale1.policy
%{_datadir}/polkit-1/actions/org.freedesktop.timedate1.policy
%{_datadir}/polkit-1/actions/org.freedesktop.login1.policy
%if ! 0%{?bootstrap}
%exclude %{_datadir}/systemd/gatewayd
%endif
%{_datadir}/systemd

%if ! 0%{?bootstrap}
# Packaged in sysvinit subpackage
%exclude %{_mandir}/man1/init.1*
%exclude %{_mandir}/man8/halt.8*
%exclude %{_mandir}/man8/reboot.8*
%exclude %{_mandir}/man8/shutdown.8*
%exclude %{_mandir}/man8/poweroff.8*
%exclude %{_mandir}/man8/telinit.8*
%exclude %{_mandir}/man8/runlevel.8*
%exclude %{_mandir}/man*/*udev*.[0-9]*
%exclude %{_mandir}/man8/systemd-journal-gatewayd.*
%{_mandir}/man1/*.1*
%{_mandir}/man5/*.5*
%{_mandir}/man7/*.7*
%{_mandir}/man8/*.8*
%endif
%{_docdir}/systemd
%{_prefix}/lib/udev/rules.d/70-uaccess.rules
%{_prefix}/lib/udev/rules.d/71-seat.rules
%{_prefix}/lib/udev/rules.d/73-seat-late.rules
%if ! 0%{?bootstrap}
%{_prefix}/lib/udev/rules.d/73-seat-numlock.rules
%endif
%{_prefix}/lib/udev/rules.d/99-systemd.rules
%{_prefix}/lib/udev/numlock-on
%if 0%{suse_version} < 1310
%{_sysconfdir}/rpm/macros.systemd
%endif
%dir %{_localstatedir}/lib/systemd
%dir %{_localstatedir}/lib/systemd/sysv-convert
%dir %{_localstatedir}/lib/systemd/migrated
%dir %{_localstatedir}/lib/systemd/catalog
%ghost %{_localstatedir}/lib/systemd/catalog/database
%dir %{_localstatedir}/lib/systemd/coredump
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/*
%ghost %{_localstatedir}/lib/systemd/backlight
%ghost %{_localstatedir}/lib/systemd/random-seed
%if 0%{?suse_version} > 1310
%{_datadir}/pkgconfig/systemd.pc
%endif

%if ! 0%{?bootstrap}
%files bash-completion
%defattr(-,root,root,-)
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/*
%endif

%files devel
%defattr(-,root,root,-)
%{_libdir}/libsystemd.so
%{_libdir}/libsystemd-daemon.so
%{_libdir}/libsystemd-login.so
%{_libdir}/libsystemd-id128.so
%{_libdir}/libsystemd-journal.so
%dir %{_includedir}/systemd
%{_includedir}/systemd/sd-login.h
%{_includedir}/systemd/sd-daemon.h
%{_includedir}/systemd/sd-id128.h
%{_includedir}/systemd/sd-journal.h
%{_includedir}/systemd/sd-messages.h
%{_includedir}/systemd/_sd-common.h
%if 0%{?suse_version} <= 1310
%{_datadir}/pkgconfig/systemd.pc
%endif
%{_libdir}/pkgconfig/libsystemd.pc
%{_libdir}/pkgconfig/libsystemd-daemon.pc
%{_libdir}/pkgconfig/libsystemd-login.pc
%{_libdir}/pkgconfig/libsystemd-id128.pc
%{_libdir}/pkgconfig/libsystemd-journal.pc
%if ! 0%{?bootstrap}
%{_mandir}/man3/*.3*
%endif

%files sysvinit
%defattr(-,root,root,-)
/sbin/init
/sbin/reboot
/sbin/halt
/sbin/shutdown
/sbin/poweroff
/sbin/telinit
/sbin/runlevel
%if ! 0%{?bootstrap}
%{_mandir}/man1/init.1*
%{_mandir}/man8/halt.8*
%{_mandir}/man8/reboot.8*
%{_mandir}/man8/shutdown.8*
%{_mandir}/man8/poweroff.8*
%{_mandir}/man8/telinit.8*
%{_mandir}/man8/runlevel.8*
%endif

%files -n udev%{?mini}
%defattr(-,root,root)
/sbin/udevd
/sbin/udevadm
# keep for compatibility
%ghost /lib/udev
%{_bindir}/udevadm
%dir %{_prefix}/lib/udev/
%{_prefix}/lib/udev/accelerometer
%{_prefix}/lib/udev/ata_id
%{_prefix}/lib/udev/path_id_compat
%{_prefix}/lib/udev/cdrom_id
%{_prefix}/lib/udev/collect
%{_prefix}/lib/udev/mtd_probe
%{_prefix}/lib/udev/scsi_id
%{_prefix}/lib/udev/v4l_id
%{_prefix}/lib/udev/udev-generate-persistent-rule
%{_prefix}/lib/udev/remount-tmpfs
%{_prefix}/lib/udev/rule_generator.functions
%{_prefix}/lib/udev/write_net_rules
%{_prefix}/lib/udev/rootsymlink-generator
%dir %{_prefix}/lib/udev/rules.d/
%exclude %{_prefix}/lib/udev/rules.d/70-uaccess.rules
%exclude %{_prefix}/lib/udev/rules.d/71-seat.rules
%exclude %{_prefix}/lib/udev/rules.d/73-seat-late.rules
%exclude %{_prefix}/lib/udev/rules.d/73-seat-numlock.rules
%exclude %{_prefix}/lib/udev/rules.d/99-systemd.rules
%{_prefix}/lib/udev/rules.d/*.rules
%dir %{_prefix}/lib/udev/hwdb.d
%{_prefix}/lib/udev/hwdb.d/*
%dir %{_sysconfdir}/udev/
%dir %{_sysconfdir}/udev/rules.d/
%ghost %{_sysconfdir}/udev/hwdb.bin
%config(noreplace) %{_sysconfdir}/udev/udev.conf
%if ! 0%{?bootstrap}
%{_mandir}/man?/*udev*.[0-9]*
%endif
%dir %{_prefix}/lib/systemd/system
%{_prefix}/lib/systemd/systemd-udevd
%{_prefix}/lib/systemd/system/systemd-udev*.service
%{_prefix}/lib/systemd/system/systemd-udevd*.socket
%{_prefix}/lib/systemd/system/initrd-udevadm-cleanup-db.service
%dir %{_prefix}/lib/systemd/system/sysinit.target.wants
%{_prefix}/lib/systemd/system/sysinit.target.wants/systemd-udev*.service
%dir %{_prefix}/lib/systemd/system/sockets.target.wants
%{_prefix}/lib/systemd/system/sockets.target.wants/systemd-udev*.socket
%dir %{_prefix}/lib/systemd/network
%{_prefix}/lib/systemd/network/*.link
%{_prefix}/lib/systemd/network/*.network
%if 0%{?suse_version} > 1310
%{_datadir}/pkgconfig/udev.pc
%endif

%files -n libudev%{?mini}1
%defattr(-,root,root)
%{_libdir}/libudev.so.*

%files -n libudev%{?mini}-devel
%defattr(-,root,root)
%{_includedir}/libudev.h
%{_libdir}/libudev.so
%if 0%{?suse_version} <= 1310
%{_datadir}/pkgconfig/udev.pc
%endif
%{_libdir}/pkgconfig/libudev.pc
%if ! 0%{?bootstrap}
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%dir %{_datadir}/gtk-doc/html/libudev
%{_datadir}/gtk-doc/html/libudev/*
%endif

%if ! 0%{?bootstrap}
%files -n libgudev-1_0-0
%defattr(-,root,root)
%{_libdir}/libgudev-1.0.so.*

%files -n typelib-1_0-GUdev-1_0
%defattr(-,root,root)
%{_libdir}/girepository-1.0/GUdev-1.0.typelib

%files -n libgudev-1_0-devel
%defattr(-,root,root)
%dir %{_includedir}/gudev-1.0
%dir %{_includedir}/gudev-1.0/gudev
%{_includedir}/gudev-1.0/gudev/*.h
%{_libdir}/libgudev-1.0.so
%{_libdir}/pkgconfig/gudev-1.0.pc
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%dir %{_datadir}/gtk-doc/html/gudev
%{_datadir}/gtk-doc/html/gudev/*
%{_datadir}/gir-1.0/GUdev-1.0.gir

%files logger
%defattr(-,root,root)
%dir %attr(2755,root,systemd-journal) %{_localstatedir}/log/journal/
%{_localstatedir}/log/README

%files -n nss-myhostname
%defattr(-, root, root)
%{_sbindir}/nss-myhostname-config
/%{_lib}/*nss_myhostname*

%files journal-gateway
%defattr(-, root, root)
%{_prefix}/lib/systemd/system/systemd-journal-gatewayd.*
%{_prefix}/lib/systemd/systemd-journal-gatewayd
%{_mandir}/man8/systemd-journal-gatewayd.*
%{_datadir}/systemd/gatewayd
%endif

%changelog
* Tue May 10 2016 fbui@suse.com
- Restore initrd-udevadm-cleanup-db.service (bsc#978275, bsc#976766)
  It's been removed accidentally.
* Thu Apr 28 2016 fbui@suse.com
- Import commit d2008b4ebb6616144eeb796275d506e81903c13a:
  - cbf8f8a transaction_add_job_and_dependencies(): return ENOENT when a unit is not found (bsc#960158 second part)
* Fri Apr 22 2016 fbui@suse.com
- Import commit 7850342baaa, which introduced the following changes:
  - c06dd31 Fix backport of "tmpfiles: add ability to mask access mode by pre-existing access mode on files/directories" (bsc#973848)
* Fri Apr  1 2016 fbui@suse.com
- Import commit bff8627c81f, which introduced the following changes:
  - e5e362a udev: exclude MD from block device ownership event locking
  - 8839413 udev: really exclude device-mapper from block device ownership event locking
  - 66782e6 udev: exclude device-mapper from block device ownership event locking (bsc#972727)
  - 1386f57 tmpfiles: explicitly set mode for /run/log
  - faadb74 tmpfiles: don't allow read access to journal files to users not in systemd-journal
  - 9b1ef37 tmpfiles: don't apply sgid and executable bit to journal files, only the directories they are contained in
  - 011c39f tmpfiles: add ability to mask access mode by pre-existing access mode on files/directories
  - 07e2d60 tmpfiles: get rid of "m" lines
  - d504e28 tmpfiles: various modernizations
  - f97250d systemctl: no need to pass --all if inactive is explicitly requested in list-units (bsc#967122)
  - 2686573 fstab-generator: fix automount option and don't start associated mount unit at boot (bsc#970423)
  - 5c1637d login: support more than just power-gpio-key (fate#318444) (bsc#970860)
  - 2c95ecd logind: add standard gpio power button support (fate#318444) (bsc#970860)
  - af3eb93 Revert "log-target-null-instead-kmsg"
  - 555dad4 shorten hostname before checking for trailing dot (bsc#965897)
  - 522194c Revert "log: honour the kernel's quiet cmdline argument" (bsc#963230)
  - cc94e47 transaction: downgrade warnings about wanted unit which are not found (bsc#960158)
  - eb3cfb3 Revert "vhangup-on-all-consoles"
  - 0c28752 remove WorkingDirectory parameter from emergency, rescue and console-shell.service (bsc#959886)
* Fri Apr  1 2016 fbui@suse.com
- Don't allow read access to journal files to users (boo#972612 CVE-2014-9770 CVE-2015-8842)
  Remove the world read bit from the permissions of (persistent)
  archived journals. This was incorrectly set due to backported commit
  18afa5c2a7a6c215.
  For the same reasons we also have to fix the permissions of
  /run/log/journal/<machine-id> directory to make sure that regular
  user won't access to its content.
* Thu Mar 31 2016 fbui@suse.com
- spec: remove libudev1 runtime dependencies on udev
* Thu Mar 31 2016 fbui@suse.com
- spec remove libusb-devel and pkgconfig(usbutils) BRs from systemd
  They're not needed since v196 (see commit 796b06c21b62d13).
* Thu Mar 31 2016 fbui@suse.com
- spec: no need to post-require libudev1 for udev
* Thu Mar 31 2016 fbui@suse.com
- spec: no need for libgudev to require the mini version of libudev.
  Since this package is not built when bootstrapping.
* Thu Mar 31 2016 fbui@suse.com
- Don't ship boot.udev and systemd-journald.init anymore.
  It was used during the systemd transition when both sysvinit and
  systemd could be used on the same system
* Thu Mar 31 2016 fbui@suse.com
- spec: do not filter out command completions which rely on
  _init_completion() anymore.
  This function is provided by bash-completion package on all distros
  we're shipping v210
* Thu Mar 31 2016 fbui@suse.com
- rop %%{real} and simplify sed expr in pre_checkin.sh
* Thu Mar 31 2016 fbui@suse.com
- Drop %%{udevpkgname}/%%{udev_major} and introduce %%{mini} instead
  This is imported from Base:System and makes the specfile a little
  bit easier to parse.
* Thu Mar 31 2016 fbui@suse.com
- spec: disable build of src/test since we currently don't run the testsuite
* Thu Mar 31 2016 fbui@suse.com
- spec: use %%{name} in Source1
* Thu Mar 31 2016 fbui@suse.com
- spec: use %%make_install
* Wed Mar 16 2016 fbui@suse.com
- drop all compiler/linker option customizations:
  - -pipe option is used by default since day 0
  - get rid of cflags() function which is not needed
  - --hash-size has no impact specially in runtime
  IOW, use the default options for the compiler and the linker,
  there's no point in making systemd different from other package in
  this regards.
* Wed Mar 16 2016 fbui@suse.com
- Fix UEFI detection logic: basically we let configure.ac figure out
  if UEFI is supported by the current build environment. No need to
  clutter the spec file with a new conditionnal %%has_efi.
* Mon Feb 22 2016 fbui@suse.com
- Don't build require binutils-gold anymore
  The use of the gold linker has been (probably) introduced due to
  the use of the -flto option. However forcing the version of the linker
  is not a good idea since it's not supported on various architectures.
  Since -flto has been disabled, it's now safe to use the *default*
  linker.
  It actually fixed a build error on 13.1 on the ppc arch.
* Mon Feb  8 2016 fbui@suse.com
- Don't ship fix.service anymore on 13.1, not needed by v210 (boo#965475)
* Tue Feb  2 2016 fbui@suse.com
- Fix wrong substitution variable name in systemd-udev-root-symlink.service.in (boo#964355)
* Thu Jan 28 2016 fbui@suse.com
- udev firmware loading support has been removed from 13.1
* Thu Jan 28 2016 fbui@suse.com
- systemd-firstboot is also shipped by SLE12
* Wed Jan 20 2016 fbui@suse.com
- Revert "disable device timeout when nofail is set" (bsc#962080)
* Wed Jan 20 2016 fbui@suse.com
- Revert "0001-make-fortify-happy-with-ppoll" (bsc#958937)
* Thu Jan 14 2016 Thomas.Blume@suse.com
- udev: set udev max children logging to debug level (bsc#958295)
* Wed Jan 13 2016 fbui@suse.com
- don't use OBS service "set_service" anymore (bsc#961576)
* Tue Jan 12 2016 lennart@poettering.net
- journald: properly sum up entry size counter (bsc#961226)
* Tue Jan 12 2016 zbyszek@in.waw.pl
- shutdown: rework messages during shutdown (bsc#955469)
* Tue Dec 22 2015 fbui@suse.com
- Don't track units/systemd-udev-root-symlink.service
* Tue Dec 22 2015 hare@suse.de
- Move net_persistent_rule generator to SCRIPTS (bsc#958935)
* Wed Dec  9 2015 fbui@suse.com
- Revert "Skip persistent device link creation on multipath device paths" (bsc#942946)
* Wed Dec  9 2015 kay@vrfy.org
- udev: remove userspace firmware loading support
* Fri Dec  4 2015 fbui@suse.com
- make sure all swap units are ordered before the swap target (bsc#955770)
* Fri Dec  4 2015 fbui@suse.com
- fstab-generator: restore parsing and handling of 'nofail'/'noauto' options for swap devices
* Thu Dec  3 2015 fbui@suse.com
- fix build for systemd-mini package
* Thu Dec  3 2015 meissner@suse.com
- remove libudev0 from baselibs.conf, it is libudev1 these days
- disable services
- restore %%setup -n for systemd-mini
* Mon Nov 30 2015 werenr@suse.de
- Restore 'Do not break already installed systemd out there'
  Mon Nov 30 09:44:22 GMT 2015 - systemd-maintainers.de
- Restore 'respect_ro_bootparam'
* Fri Nov 27 2015 fbui@suse.com
- Revert "respect_ro_bootparam" (boo#948555)
* Fri Nov 27 2015 fbui@suse.com
- Revert "Do not break already installed systemd out there"
* Fri Nov 27 2015 fbui@suse.com
- bash-completion: add minimal support fpr 'set-property' command (bsc#948458)
* Mon Nov 23 2015 Thomas.Blume@suse.com
- disable device timeout when nofail is set (bsc#949683)
* Fri Nov 13 2015 fbui@suse.com
- fix 0003-namespace-make-sure-tmp-var-tmp-and-dev-are-writable.patch:
  it incorrectly returned an error when paths given by
  ReadOnlyDirectories= and InaccessibleDirectories= directives were
  prefixed with "-" and didn't exist (bsc#954781).
* Thu Nov 12 2015 werner@suse.de
- Modify patch handle-root_uses_lang-value-in-etc-sysconfig-language.patch
  to handle locale at boot time well (boo#927250)
* Wed Nov 11 2015 werner@suse.de
- Allow systemd-sysv-convert to do its job even if one of the sysvinit
  script is not found (bsc#954336)
* Tue Nov 10 2015 fbui@suse.com
- systemd-sysv-convert --save: process all arguments even if one of
  them failed. '--show' already has this behaviour. Fix (bsc#954336).
* Tue Nov 10 2015 fbui@suse.com
- Previous patch needed some context adjustement to be applied to v210.
* Tue Nov 10 2015 fbui@suse.com
- add 0001-Make-sure-the-mount-units-pulled-by-RequiresMountsFo.patch
  in order to fix bsc#949574
* Wed Nov  4 2015 thomas.blume@suse.com
- fix disabled event source handling (bsc#951663)
  add 0001-sd-event-fix-prepare-priority-queue-comparison-funct.patch
* Wed Nov  4 2015 fbui@suse.com
- Drop the support of the new property "Delegate". Several performance
  regressions have been reported since it was introduced, see
  bsc#953241 for example. This feature was originally introduced when
  backporting a fix for bsc#932284, however this was not mandatory.
* Thu Oct 29 2015 fbui@suse.com
- Fix typo made by previous commit
* Thu Oct 29 2015 fbui@suse.com
- firstboot is shipped only by SLE12-SP1 or higer
* Wed Oct 28 2015 fbui@suse.com
- Fetch the source code from the gitlab repository
* Wed Oct 28 2015 werner@suse.de
- Modernize patch tty-ask-password-agent-on-console.patch (maybe
  related to bsc#949739)
* Tue Oct 27 2015 rmilasan@suse.com
- rootsymlink_generator: create /run/udev if it doesnt exists so we
  wont fail when starting (bsc#945282).
  Add 1107-rootsymlink-generator-fix-mkdir.patch
* Mon Oct 26 2015 werner@suse.de
- Remove my test shell function cflags
- Remove --hash-size options as there is no any change in the final
  binary nor library anymore
- Again change 1101-rules-persistent-device-names-for-NVMe-devices.patch
  to apply even if patch 1012-Skip-persistent-device-link-creation-on-multipath-de.patch
  has been removed
* Fri Oct 23 2015 werner@suse.de
- Add patch Do-not-delegate-cgroup-control-blkid.patch
  to avoid IO performance break down as side effect of patch
  0001-core-introduce-new-Delegate-yes-no-property-controll.patch
  (bsc#951265)
* Fri Oct 23 2015 rmilasan@suse.com
- rules: generate by-path links NVMe devices (bsc#944132).
  Update 1101-rules-persistent-device-names-for-NVMe-devices.patch
- path_id_compat: add old fashion phy sas disk enumeration (bsc#950510).
  Add 1106-path_compat_id-phy-sas-disk-enumeration.patch
* Mon Oct 19 2015 fbui@suse.com
- Previous commit removed Werner's workaround to rebuild systemd
  inside osc chroot. Another workaround was suggested for this workflow
  which is now added (but commented) in the specfile as required by
  Werner.
* Fri Oct 16 2015 fbui@suse.com
- Dropped let-linker-find-libudev-for-libdevmapper.patch: this patch
  modified generated files which won't be shipped anymore when we'll
  use the tarball from the git repo.
  It was a workaround for a very specific (build debug) use case:
  - osc build
  - osc chroot
  - cd rpmbuild/BUILD/systemd
  - <hack> <hack> <hack>
  - make
    ...
    x86_64-suse-linux/bin/ld: warning: libudev.so.1, needed by /lib64/libdevmapper.so.1.02, not found
  This is due to the post-build-checks done by "osc build" which
  consist of testing the installation and removal of generated
  packages inside the chroot. However libudev1 is one of them but it's
  also an indirect build requirement for systemd. So removing libudev1
  from the chroot prevent any further builds of systemd in the chroot.
  There's a workaround for this which consists of disabling
  post-build-checks by adding "BuildRequires:-post-build-checks" in
  the spec file if one plan to use the chroot as a devel workspace.
* Fri Oct 16 2015 fbui@suse.com
- Dropped 0009-make-xsltproc-use-correct-ROFF-links.patch: it modifies
  generated files which is going to be problematic when we'll use the
  tarball from the git repo. Moreover it workarounded very minor issue
  and man(1) should be fixed instead anyway.
* Thu Oct 15 2015 fbui@suse.com
- Extract -flto disabling from let-linker-find-libudev-for-libdevmapper.patch
  and create a new patch which does that:
  0001-Don-t-pass-flto-switch-to-GCC-when-compiling-systemd.patch
* Thu Oct 15 2015 fbui@suse.com
- Cleanup 0001-make-209-working-on-older-dist.patch: replace it with
  0001-Revert-static-nodes-don-t-call-mkdir.patch which is basically
  the same thing but the latter was generated with 'git-revert' and it
  doesn't modify generated files.
* Thu Oct 15 2015 fbui@suse.com
- Sanitize 1022-udev-remove-seqnum-API-and-all-assumptions-about-seq.patch
  in order to make git-am happy.
* Thu Oct 15 2015 werner@suse.de
- Fix the last patch, that is check really for 8 characters (boo#900558)
* Mon Oct 12 2015 werner@suse.de
- Be aware that patch
  1104-udev-exclude-device-mapper-from-block-device-ownersh.patch
  is already part for openSUSE 13.2 and above as
  1025-udev-exclude-device-mapper-from-block-device-ownersh.patch
* Fri Oct  9 2015 werner@suse.de
- Add patch rename_ro_bootparam_to_readonly.patch
  There are systems out there where "ro" is already in use!
  Regardless if this is a bug or not, it is not an option to
  break existing systems (boo#900558).
* Thu Oct  8 2015 thomas.blume@suse.com
- revert io scheduler for ssd disks to use deadline (fate#319110)
  Remove 1095-set-ssd-disk-to-use-noop-scheduler.patch
  Re-add 1095-set-ssd-disk-to-use-deadline-scheduler.patch
* Tue Oct  6 2015 werner@suse.de
- Add patch
  0001-virt-handle-Virtualbox-5.0-with-kvm-hypervisor.patch
  to support Virtualbox 5.0 as this release now supports the
  kvm hypervisor (boo#948705)
* Tue Oct  6 2015 thomas.blume@suse.com
- suppress warnings about duplicate sysfs paths (bsc#947212)
  Add ported upstream patch:
  core-downgrade-warning-about-duplicate-device-names.patch
* Fri Oct  2 2015 werner@suse.de
- Change patch 1101-rules-persistent-device-names-for-NVMe-devices.patch
  to apply even if patch 1012-Skip-persistent-device-link-creation-on-multipath-de.patch
  has been removed
* Thu Oct  1 2015 rmilasan@suse.com
- rules: rework KVM persistent rules generation (bsc#938908)
  Add 1105-rules-rework-KVM-persistent-rules-generation.patch
* Thu Sep 24 2015 rmilasan@suse.com
- rootsymlink_generator: always return success even if stat fails (bsc#945282)
  Add 1103-rootsymlink_generator-return-success-even-if-stat-fails.patch
- udev: exclude device-mapper from block device ownership event locking (bsc#944799)
  Add 1104-udev-exclude-device-mapper-from-block-device-ownersh.patch
* Fri Sep 18 2015 werner@suse.de
- The patch fix-kexec-force-reboot.patch has been added (bsc#940264)
- Add patch watchdog-ignore-ENOTTY.patch
  Not all watchdog drivers implement WDIOC_SETOPTIONS. Drivers which do
  not implement it have their device always enabled. So it's fine to
  report an error if WDIOS_DISABLECARD is passed and the ioctl is not
  implemented, however failing when WDIOS_ENABLECARD is passed and the
  ioctl is not implemented is not good: if the device was already
  enabled then WDIOS_ENABLECARD was a no-op and wasn't needed in the
  first place. So we can just ignore the error and continue (bsc#933533)
* Thu Sep 17 2015 werner@suse.de
- Add patch let-vconsole-setup-get-properties-only-once-to-copy-them.patch
  to avoid broken virtual console mapping due stressed ioctl API
  for the virtual consoles (boo#904214)
* Tue Sep 15 2015 fbui@suse.com
- firstboot: remove SUSE specific bits for locale handling. The system locale
  handling is currently broken on SUSE distros and probably is going to be
  fixed. Until this happens, we shouldn't try to add another undefined
  behaviour during firstboot. Indeed the patch only copied
  /etc/sysconfig/language *or* /etc/locale.conf but not both. If locale
  setting was not copied but prompted, only /etc/locale.conf was initialized
  making any further locale changes done by YaST useless.
- Removed patch firstboot_for_suse.patch included some fixes when
  setting permission bits on the copied locale.conf. Include a new
  single patch 0001-firstboot-fix-permission-bits-initialisation-done-on.patch
  for restoring these previous fixes.
* Tue Sep 15 2015 rmilasan@suse.com
- rules: fix persistent net rule generation for KVM (bsc#938908).
  Add 1102-rules-fix-persistent-net-rule-generation-for-KVM.patch
* Thu Sep  3 2015 werner@suse.de
- Add upstream patches
  0001-core-introduce-new-Delegate-yes-no-property-controll.patch
  0001-unit-suppress-unnecessary-cgroup-empty-check.patch
  0002-units-enable-waiting-for-unit-termination-in-certain.patch
  all related to cgroup handling, at least the last patch avoids
  that processes in scopes like login shells are killed immediately
  after signaled with SIGTERM (bsc#932284)
* Wed Sep  2 2015 werner@suse.de
- Add patch
  correct-order-of-compose-and-key-map.patch
  to avoid race condition for two loadkey processes, that is one
  loading the keymap and one for loading the compose tables (bsc#941576)
* Wed Sep  2 2015 rmilasan@suse.com
- Rename patch udev-removing-a-symlink-for-an-add-event-is-an-error.patch
  to 1100-udev-removing-a-symlink-for-an-add-event-is-an-error.patch
- rules: persistent devices names for NVMe devices (bsc#944132).
  Add 1101-rules-persistent-device-names-for-NVMe-devices.patch
* Mon Aug 31 2015 fbui@suse.com
- firstboot: create a proper patch headers for firstboot patches.
* Mon Aug 31 2015 fbui@suse.com
- firstboot: add upstream fix "load-fragment: ConditionFirstBoot wants a bool
  string, not a path".
* Fri Aug 28 2015 thomas.blume@suse.com
- Don't mount system root rw, if ro is given as boot parameter (bsc#900558)
    Add respect_ro_bootparam.patch
* Fri Aug 28 2015 hare@suse.de
- revert changes from bsc#872929; superseded by later changes
  (bsc#942946)
  Remove 1012-Skip-persistent-device-link-creation-on-multipath-de.patch
* Fri Aug 21 2015 fbui@suse.com
- installed systemd and udev packages should have the same version.
  These days udev and systemd are so related that it doesn't semm correct to
  allow running systemd with udev having a different version.
* Fri Aug 21 2015 thomas.blume@suse.com
- make TERM configurable for vm serial consoles (bsc#913517)
  Add term-serial-console-vm.patch
* Thu Aug 20 2015 werner@suse.de
- Add upstream patch found by Franck Bui
  0001-units-local-fs.target-don-t-pull-in-default-dependen.patch
  to avoid delay while booting with nofail entries in fstab (boo#912334)
* Wed Aug 19 2015 werner@suse.de
- Add patch firstboot_for_suse.patch that is make firstboot backport
  work for SUSE
* Thu Aug 13 2015 werner@suse.de
- Change use-rndaddentropy-ioctl-to-load-random-seed.patch to
  make it work on big endian
* Thu Aug 13 2015 thomas.blume@suse.com
- set the io scheduler for ssd disks to noop (fate#319110)
  Add 1095-set-ssd-disk-to-use-noop-scheduler.patch
  Remove 1095-set-ssd-disk-to-use-deadline-scheduler.patch
* Tue Aug 11 2015 fcrozat@suse.com
- Add firstboot.patch: backport firstboot helper and
  ConditionFirstBoot support from upstream (FATE#318894).
* Thu Jul 30 2015 werner@suse.de
- Add upstream patch 0001-Reload-manager-defaults-at-daemon-reload.patch
  to enable systemd to parse /etc/systemd/system.conf on daemon
  reload (bsc#933521)
* Thu Jul 30 2015 werner@suse.de
- Add upstream patch
  0001-sd-bus-create-clean-error-when-a-property-Set-call-w.patch
  to avoid stucked sbus connection due invalid dbus call (bsc#937900)
* Wed Jul 29 2015 werner@suse.de
- Add Correct_assert_on_unexpected_error_code.patch to work around
  a problem of an assert on ENODEV for closing fd on an input
  event device (boo#939571)
* Wed Jul 15 2015 werner@suse.de
- Add patch 0001-cgroup-memory-limits-on-are-not-supported.patch
  which fixes bsc#937512 - systemd Failed to set
  memory.limit_in_bytes on : Invalid argument
* Tue Jul  7 2015 jengelh@inai.de
- Avoid restarting logind [bnc#934901]
* Fri Jun 19 2015 thomas.blume@suse.com
- respect DefaultTimeoutStopSec in systemd unit files (bsc#933512)
  Add upstream patch
  0001-service-use-the-right-timeout-for-stop-processes-we-.patch
* Wed Jun 17 2015 werner@suse.de
- Add upstream patches
  0001-dbus-return-non-zero-return-value-in-the-case-that-p.patch
  0002-core-OOM-really-shouldn-t-be-considered-a-deserializ.patch
  0001-core-make-unit-deserialization-more-defensive.patch
  to make serializing/deserializing more stable
* Tue Jun 16 2015 werner@suse.de
- Add upstream patch
  0001-core-fix-assert-when-trying-to-serialize-non-initial.patch
  to fix last patch
- Add upstream patches
  0002-core-shared-in-deserializing-match-same-files-reache.patch
  0003-device-rework-how-we-enter-tentative-state.patch
  0004-core-don-t-consider-boot-up-finished-if-we-are-still.patch
  to extend property serializing/deserializing over daemon reload
* Mon Jun 15 2015 werner@suse.de
- Add upstream patch
  0001-bus-add-sd_bus_track-object-for-tracking-peers-and-p.patch to
  let bus connection survive a daemon reload as well as let services
  track clients which reference certain objects they maintain. This
  solve the problem that e.g. the sd-pam processes become not closed
  together with closing an ssh connection after a daemon reload.
* Wed Jun 10 2015 thomas.blume@suse.com
- Add upstream patch
  0001-man-systemd.unit-5-add-examples-for-common-tasks.patch
  to improve feature documentation (bsc#927457 comment#40)
* Tue Jun  9 2015 werner@suse.de
- Add patch let-some-boolean-survive-a-daemon-reload.patch
  to fix bsc#933365 and boo#934077
* Wed May 20 2015 werner@suse.de
- Add upstream patch
  0001-systemctl-return-an-error-code-is-status-fails.patch to
  return status code even with SysVinit boot scripts (boo#931388)
* Mon May 18 2015 rmilasan@suse.com
- rules: support "locally administered" mac address in persistent rules (bnc#921831)
  update: 1021-udev-re-add-persistent-net-rules.patch
- rules: drop 76-net-sriov-names.rules and net-set-sriov-names (bnc#921831)
  update: 1021-udev-re-add-persistent-net-rules.patch
  drop: 1050-only-rename-SRIOV-VF-devices-when-name-starts-with-eth.patch
  drop: 1051-check-if-NAME-has-a-value.patch
  drop: 1088-drop-renaming-of-virtual-interfaces-in-guest.patch
* Tue May 12 2015 werner@suse.de
- Add the missed SR#291265
- Add the changes for SLES for bsc#909358
- Remove patch 0001-Allow-up-to-4096-simultaneous-dbus-connections.patch
  to make the patches 0001-Remove-the-cap-on-epoll-events.patch
  and 0002-Allow-up-to-4096-simultaneous-connections.patch work
* Thu Apr 23 2015 werner@suse.de
- Add upstream patch
  0001-journal_fix_Inappropriate_ioctl_for_device_on_ext4.patch
  to avoid confusing warning messages (boo#928265)
* Tue Apr 21 2015 werner@suse.de
- Add patch 0001-Allow-up-to-4096-simultaneous-dbus-connections.patch
  for bsc#920195 - systemd issuing messages: too many concurrent
  connections
- Really remove write_dev_root_rule and systemd-udev-root-symlink
  as patch 1096-new-udev-root-symlink-generator.patch does the job
- Really remove patch keep-crypt-password-prompt.patch
  as patch
  0012-manager-do-not-print-anything-while-passwords-are-be.patch
  does the job
* Mon Apr 20 2015 werner@suse.de
- Modify patch use-rndaddentropy-ioctl-to-load-random-seed.patch
  to fix bsc#926169
* Fri Mar 20 2015 tcech@suse.cz
- for bnc#909358
  add patch udev-removing-a-symlink-for-an-add-event-is-an-error.patch
  add patch 0001-systemd-mount-set-device-timeout-from-the-kernel-com.patch
* Wed Mar 18 2015 thomas.blume@suse.com
- correct systemd-sleep-grub return code (bsc#919095)
* Tue Mar 17 2015 thomas.blume@suse.com
- Fix systemd --test option (bsc#921920)
  add 0001-test-engine-fix-access-to-unit-load-path.patch
* Mon Mar 16 2015 werner@suse.de
- Add upstream patch
  0001-core-don-t-change-removed-devices-to-state-tentative.patch
  to fix the fix of the last backport (bsc#921898)
* Fri Mar 13 2015 werner@suse.de
- Add upstream patch
  0001-core-rework-device-state-logic.patch
  to fix a reace condition where systemd unmounts devices known
  by the sysfs but not by udev (bsc#921898)
* Fri Mar 13 2015 tcech@suse.cz
- for bnc#920195
  - cbecf9b and 1c724e9 from GIT
    add patch 0001-Remove-the-cap-on-epoll-events.patch
    add patch 0002-Allow-up-to-4096-simultaneous-connections.patch
* Mon Mar  2 2015 thomas.blume@suse.com
- sync with patches from Base:System:Legacy (bsc#910315)
* Wed Feb 18 2015 rmilasan@suse.com
- Add path_id_compat for backwards compatibility with SLE11 (bnc#916420).
  Add 1099-add-path_compat_id-to-provide-backwards-compatibility.patch
* Tue Feb 17 2015 thomas.blume@suse.com
- do not watch for socket events when service is in SERVICE_STOP (bsc#918118)
  Add 0001-core-don-t-watch-for-socket-events-when-service-is-i.patch
* Thu Jan 22 2015 werner@suse.de
- Add upstream patch
  0001-journal-call-connect-with-dropped-privileges.patch
- Add upstream patch from mail
  0001-logind-fix-sd_eviocrevoke-ioctl-call.patch
* Thu Jan 22 2015 werner@suse.de
- Disable gold binutils due hint from bintuls maintainer
* Thu Jan 22 2015 thomas.blume@suse.com
- remove superfluous set -x from systemd-sleep-grub (bsc#905550)
* Tue Jan 20 2015 thomas.blume@suse.com
- make sure that quotacheck is executed after fsck for system root
  is finished (bnc#897799)
  add run-fsck-before-quotacheck.patch
* Tue Jan 20 2015 werner@suse.de
- Add patch kbd-model-map.patch to add missed keyboard layouts
  which are offered by YaST2 (bsc#910643 and boo#897803)
* Mon Jan 19 2015 thomas.blume@suse.com
- due to fragmentation, journal flushes on btrfs can take very long
  add-upstream-btrfs-journal-fragmentation-fixes.patch (bnc#911347)
* Wed Jan  7 2015 arvidjaar@gmail.com
- update set-and-use-default-logconsole.patch - fix comparison of
  console log facility that caused journald to skip output to console
  (boo#912030)
* Sun Dec 21 2014 arvidjaar@gmail.com
- ensure processes started using su by sysv scripts are not stopped
  early on shutdown (boo#906900 and bsc#932284)
  * Add session-class-service.patch
    introduce new session class "service" that does not termninate
    processes in its scope
  * Add set-session-class-service-for-sysv.patch
    set session class to "service" for sysvinit scripts.
* Thu Dec 18 2014 werner@suse.de
- Use Robert's latest patch
  1098-udev-link_setup-respect-kernel-name-assign-policy.patch
  which drops NAMEPOLICY_KERNEL as this breaks all on current
  systems out there
* Wed Dec 17 2014 thomas.blume@suse.com
- remove 0022-systemd-tmpfiles-ownerkeep.patch since this is now
  implemented into the systemd-tmpfiles binary
- add user based ignore statements in tmpfiles removal directives
  (bnc#903009)
  add systemd-add-user-keep.patch
* Tue Dec 16 2014 thomas.blume@suse.com
- use --boot option in systemd-tmpfiles-setup-dev.service (bnc#908476)
  add upstream patches:
  0001-units-tmpfiles-setup-dev-allow-unsafe-file-creation-.patch
  0002-man-tmpfiles.d-recommend-using-b-and-c.patch (adapted)
* Tue Dec 16 2014 werner@suse.de
- Update patch
  1098-udev-link_setup-respect-kernel-name-assign-policy.patch
  to Robert's version
* Mon Dec 15 2014 werner@suse.de
- Add upstream patches
  0001-selinux-access-fix-broken-ternary-operator.patch
  0002-systemctl-show-BindsTo-BoundBy-in-list-dependencies.patch
  0003-cryptsetup-default-to-no-hash-when-keyfile-is-specif.patch
  0004-core-fix-transaction-destructiveness-check-once-more.patch
- Avoid old net devices naming scheme on openSUSE 13.2 and less
  maybe caused by patch
  1098-udev-link_setup-respect-kernel-name-assign-policy.patch
* Thu Dec 11 2014 thomas.blume@suse.com
- fix systemd-nspawn network-veth support (bnc#906709)
  add 513-nspawn-veth.patch
* Fri Dec  5 2014 werner@suse.de
- Add upstream patch
  1098-udev-link_setup-respect-kernel-name-assign-policy.patch
  which may solve bsc#907318
* Fri Dec  5 2014 werner@suse.de
- Add upstream patches
  0001-units-make-sure-rfkill-service-is-bount-to-the-actua.patch
  0002-rfkill-rework-how-we-generate-file-names-from-rfkill.patch
* Fri Nov 28 2014 rmilasan@suse.com
- Change the maximum number of children from CPU_COUNT * 256 to
  CPU_COUNT * 64.
  Update 1097-udevd-increase-maximum-number-of-children.patch
* Thu Nov 27 2014 rmilasan@suse.com
- Increase number of children/workers to CPU_COUNT * 256 to avoid
  'maximum number of children reached' (bnc#907393).
  Add 1097-udevd-increase-maximum-number-of-children.patch
* Tue Nov 25 2014 rmilasan@suse.com
- Fix error return in rootsymlink_generator.c
  Update 1096-new-udev-root-symlink-generator.patch
* Fri Nov 21 2014 werner@suse.de
- Remove upstream patch
  0001-systemd-logind.service-set-Type-notify.patch
  as systemd-logind.service is already from DBus type, compare with
  upstream commit eab459bc0639b81b32735f36d3e929e4bfa2cb4b
* Thu Nov 20 2014 werner@suse.de
- Add upstream patches
  0001-systemd-logind.service-set-Type-notify.patch
  0002-core-watchdog-bus-properties-cannot-be-both-writable.patch
  0003-sd-bus-refuse-properties-that-claim-to-be-both-writa.patch
* Thu Nov 20 2014 werner@suse.de
- Re-add directory /usr/lib/systemd/system/basic.target.wants
* Wed Nov 19 2014 gber@opensuse.org
- remove pm-utils-hooks-compat.sh again, pm-utils built-in hooks
  partially duplicate hooks run by systemd which may potentially
  lead to problems, instead temporarily re-enable
  Forward-suspend-hibernate-calls-to-pm-utils.patch until
  boo#904828 can be addressed properly
* Wed Nov 19 2014 Led <ledest@gmail.com>
- fix bashisms in write_net_rules script
- update patches:
  * 1053-better-checks-in-write_net_rules.patch
* Tue Nov 18 2014 werner@suse.de
- Add upstream patches
  0001-systemctl-let-list-units-unit-files-honour-type.patch
  0002-systemctl-obey-state-in-list-unit-files.patch
  which allows to use --type in the systemctl command list-units
  and list-unit-files.
* Tue Nov 18 2014 werner@suse.de
- Add upstream patches
  0001-keymap-Add-support-for-IBM-ThinkPad-X41-Tablet.patch
  0002-keymap-Fix-special-keys-on-ThinkPad-X60-X61-Tablet.patch
* Thu Nov 13 2014 rmilasan@suse.com
- New root symlink rule generator
  Add 1096-new-udev-root-symlink-generator.patch
- Remove write_dev_root_rule and systemd-udev-root-symlink
* Thu Nov 13 2014 werner@suse.de
- Change patch 0001-add-hdflush-for-reboot-or-hddown-for-poweroff.patch
  to skip hdflush as well as hddown but only use halt as fallback
  for poweroff as well as synch in systemctl before any reboot command
  (compare with commit 4a3ad39957399c4a30fc472a804e72907ecaa4f9)
* Thu Nov 13 2014 rmilasan@suse.com
- Create rule to set I/O scheduler to deadline if device attribute
  'rotational' equals 0, usually SSDs (bnc#904517).
  Add 1095-set-ssd-disk-to-use-deadline-scheduler.patch
* Thu Nov 13 2014 thomas.blume@suse.com
- fix systemd-fstab-generator crypttab parsing (bnc#903963)
* Tue Nov 11 2014 gber@opensuse.org
- Add pm-utils-hooks-compat.sh in order to run pm-utils sleep hooks
  from systemd (boo#904828)
* Mon Nov 10 2014 werner@suse.de
- Add upstream patches
  0001-login-rerun-vconsole-setup-when-switching-from-vgaco.patch
  0002-shutdown-fix-arguments-to-run-initramfs-shutdown.patch
  0003-utf8-when-looking-at-the-next-unichar-honour-the-siz.patch
* Mon Nov 10 2014 werner@suse.de
- Add upstream patches
  0001-core-don-t-allow-enabling-if-unit-is-masked.patch
  0002-snapshot-return-error-when-snapshot-exists.patch
  0003-shared-install-avoid-prematurely-rejecting-missing-u.patch
  0004-Raise-level-of-Found-dependency.-lines.patch
  0005-units-order-sd-journal-flush-after-sd-remount-fs.patch
  0006-journald-fix-minor-memory-leak.patch
  0007-journald-also-check-journal-file-size-to-deduce-if-i.patch
  0008-journald-fix-memory-leak-on-error-path.patch
  0009-units-make-systemd-journald.service-Type-notify.patch
  0010-hwdb-Update-database-of-Bluetooth-company-identifier.patch
* Mon Nov 10 2014 werner@suse.de
- Add upstream patches
  1092-libudev-do-not-accept-invalid-log-levels.patch
  1093-udev-Fix-parsing-of-udev.event-timeout-kernel-parame.patch
  1094-udev-avoid-magic-constants-in-kernel-cmdline-parsers.patch
* Fri Nov  7 2014 werner@suse.de
- Add patch watch_resolv.conf_for_become_changed.patch to add an
  inotify watch on /etc/resolv.conf which enables the reload of
  a changed resolver configuration on the fly (bsc#902901)
- Do not apply patch 0022-systemd-tmpfiles-ownerkeep.patch in case
  if the script /usr/bin/systemd-tmpfiles-keep is missed
* Mon Nov  3 2014 werner@suse.de
- Add upstream patches
  0001-sd-bus-properly-handle-removals-of-non-existing-matc.patch
  0002-keymap-Ignore-brightness-keys-on-Dell-Inspiron-1520-.patch
* Mon Nov  3 2014 werner@suse.de
- Add upstream patches
  1090-udev-path_id-set-supported_parent-for-well-known-SCS.patch
  1091-udev-path_id-update-comments.patch
  which will be applied if patch
  1090-udev-path_id-set-supported_parent-for-well-known-SCS.patch
  is applied a this may fix the trouble with iSCSI (bnc#898233)
* Thu Oct 30 2014 werner@suse.de
- Add upstream patches
  0001-manager-Linux-on-hppa-has-fewer-rtsigs-hence-avoid-u.patch
  0002-time-also-support-infinity-syntax-in-parse_nsec.patch
  0003-time-earlier-exit-from-format_timestamp_relative-on-.patch
  0004-sd-bus-if-we-don-t-manage-to-properly-allocate-the-e.patch
  0005-journalctl-correct-help-text-for-until.patch
  0006-calendarspec-fix-typo-in-annually.patch
  0007-systemctl-do-not-ignore-errors-in-symlink-removal.patch
  0008-util-introduce-sethostname_idempotent.patch
  0009-util-fix-copy-paste-error-and-actually-set-the-new-h.patch
  0010-shutdown-do-final-unmounting-only-if-not-running-ins.patch
  0011-selinux-make-sure-we-do-not-try-to-print-missing-fie.patch
- Replace patch
  keep-crypt-password-prompt.patch as this with
  upstream patch
  0012-manager-do-not-print-anything-while-passwords-are-be.patch
* Fri Oct 24 2014 werner@suse.de
- Add upstream patch
  0002-shutdown-pass-own-argv-to-run-initramfs-shutdown.patch
- Add patch journald-advice-about-use-of-memory.patch to use mmap()
  flags as well as madvise(2) for journal files.
* Thu Oct 23 2014 werner@suse.de
- Add upstream patches
  0001-strv-add-an-additional-overflow-check-when-enlarging.patch
  0002-hwdb-Add-mapping-for-special-keys-on-compaq-ku-0133-.patch
  0003-journald-add-CAP_MAC_OVERRIDE-in-journald-for-SMACK-.patch
  0004-journal-do-server_vacuum-for-sigusr1.patch
  0005-cryptsetup-fix-an-OOM-check.patch
* Wed Oct 22 2014 werner@suse.de
- Add upstream patch 1089-fix-cgroup-device-controller.patch
  to avoid trouble on existing /dev/console with nspawn (bsc#902240)
* Tue Oct 21 2014 werner@suse.de
- Modify patch avoid-leaking-socket-descriptors.patch to close
  file descriptors for incomming connections in pam module in case
  of short memory.
* Mon Oct 20 2014 werner@suse.de
- Add upstream patches
  0001-systemd-continue-switch-root-even-if-umount-fails.patch
  0002-systemd-try-harder-to-bind-to-notify-socket.patch
- Add patch avoid-leaking-socket-descriptors.patch to close
  file descriptors if an incomming connection can not be handled
  due e.g. short memory. Could be related to bsc #901481
* Wed Oct 15 2014 werner@suse.de
- Add upstream patches
  0001-shell-completion-fix-completion-of-inactive-units.patch
  0002-shell-completion-propose-templates-for-disable-re-en.patch
  0003-man-we-don-t-have-Wanted-dependency.patch
  0004-selinux-fix-potential-double-free-crash-in-child-pro.patch
* Wed Oct 15 2014 werner@suse.de
- Adapt patch
  rules-add-lid-switch-of-ARM-based-Chromebook-as-a-power-sw.patch
  to make it work even with patch #438 and #439
* Tue Oct 14 2014 werner@suse.de
- Add upstream patches
  0001-systemctl-when-mangle-unit-names-for-the-isolate-suf.patch
  0001-tmpfiles-compare-return-against-correct-errno.patch
* Tue Oct 14 2014 werner@suse.de
- Add upstream patches
  0001-keymap-Fix-touchpad-toggle-on-Toshiba-Satellite-P75-.patch
  0001-units-introduce-network-pre.target-as-place-to-hook-.patch
  0002-keymap-Fix-touchpad-toggle-key-on-Asus-laptops.patch
  0003-sd-bus-check-return-value-of-vasprintf.patch
  0004-core-map-the-rescue-argument-to-rescue.target.patch
  0005-util-avoid-double-close-of-fd.patch
* Tue Oct 14 2014 werner@suse.de
- Add upstream patches
  0001-virt-detect-that-we-are-running-inside-the-docker-co.patch
  0002-bootchart-use-n-a-if-PRETTY_NAME-is-not-found.patch
  0003-fileio-label-return-error-when-writing-fails.patch
  0001-sd-event-don-t-require-a-signal-event-source-to-be-e.patch
  0004-sd-event-check-the-value-of-received-signal.patch
  0005-sd-id128-do-stricter-checking-of-random-boot-id.patch
* Tue Oct 14 2014 werner@suse.de
- Add upstream patches
  0001-core-swap-only-make-configured-units-part-of-swap.ta.patch
  0009-hwdb-Update-database-of-Bluetooth-company-identifier.patch
* Tue Oct 14 2014 werner@suse.de
- Add upstream patches
  0001-journalctl-do-not-output-reboot-markers-when-running.patch
  0002-udev-hwdb-New-Entry-for-Dell-XPS12-9Q33-keyboard.patch
* Tue Oct 14 2014 werner@suse.de
- Add upstream patches
  0001-logind-add-support-for-Triton2-Power-Button.patch
  0002-logind-add-support-for-TPS65217-Power-Button.patch
- Add upstream patches
  0001-shutdownd-clean-up-initialization-of-struct.patch
  0003-bootchart-parse-userinput-with-safe_atoi.patch
  0004-bootchart-check-return-of-strftime.patch
  0005-bootchart-Do-not-try-to-access-data-for-non-existing.patch
* Thu Oct  2 2014 lduncan@suse.com
- Revert patch 1063, which incorrectly disallows
  /dev/disk/by-path links for iSCSI (and other)
  devices. Will be corrected and re-added once
  upstream is consulted. (bnc#898233).  Disable:
  1063-udev-path_id-suppress-ID_PATH-for-devices-with-an-un.patc
* Fri Sep 26 2014 werner@suse.de
- Add upstream patch
  0001-systemd-tmpfiles-Fix-IGNORE_DIRECTORY_PATH-age-handl.patch
  for bsc#893797
* Fri Sep 26 2014 rmilasan@suse.com
- Drop renaming virtual interfaces in a guest (bnc#898432).
  Add 1088-drop-renaming-of-virtual-interfaces-in-guest.patch
* Thu Sep 25 2014 werner@suse.de
- Rename patch 0001-infinit-timeout-for-kmod-loaded-modules.patch
  to patch 1087-infinit-timeout-for-kmod-loaded-modules.patch
  and apply this one
* Thu Sep 25 2014 werner@suse.de
- Change patch
  0003-mount-order-options-before-other-arguments-to-mount.patch
  to fix bsc#898240
* Thu Sep 25 2014 werner@suse.de
- Add upstream patches
  0001-Fix-warning-about-unused-variable-with-SELINUX.patch
  0002-bus-remove-unused-check.patch
* Wed Sep 24 2014 werner@suse.de
- Add patch 0001-infinit-timeout-for-kmod-loaded-modules.patch to
  be able to avoid killing a running kmod/modprobe (bnc#889297)
* Wed Sep 24 2014 werner@suse.de
- Update patch 0001-bnc888612-logind-polkit-acpi.patch
* Wed Sep 24 2014 werner@suse.de
- Add upstream patches
  0001-login-pause-devices-before-acknowledging-VT-switches.patch
  May help that history of the shell is saved
  0001-nspawn-don-t-try-to-create-veth-link-with-too-long-i.patch
  0001-socket-introduce-SELinuxContextFromNet-option.patch (bsc#897801)
  0002-util-avoid-non-portable-__WORDSIZE.patch
* Fri Sep 19 2014 werner@suse.de
- Add patch 0001-bnc888612-logind-polkit-acpi.patch from Frederic
  to solve bnc#888612 - AUDIT-0: Power button press at gdm login
  should not prompt for credentials
* Fri Sep 19 2014 werner@suse.de
- Add upstream bugfix patches
  0001-journal-Do-not-count-on-the-compiler-initializing-fo.patch
  0002-include-fcntl.h-rather-than-sys-fcntl.h.patch
  0003-mount-order-options-before-other-arguments-to-mount.patch
  0004-shared-wtmp-utmp-don-t-clear-store_wtmp-in-utmp_put_.patch
  0005-shared-label.h-add-missing-stdio.h-include.patch
  0006-shared-sparse-endian.h-add-missing-byteswap.h-includ.patch
  0007-libudev-monitor-warn-if-we-fail-to-request-SO_PASSCR.patch
  0008-shared-conf-parser-don-t-leak-memory-on-error-in-DEF.patch
  1080-udevd-parse_argv-warn-if-argumens-are-invalid.patch
  1081-udevd-check-return-of-various-functions.patch
  1082-udevadm-hwdb-check-return-value-of-fseeko.patch
  1083-udev-node-warn-if-chmod-chown-fails.patch
  1084-udev-ctrl-log-if-setting-SO_PASSCRED-fails.patch
  1085-udev-fix-typos.patch
  1086-udevd-don-t-fail-if-run-udev-exists.patch
* Thu Sep 18 2014 werner@suse.de
- Add upstream bugfix patches
  0001-core-fix-resource-leak-in-manager_environment_add.patch
  0002-util-remove-a-unnecessary-check.patch
  0003-udev-event-explicitly-don-t-read-from-invalid-fd.patch
  0004-shared-conf-parser.patch
  0005-logind-fix-typo.patch
  0006-systemctl-fix-resource-leak-CID-1237747.patch
  0007-libudev-monitor-warn-if-we-fail-to-request-SO_PASSCR.patch
  0008-shared-conf-parser-don-t-leak-memory-on-error-in-DEF.patc
  0009-bus-fix-bus_print_property-to-use-int-for-booleans.patch
- Remove 0001-sizeof-bool-used-by-gcc-depends-on-arch.patch as
  0009-bus-fix-bus_print_property-to-use-int-for-booleans.patch
  is the upstream solution
* Wed Sep 17 2014 werner@suse.de
- Add patch 0001-sizeof-bool-used-by-gcc-depends-on-arch.patch to
  fix for the size of the gcc builtin type bool also known as _Bool
  from the include header stdbool.h.
* Tue Sep 16 2014 werner@suse.de
- Add upstream patches as real fixes
  0001-activate-fix-fd-leak-in-do_accept.patch
  0002-analyze-avoid-a-null-dereference.patch
  0003-analyze-fix-mem-leak.patch
  0004-backlight-Avoid-error-when-state-restore-is-disabled.patch
  0005-bus-avoid-using-m-kdbus-after-freeing-it.patch
  0006-bus-unref-buscreds-on-failure.patch
  0007-core-fix-a-potential-mem-leak.patch
  0008-core-smack-setup-Actually-allow-for-succesfully-load.patch
  0009-journal-do-not-leak-mmaps-on-OOM.patch
  0010-manager-use-correct-cleanup-function.patch
- Intergrate the work of Robert and rename the patch
  1068-udev-remove-userspace-firmware-loading-support.patch
  to 1078-udev-remove-userspace-firmware-loading-support.patch
  Also add patch
  1079-udev-remove-userspace-firmware-loading-support.patch
  to apply the same change for opensuse 13.2 and above
* Tue Sep 16 2014 werner@suse.de
- Add upstream patch
  0001-systemctl-allow-to-change-the-default-target-without.patch
  to allow to override default target without --force (bnc#896664)
* Tue Sep 16 2014 werner@suse.de
- Add upstream patches for udev
  1068-udev-net_setup_link-export-the-.link-filename-applie.patch
  1069-rules-net-setup-link-preserve-ID_NET_LINK_FILE-and-I.patch
  1070-rules-net-setup-link-remove-stray-linebreak.patch
  1071-udev-import-the-full-db-on-MOVE-events-for-devices-w.patch
  1072-udev-netif_rename-don-t-log-to-kmsg.patch
  1073-udev-drop-print_kmsg.patch
  1074-udev-fix-copy-paste-error-in-log-message.patch
  1075-udev-timeout-increase-timeout.patch (bnc#889297)
  1076-udev-timeout-warn-after-a-third-of-the-timeout-befor.patch (bnc#889297)
  1077-udev-timeout-warn-after-a-third-of-the-timeout-befor.patch (bnc#889297)
* Tue Sep 16 2014 rmilasan@suse.com
- udev: remove userspace firmware loading support (bnc#889297).
  Add 1068-udev-remove-userspace-firmware-loading-support.patch
* Sat Sep 13 2014 rmilasan@suse.com
- udev: always resolve correctly database names on 'change' event (bnc#864745).
  Add 1067-udev-always-resolve-correctly-database-names-on-chan.patch
* Tue Sep  9 2014 werner@suse.de
- Add upstream patch 0009-hwdb-update.patch
* Mon Sep  8 2014 werner@suse.de
- Add upstream patches
  0001-initrd-parse-etc.service-ignore-return-code-of-daemo.patch
  0008-hwdb-Update-database-of-Bluetooth-company-identifier.patch
* Thu Sep  4 2014 werner@suse.de
- Disable patch
  module-load-handle-SUSE-etc-sysconfig-kernel-module-list.patch
  for SLES-12 as well as for openSUSE-13.2 (bnc#895087)
* Tue Sep  2 2014 rmilasan@suse.com
- udev: add option to generate old 'buggy' serials (bnc#886852)
  Add 1066-udev-add-compatibility-links-for-truncated-by-id-links.patch
* Tue Sep  2 2014 werner@suse.de
- Add upstream patch
  0001-login-simplify-controller-handling.patch
* Mon Sep  1 2014 werner@suse.de
- Add upstream patches
  0001-completion-filter-templates-from-restartable-units.patch
  0002-systemd-fix-error-message.patch
  0003-Quote-unit-names-in-suggested-systemctl-commandlines.patch
  0004-config-parser-fix-mem-leak.patch
  0005-login-fix-mem-leak.patch
  1065-udev-bump-event-timeout-to-60-seconds.patch
* Fri Aug 29 2014 werner@suse.de
- Add upstream patch 0001-nspawn-fix-network-interface.patch to
  make option network-interface of systemd-nspawn work
* Thu Aug 28 2014 werner@suse.de
- Add upstream patches
  0001-login-fix-memory-leak-on-DropController.patch
  0002-util-fix-minimal-race-where-we-might-miss-SIGTERMs-w.patch
  0003-sd-journal-properly-convert-object-size-on-big-endia.patch
  0004-sd-journal-verify-that-object-start-with-the-field-n.patch
- Add upstream patch
  1064-udev-hwdb-do-not-look-at-usb_device-parents.patch
  to avoid that hwdb ID's for unrecognised USB device are taken
  from the USB hub.
* Wed Aug 27 2014 werner@suse.de
- Add upstream patches
  0001-systemctl-Correct-error-message-printed-when-bus_pro.patch
  0002-units-order-systemd-fsck-.service-after-local-fs-pre.patch
  0003-keymap-Adjust-for-more-Samsung-900X4-series.patch
* Wed Aug 27 2014 werner@suse.de
- Add patch use-rndaddentropy-ioctl-to-load-random-seed.patch to
  use RNDADDENTROPY ioctl to load random-seed and to increase
  entropy count as well (bnc#892096)
* Tue Aug 26 2014 werner@suse.de
- Add upstream patches for hwdb
  0001-hwdb-keymaps-for-Samsung-900X3E-900X3F.patch
  0002-Add-hwdb-entry-for-Samsung-Series-7-Ultra.patch
  0003-keymap-Fix-HP-Pavillon-DV7.patch
  0004-hwdb-update-format-description-and-document-reloadin.patch
  0008-hwdb-update.patch
* Tue Aug 26 2014 werner@suse.de
- Port back and add the missed upstream patches from 2014/08/22
  0004-login-set_controller-should-fail-if-prepare_vt-fails.patch
  0006-login-share-VT-signal-handler-between-sessions.patch
* Fri Aug 22 2014 werner@suse.de
- Add upstream patches
  0001-nspawn-fix-truncation-of-machine-names-in-interface-.patch
  0002-switch-root-umount-the-old-root-correctly.patch
  0003-bootchart-it-s-not-OK-to-return-1-from-a-main-progra.patch
  0005-sd-resolve-fix-allocation-if-query-ids-never-reuse-t.patch
  0007-journald-also-increase-the-SendBuffer-of-dev-log-to-.patch
  0008-mount-setup-fix-counting-of-early-mounts-without-SMA.patch
  0009-journald-Fix-off-by-one-error-in-Missed-X-kernel-mes.patch
  0010-machine_kill-Don-t-kill-the-unit-when-killing-the-le.patch
  0011-units-fix-BindsTo-logic-when-applied-relative-to-ser.patch
  0012-util-try-to-be-a-bit-more-NFS-compatible-when-checki.patch
  1063-udev-path_id-suppress-ID_PATH-for-devices-with-an-un.patch
* Fri Aug 22 2014 crrodriguez@opensuse.org
- man pages from section 3 are developer docs, move them to
  the -devel package.
* Wed Aug 20 2014 werner@suse.de
- Add patch 0001-let-systemctl-completion-ignore-at-names.patch to
  remove error messages for tab completion for systemctl isolate (bnc#892162)
* Mon Aug 18 2014 werner@suse.de
- Disable the usage of the systemd groups wheel and adm (bnc#892300)
* Fri Aug  8 2014 rmilasan@suse.com
- Set default permissions for GenWQE device nodes to 0666 (bnc#890977).
  Add 1062-rules-set-default-permissions-for-GenWQE-devices.patch
* Fri Aug  1 2014 werner@suse.de
- Add upstream patches
  0007-hwdb-update.patch
  1061-rules-allow-systemd-to-manage-loop-device-partitions.patch
* Thu Jul 31 2014 rmilasan@suse.com
- Rename:
  udev-use-device-mapper-target-name-for-btrfs-device-ready.patch
  to
  1060-udev-use-device-mapper-target-name-for-btrfs-device-ready.patch
* Wed Jul 30 2014 jeffm@suse.com
- udev: use device mapper target name for btrfs device ready (bnc#888215).
- Add udev-use-device-mapper-target-name-for-btrfs-device-ready.patch
* Wed Jul 30 2014 werner@suse.de
- Add patch tomcat6-var-lock-subsys-legacy.patch to add the
  compatibility directory /var/lock/subsys (bnc#889357)
* Wed Jul 30 2014 werner@suse.de
- Add portabiltiy patch
  1055-let-9719859c07aa13539ed2cd4b31972cd30f678543-apply.patch
* Wed Jul 30 2014 werner@suse.de
- Port and add upstream patch
  0001-sysv-order-initscripts-which-provide-network-before-.patch
  0002-keymap-Add-microphone-mute-keymap-for-Dell-Latitude.patch
  0003-keymap-Annotate-all-micmute-workarounds.patch
* Wed Jul 30 2014 werner@suse.de
- Add patch tty-ask-password-agent-on-console.patch that is for system
  console do ask passphrases on all devices of the console (bnc#886211)
* Wed Jul 30 2014 werner@suse.de
- Add former SUSE and/now upstream patches (bnc#889297)
  1056-udevd-add-event-timeout-commandline-option.patch
  1057-udev-unify-event-timeout-handling.patch
  1058-udev-unify-event-timeout-handling.patch (backport for
  compatibility if patch 1022 is not applied)
  1059-udev-fixup-commit-dd5eddd28a74a49607a8fffcaf960040db.patch
* Mon Jul 28 2014 werner@suse.de
- Add patch shut-up-rpmlint-on-var-log-journal.patch to avoid
  rpmlink warning
- Add upstream patches
  0001-bus-proxyd-fix-incorrect-comparison.patch
  0002-shell-completion-prevent-mangling-unit-names.patch
  0003-Always-check-asprintf-return-code.patch
  0004-bash-completion-use-list-unit-files-to-get-all-units.patch
  0005-core-only-set-the-kernel-s-timezone-when-the-RTC-run.patch
  0006-parse_boolean-require-exact-matches.patch
  0007-drop_duplicates-copy-full-BindMount-struct.patch
  0008-shell-completion-prevent-mangling-unit-names-bash.patch
  0009-journald-always-add-syslog-facility-for-messages-com.patch
* Fri Jul 25 2014 werner@suse.de
- Disable blkrrpart for SLES12 and below
* Fri Jul 25 2014 werner@suse.de
- Add upstream patch
  1054-udev-exclude-MD-from-block-device-ownership-event-lo.patch
- Add with condition blkrrpart to be able to disable the patches
  1025, 1027, 1029, 1030, 1031, 1032, 1033, 1034, 1037, and 1054
  which uses the BLKRRPART ioctl for e.g. synthesize change events
  which may interfere with other tools like parted.
* Thu Jul 24 2014 fcrozat@suse.com
- Update
  handle-disable_caplock-and-compose_table-and-kbd_rate.patch,
  handle-numlock-value-in-etc-sysconfig-keyboard.patch: read
  /etc/vconsole.conf after /etc/sysconfig/(keyboard,console)
  otherwise empty value in /etc/sysconfig/keyboard might override
  /etc/vconsole.conf values.
- Update :
  0001-journal-compress-return-early-in-uncompress_startswi.patch
  0002-util-don-t-consider-tabs-special-in-string_has_cc-an.patch
  0002-vconsole-setup-run-setfont-before-loadkeys.patch
  0003-core-never-consider-failure-when-reading-drop-ins-fa.patch
  0003-fsck-consider-a-fsck-implementation-linked-to-bin-tr.patch
  apply-ACL-for-nvidia-device-nodes.patch
  keep-crypt-password-prompt.patch
  log-target-null-instead-kmsg.patch
  parse-crypttab-for-noauto-option.patch
  set-and-use-default-logconsole.patch: fix all warnings in code
- Remove 0001-compress-fix-return-value.patch: not relevant to
  systemd v210 code.
* Thu Jul 24 2014 werner@suse.de
- Also change udev-generate-peristent-rule to udev-generate-persistent-rule
  in file list
* Thu Jul 24 2014 rmilasan@suse.com
- Rename (fix typo in script name):
  udev-generate-peristent-rule.sh to udev-generate-persistent-rule.sh
* Wed Jul 23 2014 rmilasan@suse.com
- Enable better checks in write_net_rules to skip adding duplicated
  entries in the generate rules (bnc#888178).
  Add 1053-better-checks-in-write_net_rules.patch
* Wed Jul 23 2014 werner@suse.de
- Change patch set-and-use-default-logconsole.patch to avoid to
  write security/authorization (private) messages to console
* Tue Jul 22 2014 werner@suse.de
- Add patch set-and-use-default-logconsole.patch to use and set
  the default logging console for both journald and kernel messages
* Mon Jul 21 2014 werner@suse.de
- Add upstream patches
  0001-bash-completion-p-option-for-journalctl.patch
  0002-journalctl-man-allow-only-between-terms.patch
  0003-systemd-use-pager-for-test-and-help.patch
* Mon Jul 21 2014 werner@suse.de
- Use verify scripts and add permission files for systemd logger
- Avoid useless warning about static systemd unit files
- Make pam file a config file
- Remove non-break-space from this changelog
* Mon Jul 21 2014 werner@suse.de
- Add upstream patches
  0001-compress-fix-return-value.patch
  0002-Be-more-verbose-when-bind-or-listen-fails.patch
  0003-Add-quotes-to-warning-message.patch
  0004-systemd-return-the-first-error-from-manager_startup.patch
* Mon Jul 21 2014 werner@suse.de
- Replace patch 0001-fix-only-discover-Xen-domU.patch with
  upstream patch 0001-detect-virt-Fix-Xen-domU-discovery.patch
- Replace patch 0001-detect-s390-virt.patch with upstream
  patch 0001-systemd-detect-virt-detect-s390-virtualization.patch
* Thu Jul 17 2014 werner@suse.de
- Add upstream patches
  0001-po-add-Ukrainian-translation.patch
  0002-man-document-yearly-and-annually-in-systemd.time-7.patch
  0003-core-nicer-message-when-inotify-watches-are-exhauste.patch
- Add patch 0001-fix-only-discover-Xen-domU.patch to fix upstream
  patch 0004-systemd-detect-virt-only-discover-Xen-domU.patch
* Thu Jul 17 2014 rmilasan@suse.com
- Check if NAME key has a value before going thru the rule (bnc#885232).
  Add 1051-check-if-NAME-has-a-value.patch
* Wed Jul 16 2014 werner@suse.de
- Add upstream patches
  0001-Clear-up-confusion-wrt.-ENTRY_SIZE_MAX-and-DATA_SIZE.patch
  0002-units-serial-getty-.service-use-the-default-RestartS.patch
  1052-rules-uaccess-add-ID_SOFTWARE_RADIO.patch
* Tue Jul 15 2014 rmilasan@suse.com
- Only rename SRIOV-VF devices if device name start with eth (bnc#885232).
  Add 1050-only-rename-SRIOV-VF-devices-when-name-starts-with-eth.patch
* Tue Jul 15 2014 werner@suse.de
- Add patch vhangup-on-all-consoles.patch that is do a vhangup on
  lines (bnc#886599)
* Tue Jul 15 2014 jlee@suse.com
- Removed %%{_libexecdir}/modules-load.d/efivars.conf because the kernel
  patch of autoload efivars driver accepted by linux-efi upstream.
  (bnc#881559)
  https://git.kernel.org/cgit/linux/kernel/git/mfleming/efi.git/commit/?h=next&id=be756a5327fe3d4686d74d3e9b273010424e230c
* Mon Jul 14 2014 werner@suse.de
- Update patch
  1007-physical-hotplug-cpu-and-memory.patch (bnc#869603)
- Add script systemd-remount-tmpfs (bnc#869603) as helper script
  for the rule changed in patch 1007-physical-hotplug-cpu-and-memory.patch
* Mon Jul 14 2014 werner@suse.de
- Add upstream patch
  0001-event-pull-in-sd-event.h-from-event-util.h.patch
  0002-util-fix-has-cc-check-and-add-test.patch
  0003-sd-event-always-call-epoll_ctl-on-mask-updates-if-ed.patch
  0004-fileio-quote-more-shell-characters-in-envfiles.patch
* Fri Jul 11 2014 werner@suse.de
- Only on SLES12 seccomp is available on ppc64 and s390x
* Thu Jul 10 2014 werner@suse.de
- Port and add upstream patch
  0001-units-make-ExecStopPost-action-part-of-ExecStart.patch
* Wed Jul  9 2014 werner@suse.de
- Add patches
  0001-logind-allow-switching-to-unused-VTs-via-SwitchTo.patch
  0002-hostnamed-add-a-new-chassis-type-for-watches.patch
- Port and add upstream patches
  0001-journal-compress-return-early-in-uncompress_startswi.patch
  0002-journal-compress-improve-xz-compression-performance.patch
* Wed Jul  9 2014 meissner@suse.com
- enable seccomp also for ppc64 and s390x
* Tue Jul  8 2014 werner@suse.de
- Port and add upstream patches
  0001-util-consider-0x7F-a-control-chracter-which-it-is-DE.patch
  0002-util-don-t-consider-tabs-special-in-string_has_cc-an.patch
  0003-architecture-add-string-table-entries-for-mips-le-ar.patch
  0004-core-Added-support-for-ERRNO-NOTIFY_SOCKET-message-p.patch
  0005-service-don-t-accept-negative-ERRNO-notification-mes.patch
  0006-systemctl-show-StatusErrno-value-in-systemctl-status.patch
  0007-service-flush-status-text-and-errno-values-each-time.patch
* Tue Jul  8 2014 werner@suse.de
- Add upstream patch
  1049-udev-link_config-ignore-errors-due-to-missing-MAC-ad.patch
* Mon Jul  7 2014 werner@suse.de
- Add upstream patch
  0001-machine-don-t-return-uninitialized-variable.patch
- Port and add upstream patch
  0002-vconsole-setup-run-setfont-before-loadkeys.patch
* Mon Jul  7 2014 rmilasan@suse.com
- Rename
  0001-udev-net_setup_link-add-a-bit-more-logging.patch
  to
  1048-udev-net_setup_link-add-a-bit-more-logging.patch
* Fri Jul  4 2014 werner@suse.de
- Port and add upstream patches
  0001-udev-net_setup_link-add-a-bit-more-logging.patch
  0003-namespace-make-sure-tmp-var-tmp-and-dev-are-writable.patch
  0002-namespace-fix-uninitialized-memory-access.patch
* Fri Jul  4 2014 werner@suse.de
- Add upstream patches
  0001-architecture-Add-tilegx.patch
  0002-architecture-Add-cris.patch
  0003-arch-add-crisv32-to-uname-check.patch
  0004-architecture-remove-cris-from-uname-list.patch
* Fri Jul  4 2014 werner@suse.de
- Add upstream patches
  0006-hwdb-update.patch
  0007-hwdb-Update-database-of-Bluetooth-company-identifier.patch
* Thu Jul  3 2014 werner@suse.de
- Add upstream patches
  0001-parse_uid-return-ENXIO-for-1-uids.patch
  0002-util-when-unescaping-strings-don-t-allow-smuggling-i.patch
  0003-localed-consider-an-unset-model-as-a-wildcard.patch
  0004-sd-bus-when-an-event-loop-terminates-explicitly-clos.patch
  0005-bus-close-a-bus-that-failed-to-connect.patch
  1047-udev-net_setup_link-builtin-should-print-the-reason-.patch
* Wed Jul  2 2014 rmilasan@suse.com
- Fix duplicated rules when having layer3 interfaces (bnc#882714).
  Add 1046-fix-duplicated-rules-with-layer3-interfaces.patch
* Tue Jul  1 2014 werner@suse.de
- Require correct pam-config version overall even for scriptlets (bnc#885288)
* Tue Jul  1 2014 werner@suse.de
- Add upstream patches
  0001-main-uid_to_name-might-fail-due-to-OOM-protect-again.patch
  0002-journald-make-MaxFileSec-really-default-to-1month.patch
  0003-units-remove-RefuseManualStart-from-units-which-are-.patch
  0004-util-refuse-considering-UID-0xFFFF-and-0xFFFFFFFF-va.patch
  0005-nspawn-block-open_by_handle_at-and-others-via-seccom.patch
  0006-tmpfiles-don-t-do-automatic-cleanup-in-XDG_RUNTIME_D.patch
  0007-units-skip-mounting-tmp-if-it-is-a-symlink.patch
* Tue Jul  1 2014 werner@suse.de
- Be aware that close_nointr_nofail() may fail whereas safe_close() not
* Tue Jul  1 2014 werner@suse.de
- Add upstream patches
  1042-libudev-queue-provide-file-descriptor-to-watch-busy-.patch
  1043-libudev-queue-watch-entire-directory-to-allow-the-re.patch
  1044-rules-update-qemu-hid-rules.patch
  1045-rules-don-t-enable-usb-pm-for-Avocent-devices.patch
* Fri Jun 27 2014 werner@suse.de
- Add upstream bug fix patch
  1041-libudev-fix-udev_queue_get_queue_is_empty-logic.patch (bnc#882714)
* Fri Jun 27 2014 werner@suse.de
- Update of patch 0001-detect-s390-virt.patch (bnc#880438)
* Thu Jun 26 2014 werner@suse.de
- Shut up stupid check scripts crying for not mentioned systemd-mini-rpmlintrc
* Thu Jun 26 2014 werner@suse.de
- Add upstream patchs
  0001-core-use-correct-format-string-for-UIDs.patch
  0002-core-transaction-fix-cycle-break-attempts-outside-tr.patch
  0003-fsck-consider-a-fsck-implementation-linked-to-bin-tr.patch
* Thu Jun 26 2014 werner@suse.de
- Add upstream patch
  0001-units-order-network-online.target-after-network.targ.patch
  to make sure that etwork-online.target follows network.target
* Wed Jun 25 2014 rmilasan@suse.com
- rules: re-enable dev_id conditionally in persistent rules
  (bnc#884403 and bnc#882714).
  Add 1040-re-enable-dev_id-conditionally-in-persistent-rules.patch
* Wed Jun 25 2014 werner@suse.de
- Add upstream patches
  0001-vconsole-also-copy-character-maps-not-just-fonts-fro.patch
  0002-core-make-sure-Environment-fields-passed-in-for-tran.patch
  0003-core-You-can-not-put-the-cached-result-of-use_smack-.patch
  0004-cryptsetup-don-t-add-unit-dependency-on-dev-null-dev.patch
  0005-man-fix-path-in-crypttab-5.patch
* Wed Jun 25 2014 werner@suse.de
- Add upstream patch
  1039-udevadm-settle-fixed-return-code-for-empty-queue.patch it
  fixes udevadm settle exit code which may had broken dracut scripts
  (bnc#884271 comment#18)
* Wed Jun 25 2014 werner@suse.de
- Temporary disable patch 1022 (bnc#884271 and bnc#882714).
* Tue Jun 24 2014 rmilasan@suse.com
- Rename 0002-udev-fix-invalid-free-in-enable_name_policy.patch
  to 1038-udev-fix-invalid-free-in-enable_name_policy.patch
* Tue Jun 24 2014 werner@suse.de
- Replace patches
  0001-systemd-empty-sigmask-on-reexec.patch with
  upstream 0008-Reset-signal-mask-on-re-exec-to-init.patch
  ensure-sysctl-are-applied-after-modules-are-loaded.patch with
  upstream 0001-units-systemd-sysctl.service.in-run-after-load-modul.patch
  getty-generator-with-serial-3270-tty.patch with
  upstream 0004-getty-generator-properly-escape-instance-names.patch
- Add upstream patches
  0002-units-add-missing-caps-so-that-GetAddresses-can-work.patch
  0003-units-order-systemd-tmpfiles-clean.service-after-tim.patch
  0005-po-add-Greek-translation.patch
  0006-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  0007-po-add-German-translation.patch
  0009-core-clean-up-signal-reset-logic-when-reexec.patch
  0010-util-treat-fuse.sshfs-as-a-network-filesystem.patch
  0011-build-sys-add-pthread-flag-for-libsystemd-shared.patch
  0012-core-transaction-avoid-misleading-error-message-when.patch
* Tue Jun 24 2014 werner@suse.de
- Invert of the boolean for locking scheme of fsck (bnc#881125)
- Remove the ghost entry /etc/hostname and require the netcfg
* Mon Jun 23 2014 arvidjaar@gmail.com
- make sure legacy services that depend on network are started after
  network is available (bnc#883565)
  * 0001-core-sysvcompat-network-should-be-equivalent-to-netw.patch
  * update insserv-generator.patch to translate $network into
    network-online.target
* Wed Jun 18 2014 werner@suse.de
- Add patch 0001-detect-s390-virt.patch from Thomas Blume (bnc#880438)
  to detect the virtualization layers on s390x as well
* Wed Jun 18 2014 werner@suse.de
- Do not generate synthesize change for cd/dvd (bnc#882714, comment #51)
  add patch 1037-udev-exclude-cd-dvd-from-block-device.patch from
  Roberts suggestion as well as readd
  1022-udev-remove-seqnum-API-and-all-assumptions-about-seq.patch
* Tue Jun 17 2014 werner@suse.de
- Add upstream patches
  0001-core-fix-invalid-free-in-killall.patch
  0002-udev-fix-invalid-free-in-enable_name_policy.patch
  0003-install-fix-invalid-free-in-unit_file_mask.patch
* Tue Jun 17 2014 rmilasan@suse.com
- rules: disable usage of dev_id in persistent rules (bnc#882714).
  add: 1036-rules-disable-usage-of-dev_id-in-persistent-rules.patch
- Disable patch (bnc#882714).
  1022-udev-remove-seqnum-API-and-all-assumptions-about-seq.patch
* Thu Jun 12 2014 werner@suse.de
- Add patch
  1035-99-systemd.rules-Ignore-devices-with-SYSTEMD_READY-0.patch
  from Hannes Reinecke to avoid a race condition between variable
  'SYSTEMD_READY=0' and 'systemd' tag within udev rules (bnc#881942)
* Thu Jun 12 2014 werner@suse.de
- Add workaround for bnc#882393 by adding the systemd update utmp
  runlevel service to the wanted unit of e.g. the graphical target
- Add some later on created files to our file list
* Thu Jun 12 2014 jlee@suse.com
- Generate %%{_libexecdir}/modules-load.d/efivars.conf so we load efivars
  module at boot time not from udev (bnc#881559).
* Wed Jun 11 2014 crrodriguez@opensuse.org
- Do not build EFI support code in architectures on which
  the kernel does not support CONFIG_EFI, it won't work.
  (ia64 also supports it, but that's dead so is not included)
* Wed Jun 11 2014 werner@suse.de
- Add patch tmpfiles-do-not-clean-for-mandb-index-files.patch
  there is no need to clean out all 30 days the index data base
  files nor the cachedir tags of mandb.  Those files are used
  for whatis(1) as well as for apropos(1).
* Wed Jun 11 2014 werner@suse.de
- Do not override predictable names for openSUSE
* Wed Jun 11 2014 werner@suse.de
- Remove systemd-detect-xendom.patch as it becomes obsolete with
  upstream patch 0004-systemd-detect-virt-only-discover-Xen-domU.patch
- Add upstream patches
  0001-umount-modernizations.patch
  0002-namespace-when-setting-up-an-inaccessible-mount-poin.patch
  0003-core-allow-transient-mount-units.patch
  0004-systemd-detect-virt-only-discover-Xen-domU.patch
  0005-backlight-Do-not-clamp-brightness-for-LEDs.patch
  0006-log-honour-the-kernel-s-quiet-cmdline-argument.patch
* Tue Jun 10 2014 rmilasan@suse.com
- Add upstream patches
  1033-udev-really-exclude-device-mapper-from-block-device.patch
  1034-udev-check-the-return-value-from-udev_enumerate_scan.patch
* Tue Jun 10 2014 werner@suse.de
- Change detection of new locking scheme of fsck
* Tue Jun 10 2014 werner@suse.de
- Change 1021-udev-re-add-persistent-net-rules.patch to use persistent
  rules as a default on SLES-12 and predictable rules as a default
  otherwise
- Add cflags shell function to check possible flags for the compiler
  as well as for the linker
* Mon Jun  9 2014 rmilasan@suse.com
- Add upstream patches
  1025-udev-exclude-device-mapper-from-block-device-ownersh.patch
  1026-udevd-inotify-modernizations.patch
  1027-udev-synthesize-change-events-for-partitions-when-to.patch
  1028-udev-link-config-fix-mem-leak.patch
  1029-udev-try-first-re-reading-the-partition-table.patch
  1030-udev-guard-REREADP-logic-with-open-O_ECXL.patch
  1031-udev-make-sure-we-always-get-change-for-the-disk.patch
  1032-udev-guard-REREADPT-by-exclusive-lock-instead-of-O_E.patch
* Fri Jun  6 2014 werner@suse.de
- Add upstream patches
  0001-sd-event-restore-correct-timeout-behaviour.patch
  0002-bus-make-use-of-sd_bus_try_close-in-exit-on-idle-ser.patch
* Thu Jun  5 2014 werner@suse.de
- Add upstream patch 0001-hwdb-fix-case-sensitive-match.patch
* Thu Jun  5 2014 werner@suse.de
- Add dynamic detection of util-linux version to be able to
  disable the fsck option -l for version less than 2.25.0
* Thu Jun  5 2014 werner@suse.de
- Add changes from Cristian Rodríguez:
  * The patches
    delay-fsck-cryptsetup-after-md-dmraid-lvm-are-started.patch and
    ensure-DM-and-LVM-are-started-before-local-fs-pre-target.patch
    indeed mention unit files which do not exist anymore.
- Make sure that systemd-ask-password-wall.service has a tty as
  it is not sure that a tty1 exists
- Avoid broken firmware loading on newer distributions as 13.1
* Thu Jun  5 2014 werner@suse.de
- Correct version check for the tcp-devel drop
- Use correct permissions for /var/log/journal
- Use ACLs for /var/log/journal as described in man:systemd-journald.service(8)
* Thu Jun  5 2014 crrodriguez@opensuse.org
- Correct the libseccomp distribution version test must be >= 13.1
-  In order to use unit directive AppArmorProfile= libapparmor-devel
  must be present in buildRequires.
* Tue Jun  3 2014 sndirsch@suse.com
- apply-ACL-for-nvidia-uvm-device-node.patch: set ACL on nvidia-uvm
  device (bnc#879767).
* Tue Jun  3 2014 werner@suse.de
- Add changes from Cristian Rodríguez:
  * fix keep-crypt-password-prompt.patch which floods the system
    logs with bogus opendir failures, still the wrong thing to do however.
  * Use %%find_lang to collect locale files
  * systemd-no-libattr.patch: systemd does not require  libattr
    but just sys/xattr.h, therefore drop the dependency.
    (from upstream)
  * Again, drop tcp-devel from buildRequires, this time it is not a
    SUSE specific feature removal, tcpd supportdisappeared in systemd
    212 and we shouldn't keep it around.
- Add patch 0001-build-sys-use-glibc-s-xattr-support-instead-of-requi.patch
  that is rename systemd-no-libattr.patch to git format
- Drop tcp-devel only for *next* openSUSE and not for SLES-12 nor
  for openSUSE 13.1
* Tue Jun  3 2014 werner@suse.de
- Add upstream patches
  0001-virt-rework-container-detection-logic.patch
  0002-fsck-include-device-name-in-the-message-about-missin.patch
  0003-units-use-KillMode-mixed-for-systemd-nspawn-.service.patch
  0004-util-ignore_file-should-not-allow-files-ending-with.patch
  0006-tty-ask-password-agent-Do-tell-what-directory-we-fai.patch
- Add upstream patches to update keyboard data base
  0007-keyboard-add-Plantronics-.Audio-mute-button.patch
- Add upstream patches for udev
  1023-udev-builtin-keyboard-do-tell-on-which-device-EVIOCS.patch
  1024-udev-always-close-lock-file-descriptor.patch
* Tue Jun  3 2014 rmilasan@suse.com
- Fix enabling predictable rules when using net.ifnames=1.
  update: 1021-udev-re-add-persistent-net-rules.patch
* Fri May 30 2014 rmilasan@suse.com
- Re-add persistent rules as a default and make predictable rules as
  fallback (bnc#880732).
  add: 1021-udev-re-add-persistent-net-rules.patch
- udev: remove seqnum API and all assumptions about seqnums
  add: 1022-udev-remove-seqnum-API-and-all-assumptions-about-seq.patch
* Tue May 27 2014 werner@suse.de
- Add upstream patches
  0001-Do-not-unescape-unit-names-in-Install-section.patch
  0002-analyze-run-use-bus_open_transport_systemd-instead-o.patch
* Mon May 26 2014 werner@suse.de
- Add upstream patch
  1020-udev-keyboard-also-hook-into-change-events.patch
* Mon May 26 2014 werner@suse.de
- Add upstream patches to update keyboard data base
  0001-keymap-Add-Lenovo-Enhanced-USB-Keyboard.patch
  0002-keymap-Asus-EeePC-touchpad-toggle-key.patch
- Add upstream patches
  0001-nspawn-allow-to-bind-mount-journal-on-top-of-a-non-e.patch
  0002-nspawn-restore-journal-directory-is-empty-check.patch
  0003-core-never-consider-failure-when-reading-drop-ins-fa.patch
  0004-socket-properly-handle-if-our-service-vanished-durin.patch
* Wed May 21 2014 coolo@suse.com
- fix file list of systemd.pc
* Wed May 21 2014 werner@suse.de
- Add a workaround for old distributions like 13.1 to avoid
  deadlocks due NFS shares stopped after network
* Wed May 21 2014 werner@suse.de
- Add upstream patches
  0001-journal-cleanup-up-error-handling-in-update_catalog.patch
  0002-journal-properly-detect-language-specified-in-line.patch
  0003-man-mention-XDG_CONFIG_HOME-in-systemd.unit.patch
* Wed May 21 2014 werner@suse.de
- Add upstream patches to update usb and pci company identifiers
  0001-hwdb-update.patch
  0002-hwdb-update.patch
  0003-hwdb-PCI-include-primary-model-string-in-subsystem-m.patch
  0004-hwdb-update.patch
  0005-hwdb-update.patch
* Wed May 21 2014 werner@suse.de
- Move systemd.pc and udev.pc to their main packages (bnc#876587)
* Tue May 20 2014 werner@suse.de
- Add upstream patches
  0001-conf-parser-silently-ignore-sections-starting-with-X.patch
  0002-man-note-that-entire-sections-can-now-be-ignored.patch
  0004-machined-make-sure-GetMachineAddresses-is-available-.patch
  0005-core-Filter-by-state-behind-the-D-Bus-API-not-in-the.patch
  0006-login-add-mir-to-the-list-of-session-types.patch
  0007-logind-fix-Display-property-of-user-objects.patch
* Tue May 20 2014 werner@suse.de
- Add upstream patches to update BluTooth company identifiers
  0001-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  0002-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  0003-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  0004-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  0005-hwdb-Update-database-of-Bluetooth-company-identifier.patch
* Tue May 20 2014 werner@suse.de
- Add upstream patches to allow processes to serialize block device
  events, also do execute the RUN tag if rename of a network device
  fails:
  1016-udev-serialize-synchronize-block-device-event-handli.patch
  1017-udev-do-not-skip-the-execution-of-RUN-when-renaming-.patch
  1018-udev-avoid-use-of-uninitialized-err.patch
- Rename 0002-udev-warn-when-name_to_handle_at-is-not-implemented.patch
  to 1016-udev-warn-when-name_to_handle_at-is-not-implemented.patch
* Mon May 19 2014 werner@suse.de
- Add upstream patches mainly for better lid handling (bnc#878525
  and bnc#868019)
  0001-logind-ignore-lid-switch-if-more-than-1-display-is-c.patch
  0002-logind-fix-printf-format.patch
  0003-logind-ignore-lid-switch-events-for-30s-after-each-s.patch
  0004-logind-Do-not-fail-display-count-if-a-device-has-no-.patch
  0005-logind-move-lid-switch-handling-from-logind-main-to-.patch
  0006-man-clarify-that-the-ExecReload-command-should-be-sy.patch
  0007-man-readahead-fix-cmdline-switch-inconsistency-betwe.patch
  0008-man-update-journald-rate-limit-defaults.patch
  0009-nspawn-properly-format-container_uuid-in-UUID-format.patch
  0010-logind-allow-suspending-if-there-are-no-displays.patch
* Fri May 16 2014 werner@suse.de
- Make baselibs.conf aware to use the appropiate %%post and %%postun
  scriptlets which includes pam-config (bnc#877674)
* Fri May 16 2014 werner@suse.de
- Add upstream patches
  0001-core-close-socket-fds-asynchronously.patch
  0002-logind-bring-polkit-policy-for-hibernate-in-line-wit.patch
  0003-core-make-sure-to-serialize-jobs-for-all-units.patch
* Wed May 14 2014 werner@suse.de
- Add upstream patches
  0001-replace-more-dup-by-F_DUPFD_CLOEXEC.patch
  0002-pam_systemd-use-F_DUPFD_CLOEXEC-when-dupping-session.patch
  to avoid that in pam session unwanted file descriptors are inherited
* Tue May 13 2014 werner@suse.de
- Add patch log-target-null-instead-kmsg.patch from Thomas Blume
  to enable the kernel developers to see a clean kmsg ring buffer
  without any systemd/udev messages included (bnc#877021)
* Mon May 12 2014 werner@suse.de
- Add upstream patches for backlight
  0001-backlight-Avoid-restoring-brightness-to-an-unreadabl.patch
  0002-backlight-do-nothing-if-max_brightness-is-0.patch
  0003-backlight-unify-error-messages.patch
  0004-backlight-warn-if-kernel-exposes-backlight-device-wi.patch
  0005-backlight-handle-saved-brightness-exceeding-max-brig.patch
* Mon May 12 2014 werner@suse.de
- Add upstream patches
  0001-errno-make-sure-to-handle-the-3-errnos-that-are-alia.patch
  0002-udev-warn-when-name_to_handle_at-is-not-implemented.patch
  0003-analyze-fix-plot-with-bad-y-size.patch
  0004-job-add-waiting-jobs-to-run-queue-in-unit_coldplug.patch
  0005-job-always-add-waiting-jobs-to-run-queue-during-cold.patch
* Mon May 12 2014 rmilasan@suse.com
- Drop upstream-net_id-changes.patch and replace them with the correct
  patches from upstream and their commits:
  add: 1014-udev-update-net_id-comments.patch
  add: 1015-udev-persistent-naming-we-cannot-use-virtio-numbers-.patch
* Wed May  7 2014 werner@suse.de
- Add patch parse-crypttab-for-noauto-option.patch from Thomas Blume
  to handle the option 'noauto' in /etc/crypttab (bnc#742774)
* Wed May  7 2014 werner@suse.de
- Modify and extend patch
  0001-On_s390_con3270_disable_ANSI_colour_esc.patch
  to have the correct terminal type used with agetty
- Add patch 0001-tmpfiles-fix-permissions-on-new-journal-files.patch
  to allow users to access systemd user journal (bnc#876694)
* Mon May  5 2014 werner@suse.de
- Port upstream patch
  0001-sd-rtnl-message-append-fix-uninitialized-memory.patch
  back to 210
- Add patch keep-crypt-password-prompt.patch from Thomas Blume
  to fix bnc#875502 - fails to boot when swap space is encrypted
- Port upstream patch set for net_id back in patch
  upstream-net_id-changes.patch
* Fri May  2 2014 werner@suse.de
- Add patch shut-up-annoying-assertion-monotonic-clock-message.patch
  to avoid annyoing messages on failing dual_timestamp_is_set in the
  kernel's message ring buffer
* Wed Apr 30 2014 werner@suse.de
- Update udev-generate-peristent-rule.sh from latest git
* Wed Apr 30 2014 werner@suse.de
- Modify and extend patch
  0001-On_s390_con3270_disable_ANSI_colour_esc.patch
  to avoid also ANSI escape sequences for busy jobs on s390
* Mon Apr 28 2014 werner@suse.de
- Add or port upstream bugfix patches:
  0001-bash-completion-fix-__get_startable_units.patch
  0002-sysctl-replaces-some-slashes-with-dots.patch
  0003-delta-do-not-use-unicode-chars-in-C-locale.patch
  0004-implement-a-union-to-pad-out-file_handle.patch
- Add patch respect-nfs-bg-option.patch from Thomas Blume:
  System fails to boot if nfs mounts get added to fstab (bnc#874665)
* Wed Apr 23 2014 oneukum@suse.com
- Do not use runtime PM for some IBM consoles (bnc#868931)
  1013-no-runtime-PM-for-IBM-consoles.patch
* Thu Apr 17 2014 werner@suse.de
- Extend avoid-divide-by-zero-sigtrap.patch to make the crash
  handler know about SIGTRAP and SIGSYS
* Thu Apr 17 2014 werner@suse.de
- Add avoid-divide-by-zero-sigtrap.patch which fixes bnc#867663
  that is a divide by zero on a jobless system
* Wed Apr 16 2014 werner@suse.de
- Use latest regenerate-initrd rpm macros (fate#313506)
- Add rescue-emergency-target-conflicts.patch to avoid that
  emergency and rescue sulogin are fighting on console
* Tue Apr 15 2014 werner@suse.de
- Modify systemd-sleep-grub to let hybrid-sleep.target work even
  on XEN, changes from Thomas Blume (bnc#873432)
* Mon Apr 14 2014 werner@suse.de
- Add backported upstream patch
  0001-reduce-the-amount-of-messages-logged-to-dev-kmsg-whe.patch
- Add patch systemd-detect-xendom.patch from Thomas Blume
  to be able to detect XEN dom0 as well as domU
- systemd conflicts with sysvinit, ven if the package systemd-sysvinit
  does already conflict with sysvinit-init (bnc#873444)
* Thu Apr 10 2014 werner@suse.de
- Add two patches from hare@suse.com
  1011-64-btrfs.rules-skip-btrfs-check-if-devices-are-not-r.patch
  1012-Skip-persistent-device-link-creation-on-multipath-de.patch
  to solve bnc#872929
* Wed Apr  9 2014 rmilasan@suse.com
- Increase result size for programs stdout (bnc#867840).
  add: 1010-udev-increase-result-size-for-programs.patch
- Update udev-generate-peristent-rule.sh to the latest version.
- Clean-up spec file, re-arange patch to suit the setup, all udev
  patches start with 1XXX-*.{patch,diff}.
- Rename: 0013-cdrom_id-use-the-old-MMC-fallback.patch to
  1009-cdrom_id-use-the-old-MMC-fallback.patch
- Rename: 1009-make-xsltproc-use-correct-ROFF-links.patch to
  0009-make-xsltproc-use-correct-ROFF-links.patch
- Rename: 1010-do-not-install-sulogin-unit-with-poweroff.patch to
  0010-do-not-install-sulogin-unit-with-poweroff.patch
- Rename: 1014-journald-with-journaling-FS.patch to
  0014-journald-with-journaling-FS.patch
- Rename: 1018-Make-LSB-Skripts-know-about-Required-and-Should.patch to
  0018-Make-LSB-Skripts-know-about-Required-and-Should.patch
- Rename: 1019-make-completion-smart-to-be-able-to-redirect.patch to
  0019-make-completion-smart-to-be-able-to-redirect.patch
- Rename: 1022-systemd-tmpfiles-ownerkeep.patch to
  0022-systemd-tmpfiles-ownerkeep.patch
* Tue Apr  8 2014 werner@suse.de
- Add patch portmap-wants-rpcbind-socket.patch to make sure that
  rpcbind socket as well as service is up with the target
- Add or port upstream bugfix patches:
  0001-journal-fix-export-of-messages-containing-newlines.patch
  0002-systemctl-update-NAME-to-PATTERN-in-help.patch
  0003-tty-ask-password-agent-return-negative-errno.patch
  0004-systemd-python-use-.hex-instead-of-.get_hex.patch
  0005-systemd-python-fix-failing-assert.patch
* Fri Mar 28 2014 werner@suse.de
- Add or port upstream bugfix patches:
  0001-cgroup-it-s-not-OK-to-invoke-alloca-in-loops.patch
  0002-machined-fix-Kill-bus-call-on-machine-objects-when-w.patch
  0003-sd-bus-don-t-use-assert_return-to-check-for-disconne.patch
  0004-core-don-t-try-to-relabel-mounts-before-we-loaded-th.patch
  0005-sd-daemon-fix-incorrect-variable-access.patch
  0006-sd-event-initialization-perturbation-value-right-bef.patch
  0007-sd-event-don-t-accidentally-turn-of-watchdog-timer-e.patch
  0008-systemctl-kill-mode-is-long-long-gone-don-t-mention-.patch
  0009-ask-password-when-the-user-types-a-overly-long-passw.patch
- Modify patch
  1019-make-completion-smart-to-be-able-to-redirect.patch
  to work together with
  0008-systemctl-kill-mode-is-long-long-gone-don-t-mention-.patch
* Fri Mar 28 2014 werner@suse.de
- Use Robert's revised 1006-udev-always-rename-network.patch
* Tue Mar 25 2014 werner@suse.de
- Readd patch Forward-suspend-hibernate-calls-to-pm-utils.patch
  older code base as 13.1 only
- Add patch avoid-random-hangs-on-timeouts-due-lost-cwd.patch
  to be able to terminate the user manager even if cwd of the
  user is gone
* Tue Mar 25 2014 thomas.blume@suse.com
- add prepare-suspend-to-disk.patch
  enable suspend conditions check and preparation for systemd-sleep
  (fate#316824, bnc#856389, bnc#856392)
- remove Forward-suspend-hibernate-calls-to-pm-utils.patch since it is obsolete
  (bnc#856392#c20)
- add boot-local-start.patch
  fix startup for /etc/init.d/boot.local (bnc#869142)
* Mon Mar 24 2014 coolo@suse.com
- also autoreconf in systemd-mini to simplify spec file logic
  and fix build in staging:gcc49
  (obsoleting 0002-make-209-working-on-older-dist.patch)
* Wed Mar 19 2014 werner@suse.de
- Be sure that the refreshed manual pages are installed
* Wed Mar 19 2014 werner@suse.de
- Add patch systemctl-set-default-target.patch which explain how
  to override the default.target by using --force (bnc#868439)
* Tue Mar 18 2014 werner@suse.de
- Add Robert's udev-generate-peristent-rule shell script to
  udev's tool library
- Add or port upstream bugfix patches:
  0001-gpt-auto-generator-don-t-return-OOM-on-parentless-de.patch
  0002-bus-fix-memory-leak-when-kdbus-is-not-enabled.patch
  0006-Do-not-return-1-EINVAL-on-allocation-error.patch
  0007-networkd-fix-typo.patch
  0008-sd-bus-don-t-access-invalid-memory-if-a-signal-match.patch
  0009-sd-bus-don-t-choke-if-somebody-sends-us-a-message-wi.patch
  0012-journald-remove-stray-reset-of-error-return-value.patch
  0013-core-libsystemd-systemd-timedate-udev-spelling-fixes.patch
* Fri Mar 14 2014 werner@suse.de
- Add patch getty-generator-with-serial-3270-tty.patch to avoid
  harmless error messages on not existing getty@3270 files
* Fri Mar 14 2014 werner@suse.de
- Replace systemd-big-endian-reply-matching.patch with upstream
  0001-sd-bus-don-t-look-for-a-64bit-value-when-we-only-hav.patch
  to solve broken systemd communication with and over dbus (bnc#866732)
* Fri Mar 14 2014 werner@suse.de
- Readd patch 1008-add-msft-compability-rules.patch for
  older code base as 13.1
- Modify pre_checkin.sh to throw an error if a patch will be
  applied which modifies one of Makefile.am, Makefile.in, or
  configiure.ac as this breaks bootstrapping
- Add second version of make-209-working-on-older-dist.patch
  to be able to apply for bootstrapping version
* Thu Mar 13 2014 schwab@linux-m68k.org
- Don't require non-existing binutils-gold
* Thu Mar 13 2014 werner@suse.de
- Avoid file conflict between udev and systemd (bnc#868230)
* Wed Mar 12 2014 werner@suse.de
- Modify patch
  module-load-handle-SUSE-etc-sysconfig-kernel-module-list.patch
  to ignore if /etc/sysconfig/kernel does not exist (bnc#865834)
* Wed Mar 12 2014 werner@suse.de
- Add patch systemd-big-endian-reply-matching.patch
  make sure that systemd can talk with dbus-daemon even on big
  endian systems (bnc#866732)
* Tue Mar 11 2014 hrvoje.senjan@gmail.com
- Due to previous reason, resurrect systemd-dbus-system-bus-address.patch
- Removed pkgconfig(dbus-1) BuildRequires - with 209 and newer, itis only
  needed for quering default DBus directories, which we nowpass to configure.
  This also unbreaks libdbus <-> systemd-miniBuild Cycle
* Tue Mar 11 2014 werner@suse.de
- Add or port upstream bugfix patches:
  0001-core-busname-add-lookup-string-for-BUSNAME_FAILURE_S.patch
  0002-manager-flush-memory-stream-before-using-the-buffer.patch
  0003-busname-don-t-drop-service-from-the-result-string.patch
  0004-fix-off-by-one-error-in-array-index-assertion.patch
  0005-logind-fix-policykit-checks.patch
  0006-rules-mark-loop-device-as-SYSTEMD_READY-0-if-no-file.patch
  0007-dbus-suppress-duplicate-and-misleading-messages.patch
  0008-man-multiple-sleep-modes-are-to-be-separated-by-whit.patch
* Tue Mar 11 2014 werner@suse.de
- Make compeletion file parser work (bnc#867664)
* Fri Mar  7 2014 hare@suse.de
- Integrate powerd handling in initctl service
  + Remove 1016-support-powerfail-with-powerstatus.patch
  + Remove systemd-powerfail
  + Add systemd-powerd-initctl-support.patch
- Remove 61-msft.rules; superseded by sg3_utils (bnc#866933)
- Persistent by-path links for ATA devices (FATE#317063)
  + Update 1001-re-enable-by_path-links-for-ata-devices.patch
* Fri Mar  7 2014 werner@suse.de
- Add or port upstream bugfix patches:
  0001-Fix-systemd-stdio-bridge-symlink.patch
  0002-execute-free-directory-path-if-we-fail-to-remove-it-.patch
  0003-Do-not-print-invalid-UTF-8-in-error-messages.patch
  0004-man-document-missing-options-of-systemd-run.patch
  0005-systemd-run-add-some-extra-safety-checks.patch
  0006-journal-assume-that-next-entry-is-after-previous-ent.patch
  0007-journal-forget-file-after-encountering-an-error.patch
  0008-core-correctly-unregister-PIDs-from-PID-hashtables.patch
  0009-logind-fix-reference-to-systemd-user-sessions.servic.patch
  0010-man-update-link-to-LSB.patch
  0011-man-systemd-bootchart-fix-spacing-in-command.patch
  0012-man-add-missing-comma.patch
  0013-units-Do-not-unescape-instance-name-in-systemd-backl.patch
* Fri Mar  7 2014 werner@suse.de
- Add linker scripts as place holder of the old systemd shared
  libraries now all included in libsystemd.so  (bnc#867128)
* Tue Mar  4 2014 werner@suse.de
- Make patch 1006-udev-always-rename-network.patch work again
  and add it again.
* Mon Mar  3 2014 thomas.blume@suse.com
- address missing owner functionality in systemd-tmpfiles (fate#314974)
  1022-systemd-tmpfiles-ownerkeep.patch
* Mon Mar  3 2014 werner@suse.de
- Generate the bash completion files on the fly for the case of
  not having the package bash-completion around
- Add or port upstream bugfix patches:
  0001-nspawn-fix-detection-of-missing-proc-self-loginuid.patch
  0002-cdrom_id-use-the-old-MMC-fallback.patch
  0003-journalctl-refuse-extra-arguments-with-verify-and-si.patch
  0004-logs-show-fix-corrupt-output-with-empty-messages.patch
  0005-mount-don-t-fire-PropertiesChanged-signals-for-mount.patch
  0006-mount-don-t-send-out-PropertiesChanged-message-if-ac.patch
  0007-Use-var-run-dbus-system_bus_socket-for-the-D-Bus-soc.patch
  0008-README-document-that-var-run-must-be-a-symlink-run.patch
  0010-Replace-var-run-with-run-in-remaining-places.patch
  0009-Revert-back-to-var-run-at-a-couple-of-problems.patch
  0011-fix-typo-in-iDRAC-network-interface-name-irdac-idrac.patch
  0012-login-Allow-calling-org.freedesktop.login1.Seat.Swit.patch
  0013-login-set-pos-slot-to-fallback-on-pos-eviction.patch
  0014-login-fix-pos-array-allocation.patch
* Mon Mar  3 2014 werner@suse.de
- Update to Release v210
  + systemd will now relabel /dev after loading the SMACK policy
    according to SMACK rules.
  + A new unit file option AppArmoreProfile= has been added to
    set the AppArmor profile for the processes of a unit.
  + A new condition check ConditionArchitecture= has been added
    to conditionalize units based on the system architecture, as
    reported by uname()'s "machine" field.
  + systemd-networkd now supports matching on the system
    virtualization, architecture, kernel command line, host name
    and machine ID.
  + logind is now a lot more aggressive when suspending the
    machine due to a closed laptop lid.
  + logind will now watch SW_DOCK switches and inhibit reaction
    to the lid switch if it is pressed.
  + nspawn will now make use of the devices cgroup controller by
    default, and only permit creation of and access to the usual
    API device nodes like /dev/null or /dev/random, as well as
    access to (but not creation of) the pty devices.
  + systemd will now understand the usual M, K, G, T suffixes
    according to SI conventions (i.e. to the base 1000) when
    referring to throughput and hardware metrics.
  + The DeviceAllow= setting in unit files now supports a syntax
    to whitelist an entire group of devices node majors at once,
    based on the /proc/devices listing. For example, with the
    string "char-pts" it is now possible to whitelist all
    current and future pseudo-TTYs at once.
  + sd-event learned a new "post" event source. Event sources of
    this type are triggered by the dispatching of any event
    source of a type that is not "post". This is useful for
    implementing clean-up and check event sources that are
    triggered by other work being done in the program.
  + The compatibility libraries for libsystemd-journal.so,
    libsystem-id128.so, libsystemd-login.so and
    libsystemd-daemon.so do not make use of IFUNC
    anymore.
- Dropped systemd patches as those are fixed upstream:
  * 0001-units-serial-getty-.service-add-Install-section.patch
  * 0001-shared-architecture.h-fix-preprocessor-directives.patch
  * 0001-selinux-Don-t-attempt-to-load-policy-in-initramfs-if.patch
  * 0001-sd-event-Fix-systemd-crash-when-using-timer-units.patchc
  * 0001-make-tests-with-libseccomp-work.patch
  * 0001-build-sys-Fix-compilation-of-nspawn-when-seccomp-is-.patch
  * 0001-units-serial-getty-.service-add-Install-section.patch
- Dropped patches as those do not work anymore
  * 1006-udev-always-rename-network.patch
- Renamed systemd patches as seen from git log:
  * 0001-cdrom_id-use-the-old-MMC-fallback.patch
    become 0002-cdrom_id-use-the-old-MMC-fallback.patch
  * 0001-journalctl-refuse-extra-arguments-with-verify-and-si.patch
    become 0003-journalctl-refuse-extra-arguments-with-verify-and-si.patch
  * 0001-logs-show-fix-corrupt-output-with-empty-messages.patch
    become 0004-logs-show-fix-corrupt-output-with-empty-messages.patch
- Add several upstream bugfix patches which are missed:
  * 0001-build-sys-Add-setns-functions-if-not-in-the-C-librar.patch
  * 0001-build-sys-Fix-compilation-of-nspawn-when-seccomp-is-.patch
  * 0001-sd-event-Fix-systemd-crash-when-using-timer-units.patch
  * 0001-selinux-Don-t-attempt-to-load-policy-in-initramfs-if.patch
  * 0001-shared-architecture.h-fix-preprocessor-directives.patch
  * 0005-mount-don-t-fire-PropertiesChanged-signals-for-mount.patch
  * 0006-mount-don-t-send-out-PropertiesChanged-message-if-ac.patch
  * 0007-Use-var-run-dbus-system_bus_socket-for-the-D-Bus-soc.patch
  * 0008-README-document-that-var-run-must-be-a-symlink-run.patch
  * 0009-Revert-back-to-var-run-at-a-couple-of-problems.patch
  * 0010-Replace-var-run-with-run-in-remaining-places.patch
  * 0011-fix-typo-in-iDRAC-network-interface-name-irdac-idrac.patch
  * 0012-login-Allow-calling-org.freedesktop.login1.Seat.Swit.patch
  * 0013-login-set-pos-slot-to-fallback-on-pos-eviction.patch
  * 0014-login-fix-pos-array-allocation.patch
- Modified patches to make is build
  * 0001-add-network-device-after-NFS-mount-units.patch
- Reenable libseccomp for the architecture for which libseccomp exists
* Sun Mar  2 2014 ro@suse.de
- always install compat pkgconfig files, regardless if
  compat libs is enabled or not
* Sun Mar  2 2014 ro@suse.de
- disable use of libseccomp for sle12, library has not been ported
  to most architectures
- do not use binutils-gold on s390/s390x, does not exist there
- fix exclude statements for bootstrap case
* Fri Feb 28 2014 werner@suse.de
- Add upstream patches
  + 0001-cdrom_id-use-the-old-MMC-fallback.patch
  + 0001-logs-show-fix-corrupt-output-with-empty-messages.patch
  + 0001-journalctl-refuse-extra-arguments-with-verify-and-si.patch
* Fri Feb 28 2014 werner@suse.de
- Add patch
  0001-systemd-empty-sigmask-on-reexec.patch
  which corrects sigmaks for reexec in initrd (bnc#864904)
* Fri Feb 28 2014 werner@suse.de
- Add patch
  0001-nspawn-fix-detection-of-missing-proc-self-loginuid.patch
  to avoid error on not existing file /proc/self/loginuid
* Fri Feb 28 2014 werner@suse.de
- Make patch
  0001-make-209-working-on-older-dist.patch
  more smart that is make configure script les restrictive
- Make patch
  apply-ACL-for-nvidia-device-nodes.patch
  apply to v209
* Fri Feb 28 2014 werner@suse.de
- Update to Release v209 on the base of the work of Stefan Brüns
  from declined submit request 223602:
  + A new tool "systemd-socket-proxyd" has been added
  + Add a new tool to save/restore rfkill state on
    shutdown/boot.
  + Save/restore state of keyboard backlights in addition to
    display backlights on shutdown/boot.
  + udev learned a new SECLABEL{} construct to label device
    nodes with a specific security label when they appear. For
    now, only SECLABEL{selinux} is supported, but the syntax is
    prepared for additional security frameworks.
  + When the User= switch is used in a unit file, also
    initialize $SHELL= based on the user database entry.
  + systemd no longer depends on libdbus. All communication is
    now done with sd-bus, systemd's low-level bus library
    implementation.
  + sd-bus: add a light-weight vtable implementation that allows
    defining objects on the bus with a simple static const
    vtable array of its methods, signals and properties.
  + systemd will not generate or install static dbus
    introspection data anymore to /usr/share/dbus-1/interfaces,
    as the precise format of these files is unclear, and
    nothing makes use of it.
  + A proxy daemon is now provided to proxy clients connecting
    via classic D-Bus AF_UNIX sockets to kdbus, to provide full
    compatibility with classic D-Bus.
  + A bus driver implementation has been added that supports the
    classic D-Bus bus driver calls on kdbus, also for
    compatibility purposes.
  + A new API "sd-event.h" has been added that implements a
    minimal event loop API built around epoll.
  + A new API "sd-rntl.h" has been added that provides an API
    around the route netlink interface of the kernel, similar in
    style to "sd-bus.h".
  + A new API "sd-dhcp-client.h" has been added that provides a
    small DHCPv4 client-side implementation. This is used by
    "systemd-networkd".
  + There is a new kernel command line option
    "systemd.restore_state=0|1". When set to "0", none of the
    systemd tools will restore saved runtime state to hardware
    devices. More specifically, the rfkill and backlight states
    are not restored.
  + The FsckPassNo= compatibility option in mount/service units
    has been removed. The fstab generator will now add the
    necessary dependencies automatically, and does not require
    PID1's support for that anymore.
  + journalctl gained a new switch, --list-boots, that lists
    recent boots with their times and boot IDs.
  + The various tools like systemctl, loginctl, timedatectl,
    busctl, systemd-run, ... have gained a new switch "-M" to
    connect to a specific, local OS container (as direct
    connection, without requiring SSH).
  + systemd-run and systemd-analyze also gained support for "-H"
    to connect to remote hosts via SSH. This is particularly
    useful for systemd-run because it enables queuing of jobs
    onto remote systems.
  + machinectl gained a new command "login" to open a getty
    login in any local container. This works with any container
    that is registered with machined (such as those created by
    libvirt-lxc or nspawn), and which runs systemd inside.
  + machinectl gained a new "reboot" command that may be used to
    trigger a reboot on a specific container that is registered
    with machined. This works on any container that runs an init
    system of some kind.
  + systemctl gained a new "list-timers" command to print a nice
    listing of installed timer units with the times they elapse
    next.
  + Alternative reboot() parameters may now be specified on the
    "systemctl reboot" command line and are passed to the
    reboot() system call.
  + systemctl gained a new --job-mode= switch to configure the
    mode to queue a job with. This is a more generic version of
  - -fail, --irreversible, and --ignore-dependencies, which are
    still available but not advertised anymore.
  + /etc/systemd/system.conf gained new settings to configure
    various default timeouts of units, as well as the default
    start limit interval and burst. These may still be overridden
    within each Unit.
  + PID1 will now export on the bus profile data of the security
    policy upload process (such as the SELinux policy upload to
    the kernel).
  + journald: when forwarding logs to the console, include
    timestamps (following the setting in
    /sys/module/printk/parameters/time).
  + OnCalendar= in timer units now understands the special
    strings "yearly" and "annually". (Both are equivalent)
  + The accuracy of timer units is now configurable with the new
    AccuracySec= setting. It defaults to 1min.
  + A new dependency type JoinsNamespaceOf= has been added that
    allows running two services within the same /tmp and network
    namespace, if PrivateNetwork= or PrivateTmp= are used.
  + A new command "cat" has been added to systemctl. It outputs
    the original unit file of a unit, and concatenates the
    contents of additional "drop-in" unit file snippets, so that
    the full configuration is shown.
  + systemctl now supports globbing on the various "list-xyz"
    commands, like "list-units" or "list-sockets", as well as on
    those commands which take multiple unit names.
  + journalctl's --unit= switch gained support for globbing.
  + All systemd daemons now make use of the watchdog logic so
    that systemd automatically notices when they hang.
  + If the $container_ttys environment variable is set,
    getty-generator will automatically spawn a getty for each
    listed tty. This is useful for container managers to request
    login gettys to be spawned on as many ttys as needed.
  + %%h, %%s, %%U specifier support is not available anymore when
    used in unit files for PID 1. This is because NSS calls are
    not safe from PID 1. They stay available for --user
    instances of systemd, and as special case for the root user.
  + loginctl gained a new "--no-legend" switch to turn off output
    of the legend text.
  + The "sd-login.h" API gained three new calls:
    sd_session_is_remote(), sd_session_get_remote_user(),
    sd_session_get_remote_host() to query information about
    remote sessions.
  + The udev hardware database now also carries vendor/product
    information of SDIO devices.
  + The "sd-daemon.h" API gained a new sd_watchdog_enabled() to
    determine whether watchdog notifications are requested by
    the system manager.
  + Socket-activated per-connection services now include a
    short description of the connection parameters in the
    description.
  + tmpfiles gained a new "--boot" option. When this is not used,
    only lines where the command character is not suffixed with
    "!" are executed. When this option is specified, those
    options are executed too.
  + systemctl gained a new "import-environment" command which
    uploads the caller's environment (or parts thereof) into the
    service manager so that it is inherited by services started
    by the manager. This is useful to upload variables like
    $DISPLAY into the user service manager.
  + A new PrivateDevices= switch has been added to service units
    which allows running a service with a namespaced /dev
    directory that does not contain any device nodes for
    physical devices. More specifically, it only includes devices
    such as /dev/null, /dev/urandom, and /dev/zero which are API
    entry points.
  + logind has been extended to support behaviour like VT
    switching on seats that do not support a VT. This makes
    multi-session available on seats that are not the first seat
    (seat0), and on systems where kernel support for VTs has
    been disabled at compile-time.
  + If a process holds a delay lock for system sleep or shutdown
    and fails to release it in time, we will now log its
    identity. This makes it easier to identify processes that
    cause slow suspends or power-offs.
  + When parsing /etc/crypttab, support for a new key-slot=
    option as supported by Debian is added. It allows indicating
    which LUKS slot to use on disk, speeding up key loading.
  + The sd_journald_sendv() API call has been checked and
    officially declared to be async-signal-safe so that it may
    be invoked from signal handlers for logging purposes.
  + Boot-time status output is now enabled automatically after a
    short timeout if boot does not progress, in order to give
    the user an indication what she or he is waiting for.
  + The boot-time output has been improved to show how much time
    remains until jobs expire.
  + The KillMode= switch in service units gained a new possible
    value "mixed". If set, and the unit is shut down, then the
    initial SIGTERM signal is sent only to the main daemon
    process, while the following SIGKILL signal is sent to
    all remaining processes of the service.
  + logind will now also track a "Desktop" identifier for each
    session which encodes the desktop environment of it. This is
    useful for desktop environments that want to identify
    multiple running sessions of itself easily.
  + A new SELinuxContext= setting for service units has been
    added that allows setting a specific SELinux execution
    context for a service.
  + Most systemd client tools will now honour $SYSTEMD_LESS for
    settings of the "less" pager.
  + systemd's "seccomp" hook-up has been changed to make use of
    the libseccomp library instead of using its own
    implementation. This has benefits for portability among
    other things.
- Dropped systemd patches as those are fixed upstream:
  * 0001-acpi-fptd-fix-memory-leak-in-acpi_get_boot_usec.patch
  * 0002-fix-lingering-references-to-var-lib-backlight-random.patch
  * 0003-acpi-make-sure-we-never-free-an-uninitialized-pointe.patch
  * 0004-systemctl-fix-name-mangling-for-sysv-units.patch
  * 0005-cryptsetup-fix-OOM-handling-when-parsing-mount-optio.patch
  * 0006-journald-add-missing-error-check.patch
  * 0007-bus-fix-potentially-uninitialized-memory-access.patch
  * 0008-dbus-fix-return-value-of-dispatch_rqueue.patch
  * 0009-modules-load-fix-error-handling.patch
  * 0010-efi-never-call-qsort-on-potentially-NULL-arrays.patch
  * 0011-strv-don-t-access-potentially-NULL-string-arrays.patch
  * 0012-mkdir-pass-a-proper-function-pointer-to-mkdir_safe_i.patch
  * 0014-tmpfiles.d-include-setgid-perms-for-run-log-journal.patch
  * 0001-systemd-order-remote-mounts-from-mountinfo-before-re.patch
  * 0001-gpt-auto-generator-exit-immediately-if-in-container.patch
  * 0001-manager-when-verifying-whether-clients-may-change-en.patch
  * 0001-logind-fix-bus-introspection-data-for-TakeControl.patch
  * 0001-mount-check-for-NULL-before-reading-pm-what.patch
  * 0001-shared-util-fix-off-by-one-error-in-tag_to_udev_node.patch
  * 0001-systemd-serialize-deserialize-forbid_restart-value.patch
  * 0001-core-unify-the-way-we-denote-serialization-attribute.patch
  * 0001-journald-fix-minor-memory-leak.patch
  * 0001-do-not-accept-garbage-from-acpi-firmware-performance.patch
  * 0001-journald-remove-rotated-file-from-hashmap-when-rotat.patch
  * 0001-login-fix-invalid-free-in-sd_session_get_vt.patch
  * 0001-login-make-sd_session_get_vt-actually-work.patch
  * 0001-Never-call-qsort-on-potentially-NULL-arrays.patch
  * 0001-dbus-common-avoid-leak-in-error-path.patch
  * 0001-drop-ins-check-return-value.patch
  * 0001-shared-util-Fix-glob_extend-argument.patch
  * 0001-Fix-bad-assert-in-show_pid_array.patch
  * 0001-analyze-set-white-background.patch
  * 0001-analyze-set-text-on-side-with-most-space.patch
  * analyze-fix-crash-in-command-line-parsing.patch
  * 0001-core-replace-OnFailureIsolate-setting-by-a-more-gene.patch
  * 0001-core-introduce-new-KillMode-mixed-which-sends-SIGTER.patch
  * 0002-service-allow-KillMode-mixed-in-conjunction-with-PAM.patch
  * 0003-core-make-sure-to-always-go-through-both-SIGTERM-and.patch
  * U_logind_revert_lazy_session_activation_on_non_vt_seats.patch
  * build-sys-make-multi-seat-x-optional.patch
  * 1017-skip-native-unit-handling-if-sysv-already-handled.patch
  * 0018-core-do-not-add-what-to-RequiresMountsFor-for-networ.patch
  * 0030-Fix-for-SIGSEGV-in-systemd-bootchart-on-short-living.patch
  * 0031-man-document-the-b-special-boot-option.patch
  * 0033-tmpfiles-log-unaccessible-FUSE-mount-points-only-as-.patch
  * 0034-systemd-python-fix-booted-and-add-two-functions-to-d.patch
  * 0035-activate-mention-E-in-the-help-text.patch
  * 0036-activate-fix-crash-when-s-is-passed.patch
  * 0037-tmpfiles-adjust-excludes-for-the-new-per-service-pri.patch
  * 0038-core-socket-fix-SO_REUSEPORT.patch
  * 0039-journal-when-appending-to-journal-file-allocate-larg.patch
  * 0040-journal-optimize-bisection-logic-a-bit-by-caching-th.patch
  * 0041-journal-fix-iteration-when-we-go-backwards-from-the-.patch
  * 0042-journal-allow-journal_file_copy_entry-to-work-on-non.patch
  * 0043-journal-simplify-pre-allocation-logic.patch
  * 0044-journald-mention-how-long-we-needed-to-flush-to-var-.patch
  * 0046-util.c-check-if-return-value-from-ttyname_r-is-0-ins.patch
  * 0047-docs-remove-unneeded-the-s-in-gudev-docs.patch
  * 0048-man-explicitly-say-when-multiple-units-can-be-specif.patch
  * 0049-systemd-treat-reload-failure-as-failure.patch
- Dropped backported systemd patches as those are fixed upstream
  * 0145-logind-use-correct-who-enum-values-with-KillUnit.patch
  * 1011-check-4-valid-kmsg-device.patch
  * 0001-logind-garbage-collect-stale-users.patch
- Dropped udev patches as those are fixed fixed upstream:
  * 0026-udevadm.xml-document-resolve-names-option-for-test.patch
  * 0032-rules-don-t-limit-some-of-the-rules-to-the-add-actio.patch
- Modified patches
  * 1006-udev-always-rename-network.patch
- Replaced patches
  * the patch
    1012-pam_systemd_do_override_XDG_RUNTIME_DIR_of_the_original_user.patch
    is upstream now but has to be replaced by patch
    0001-pam_systemd_do_override_XDG_RUNTIME_DIR_of_the_original_user.patch
    to fix an further issue similar to the upstream patch (bnc#852015)
  * the patch
    0001-upstream-systemctl-halt-reboot-error-handling.patch
    is upstream now, only the part with the halt after a failed poweroff
    has been added to the patch
    0001-add-hdflush-for-reboot-or-hddown-for-poweroff.patch
* Thu Feb 27 2014 werner@suse.de
- Add patch 0001-make-209-working-on-older-dist.patch to make
  it usable on older distributions like 13.1
* Wed Feb 26 2014 werner@suse.de
- Add patch 0001-add-network-device-after-NFS-mount-units.patch to
  add "After" dependency to all NFS shares to the network interface
  device as this ensures at shutdown that the NFS share becomes
  unmounted before the interface is down (bnc#861489)
* Sun Feb 23 2014 stefan.bruens@rwth-aachen.de
- enable compat-libs, BuildRequires binutils-gold
  ("old" ld fails on ifunc magic)
* Sun Feb 23 2014 stefan.bruens@rwth-aachen.de
- add network link configuration for udev
* Sun Feb 23 2014 stefan.bruens@rwth-aachen.de
- Modify patch 0001-add-hdflush-for-reboot-or-hddown-for-poweroff.patch,
  move to core and link in directly to avoid libudev dep all over
- Disable networkd
- Disable compat-libs, adapt files section
- add and remove some entries in the files section
* Fri Feb 21 2014 werner@suse.de
- Modify patch 1018-Make-LSB-Skripts-know-about-Required-and-Should.patch
  to avoid WantedBy for Should-Start/Start-Before/Start-After SysVinit
  scripts (bnc#863217)
* Thu Feb 20 2014 werner@suse.de
- Modify patch 0001-add-hdflush-for-reboot-or-hddown-for-poweroff.patch
  to do a final sync() and flush the disks
* Fri Feb 14 2014 werner@suse.de
- Add several upstream bugfix patches which are missed:
  * 0018-core-do-not-add-what-to-RequiresMountsFor-for-networ.patch
  * 0026-udevadm.xml-document-resolve-names-option-for-test.patch
  * 0030-Fix-for-SIGSEGV-in-systemd-bootchart-on-short-living.patch
  * 0032-rules-don-t-limit-some-of-the-rules-to-the-add-actio.patch
  * 0031-man-document-the-b-special-boot-option.patch
  * 0033-tmpfiles-log-unaccessible-FUSE-mount-points-only-as-.patch
  * 0034-systemd-python-fix-booted-and-add-two-functions-to-d.patch
  * 0035-activate-mention-E-in-the-help-text.patch
  * 0036-activate-fix-crash-when-s-is-passed.patch
  * 0037-tmpfiles-adjust-excludes-for-the-new-per-service-pri.patch
  * 0038-core-socket-fix-SO_REUSEPORT.patch
  * 0039-journal-when-appending-to-journal-file-allocate-larg.patch
  * 0040-journal-optimize-bisection-logic-a-bit-by-caching-th.patch
  * 0041-journal-fix-iteration-when-we-go-backwards-from-the-.patch
  * 0042-journal-allow-journal_file_copy_entry-to-work-on-non.patch
  * 0043-journal-simplify-pre-allocation-logic.patch
  * 0044-journald-mention-how-long-we-needed-to-flush-to-var-.patch
  * 0046-util.c-check-if-return-value-from-ttyname_r-is-0-ins.patch
  * 0047-docs-remove-unneeded-the-s-in-gudev-docs.patch
  * 0048-man-explicitly-say-when-multiple-units-can-be-specif.patch
  * 0049-systemd-treat-reload-failure-as-failure.patch
- Add patch 0001-Don-t-snprintf-a-potentially-NULL-pointer.patch
  to avoid potential NULL pointer
- Reorder patches to reflect udev/systemd usage
* Tue Feb 11 2014 coolo@suse.com
- don't build bash-completions for bootstrap package
* Tue Feb 11 2014 coolo@suse.com
- add more requires to this-is-only-for-build-envs to avoid
  problems in kiwi configs
* Mon Feb 10 2014 werner@suse.de
- Add patch 0145-logind-use-correct-who-enum-values-with-KillUnit.patch
  to be able to kill sessions (bnc#860574)
* Mon Feb 10 2014 werner@suse.de
- Do not return from main shell script but simply exit (bnc#862789)
* Sun Feb  9 2014 werner@suse.de
- ... as only the systemd-analyze completion depends on
  bash-completion I prefere a without which has to be defined
  for SLES 12
* Sun Feb  9 2014 coolo@suse.com
- avoid bootstrap cycle with libusb and systemd-mini
* Sat Feb  8 2014 coolo@suse.com
- split bash-completion support into its own package,
  no need for sles_version
* Fri Feb  7 2014 werner@suse.de
- Split off systemd-rpm-macros as a separate package to avoid
  a rebuild of all packages due new systemd package
- Define a sles_version 12 for suse_version 1315
* Wed Feb  5 2014 werner@suse.de
- Change and extend patch
  0001-On_s390_con3270_disable_ANSI_colour_esc.patch
  to disable the workaround to find /dev/3270/tty1 as this now
  should be done by a) the kernel patch
  http://lkml.indiana.edu/hypermail/linux/kernel/1402.0/02319.html
  and the changed udev rule 99-systemd.rules
* Sun Feb  2 2014 ohering@suse.com
- Remove PreReq pidof from udev, nothing in this pkg uses it
* Fri Jan 31 2014 werner@suse.de
- Change and extend patch
  0001-On_s390_con3270_disable_ANSI_colour_esc.patch
  to re-enable colouring if 3270 console was enforced on the kernel
  command line as 3270 cna handle colour ANSI escape sequences.
  Also let the serial getty generator find the /dev/3270/tty1
  character device (bnc#861316)
* Thu Jan 30 2014 werner@suse.de
- Add patch 0001-On_s390_con3270_disable_ANSI_colour_esc.patch
  to strip the colouring ANSI escape sequences from the console
  messages (bnc#860937)
* Thu Jan 30 2014 werner@suse.de
- Change patch 0001-add-hdflush-for-reboot-or-hddown-for-poweroff.patch
  to skip already by the kernel managed devices
* Wed Jan 29 2014 arvidjaar@gmail.com
- fix timeout stopping user@.service (bnc#841544)
  * 0001-core-introduce-new-KillMode-mixed-which-sends-SIGTER.patch
  * 0002-service-allow-KillMode-mixed-in-conjunction-with-PAM.patch
  * 0003-core-make-sure-to-always-go-through-both-SIGTERM-and.patch
* Tue Jan 28 2014 werner@suse.de
- Add patch 0001-upstream-systemctl-halt-reboot-error-handling.patch
  to be able to detect if the sysctl reboot() returns.
- Add patch 0001-add-hdflush-for-reboot-or-hddown-for-poweroff.patch
  A check for unmaintained disk like devices is added to be able to
  flush and maybe shut them down.  Also the missing sync() system
  call is added for the direct halt/reboot systemctl command. Then
  the system halt is used as fallback if poweroff fails for both
  the direct poweroff systemctl command as well as for the
  systemd-shutdown utility.
* Thu Jan 23 2014 werner@suse.de
- Make systemd-mini build
* Thu Jan 23 2014 werner@suse.de
- Make requires bash-completion a recommends
* Tue Jan 21 2014 werner@suse.de
- Add patch 1017-skip-native-unit-handling-if-sysv-already-handled.patch
  to avoid that enabled boot scripts will be handled as unit files
  by systemctl status command (bnc#818044)
* Tue Jan 21 2014 werner@suse.de
- Drop patch 1017-enforce-sufficient-shutdown-warnings.patch
  as the original code behaves exactly as the shutdown code of
  the old SysVinit (bnc#750845)
- Rename support-powerfail-with-powerstatus.patch to
  1016-support-powerfail-with-powerstatus.patch
* Mon Jan 20 2014 fcrozat@suse.com
- Add analyze-fix-crash-in-command-line-parsing.patch: fix crash in
  systemd-analyze (bnc#859365)
* Fri Jan 17 2014 werner@suse.de
- Add patch
  1019-make-completion-smart-to-be-able-to-redirect.patch
  to make redirections work with the bash command completions for
  for systemd command tools (bnc#856858, bnc#859072)
* Fri Jan 17 2014 werner@suse.de
- Add patch
  1018-Make-LSB-Skripts-know-about-Required-and-Should.patch
  to support the "+" to tag wanted dependencies as well as make
  sure that required dependencies are handles as required ones.
  This should fix bnc#858864 and bnc#857204.
* Thu Jan 16 2014 lnussel@suse.de
- apply preset also to service files that are new in upgrade
* Wed Jan 15 2014 werner@suse.de
- Change support-powerfail-with-powerstatus.patch to use BindsTo
  instead of BindTo
* Wed Jan 15 2014 werner@suse.de
- Add patch 1017-enforce-sufficient-shutdown-warnings.patch
  Warn once per hour in the last 3 hours, then all 30 minutes in last
  hour, all 15 minutes in the last 45 minutes, all 10 minutes in the
  last 15 minutes, and then all minute in the last 10 minutes (bnc#750845)
* Tue Jan 14 2014 werner@suse.de
- Add patch support-powerfail-with-powerstatus.patch and source
  file systemd-powerfail to implement SIGPWR support with evaluation
  of the file /var/run/powerstatus (bnc#737690)
* Fri Dec 20 2013 werner@suse.de
- Adapt patch
  1011-check-4-valid-kmsg-device.patch
  to fit current upstream version maybe related to bnc#854884
- Change patch
  1012-pam_systemd_do_override_XDG_RUNTIME_DIR_of_the_original_user.patch
  to check if XDG_RUNTIME_DIR is set before the call of pam_putenv()
  may fix bnc#855160
* Fri Dec 20 2013 lbsousajr@gmail.com
- Disable multi-seat-x build, since package xorg-x11-server
  currently in Factory no longer needs it.
* Wed Dec 18 2013 hrvoje.senjan@gmail.com
- Added 0001-logind-garbage-collect-stale-users.patch: Don't stop a
  running user manager from garbage-collecting the user. Original
  behavior caused bnc#849870
* Mon Dec 16 2013 lbsousajr@gmail.com
- Add build-sys-make-multi-seat-x-optional.patch
  * See: http://cgit.freedesktop.org/systemd/systemd/commit/?id=bd441fa27a22b7c6e11d9330560e0622fb69f297
  * Now systemd-multi-seat-x build can be disabled with configure option
  - -disable-multi-seat-x. It should be done when xorg-x11-server
    no longer needs it (work in progress).
* Mon Dec 16 2013 fcrozat@suse.com
- Update insserv-generator.patch: fix crash in insserv generator
  (bnc#854314).
- Update apply-ACL-for-nvidia-device-nodes.patch with latest fixes
  for Nvidia cards (bnc#808319).
* Fri Dec  6 2013 werner@suse.de
- Add patch
  1014-journald-with-journaling-FS.patch
  which now uses the file system ioctls for switching off atime,
  compression, and copy-on-write of the journal directory of the
  the systemd-journald (bnc#838475)
- Let us build require the package config for libpcre (bnc#853293)
* Sat Nov 30 2013 arvidjaar@gmail.com
- Add patch
  0001-core-replace-OnFailureIsolate-setting-by-a-more-gene.patch
  Make sure emergency shell is not killed by attempt to start another unit
  (bnc#852021). Backported from d420282b28f50720e233ccb1c02547c562195653.
- Add patch
  make-emergency.service-conflict-with-syslog.socket.patch
  Previous patch did not fix problem if syslog connection request came
  after emergency shell was already started. So forcibly stop syslog.socket
  when starting emergency.service. (bnc#852232)
* Thu Nov 28 2013 lbsousajr@gmail.com
- Add U_logind_revert_lazy_session_activation_on_non_vt_seats.patch
  * See: http://cgit.freedesktop.org/systemd/systemd/commit/?id=3fdb2494c1e24c0a020f5b54022d2c751fd26f50
* Tue Nov 26 2013 werner@suse.de
- Add patch
  1012-pam_systemd_do_override_XDG_RUNTIME_DIR_of_the_original_user.patch
  to avoid (xdg-)su to set XDG_RUNTIME_DIR to the original user and
  avoid that e.g. pulseaudio will create /run/user/<pid>/pulse owned
  by root (bnc#852015)
* Thu Nov 21 2013 werner@suse.de
- Add patch
  1011-check-4-valid-kmsg-device.patch
  to avoid a busy systemd-journald (bnc#851393)
* Wed Nov  6 2013 werner@suse.de
- Add patch
  1010-do-not-install-sulogin-unit-with-poweroff.patch
  that is do not install console-shell.service in any system target
  as this will cause automatic poweroff at boot (bnc#849071)
* Mon Nov  4 2013 werner@suse.de
- Add upstream patch
  0001-analyze-set-text-on-side-with-most-space.patch
  to place the text on the side with most space
* Fri Oct 25 2013 werner@suse.de
- Add upstream patch
  0001-analyze-set-white-background.patch
  to make SVG output of systemd analyze readable
* Mon Oct 21 2013 werner@suse.de
- Add patch
  1009-make-xsltproc-use-correct-ROFF-links.patch
  to have valid ROFF links in manual pages working again (bnc#842844)
* Tue Oct 15 2013 fcrozat@suse.com
- Add
  0001-gpt-auto-generator-exit-immediately-if-in-container.patch:
  don't start gpt auto-generator in container (git).
- Add
  0001-manager-when-verifying-whether-clients-may-change-en.patch:
  fix reload check in selinux case (git).
- Add 0001-logind-fix-bus-introspection-data-for-TakeControl.patch:
  fix introspection for TakeControl (git).
- Add 0001-mount-check-for-NULL-before-reading-pm-what.patch: fix
  crash when parsing some incorrect unit (git).
- Add
  0001-shared-util-fix-off-by-one-error-in-tag_to_udev_node.patch:
  Fix udev rules parsing (git).
- Add
  0001-systemd-serialize-deserialize-forbid_restart-value.patch:
  Fix incorrect deserialization for forbid_restart (git).
- Add
  0001-core-unify-the-way-we-denote-serialization-attribute.patch:
  Ensure forbid_restart is named like other attributes (git).
- Add 0001-journald-fix-minor-memory-leak.patch: fix memleak in
  journald (git).
- Add
  0001-do-not-accept-garbage-from-acpi-firmware-performance.patch:
  Improve ACPI firmware performance parsing (git).
- Add
  0001-journald-remove-rotated-file-from-hashmap-when-rotat.patch:
  Fix journal rotation (git).
- Add
  0001-login-fix-invalid-free-in-sd_session_get_vt.patch:
  Fix memory corruption in sd_session_get_vt (git).
- Add 0001-login-make-sd_session_get_vt-actually-work.patch: Ensure
  sd_session_get_vt returns correct value (git).
- Add 0001-Never-call-qsort-on-potentially-NULL-arrays.patch: Don't
  call qsort on NULL arrays (git).
- Add 0001-dbus-common-avoid-leak-in-error-path.patch: Fix memleak
  in dbus-common code (git).
- Add 0001-drop-ins-check-return-value.patch: Fix return value for
  drop-ins checks (git).
- Add 0001-shared-util-Fix-glob_extend-argument.patch: Fix
  glob_extend argument (git).
- Add 0001-Fix-bad-assert-in-show_pid_array.patch: Fix bad assert
  in show_pid_array (git).
* Thu Oct  3 2013 fcrozat@suse.com
- Add 0001-acpi-fptd-fix-memory-leak-in-acpi_get_boot_usec.patch:
  fix acpi memleak.
- Add
  0002-fix-lingering-references-to-var-lib-backlight-random.patch:
  fix invalid path in documentation.
- Add
  0003-acpi-make-sure-we-never-free-an-uninitialized-pointe.patch:
  fix invalid memory free.
- Add 0004-systemctl-fix-name-mangling-for-sysv-units.patch: fix
  name mangling for sysv units.
- Add
  0005-cryptsetup-fix-OOM-handling-when-parsing-mount-optio.patch:
  fix OOM handling.
- Add 0006-journald-add-missing-error-check.patch: add missing
  error check.
- Add 0007-bus-fix-potentially-uninitialized-memory-access.patch:
  fix uninitialized memory access.
- Add 0008-dbus-fix-return-value-of-dispatch_rqueue.patch: fix
  return value.
- Add 0009-modules-load-fix-error-handling.patch: fix error
  handling.
- Add 0010-efi-never-call-qsort-on-potentially-NULL-arrays.patch:
  fix incorrect memory access.
- Add 0011-strv-don-t-access-potentially-NULL-string-arrays.patch:
  fix incorrect memory access.
- Add
  0012-mkdir-pass-a-proper-function-pointer-to-mkdir_safe_i.patch:
  fix invalid pointer.
- Add
  0014-tmpfiles.d-include-setgid-perms-for-run-log-journal.patch:
  fix permission on /run/log/journal.
- Add
  0001-systemd-order-remote-mounts-from-mountinfo-before-re.patch:
  order remote mount points properly before remote-fs.target.
* Wed Oct  2 2013 hrvoje.senjan@gmail.com
- Explicitly require pam-config for %%post of the main package
* Wed Oct  2 2013 fcrozat@suse.com
- Release v208:
  + logind gained support for facilitating privileged input and drm
    devices access for unprivileged clients (helps Wayland /
    kmscon).
  + New kernel command line luks.options= allows to specify LUKS
    options, when used with luks.uuid=
  + tmpfileS.d snippets can uses specifier expansion in path names
    (%%m, %%b, %%H, %%v).
  + New tmpfiles.d command "m" introduced to change
    owner/group/access mode of a file/directory only if it exists.
  + MemorySoftLimit= cgroup settings is no longer supported
    (underlying kernel cgroup attribute will disappear in the
    future).
  + memeory.use_hierarchy cgroup attribute is enabled for all
    cgroups systemd creates in memory cgroup hierarchy.
  + New filed _SYSTEMD_SLICE= is logged in journal messages related
    to a slice.
  + systemd-journald will no longer adjust the group of journal
    files it creates to "systemd-journal" group. Permissions and
    owernship is adjusted when package is upgraded.
  + Backlight and random seed files are now stored in
    /var/lib/systemd.
  + Boot time performance measurements included ACPI 5.0 FPDT
    informations if available.
- Drop merged patches:
  0001-cgroup-add-the-missing-setting-of-variable-s-value.patch,
  0002-cgroup-correct-the-log-information.patch,
  0003-cgroup-fix-incorrectly-setting-memory-cgroup.patch,
  0004-random-seed-we-should-return-errno-of-failed-loop_wr.patch,
  0005-core-cgroup-first-print-then-free.patch,
  0006-swap-fix-reverse-dependencies.patch,
  0008-swap-create-.wants-symlink-to-auto-swap-devices.patch,
  0009-polkit-Avoid-race-condition-in-scraping-proc.patch,
  Fix-timeout-when-stopping-Type-notify-service.patch,
  set-ignoreonisolate-noauto-cryptsetup.patch,
  0001-Fix-buffer-overrun-when-enumerating-files.patch,
  0007-libudev-fix-move_later-comparison.patch.
- Refresh patches
  remain_after_exit-initscript-heuristic-and-add-new-LSB-hea.patch,
  delay-fsck-cryptsetup-after-md-dmraid-lvm-are-started.patch,
  handle-root_uses_lang-value-in-etc-sysconfig-language.patch,
  handle-SYSTEMCTL_OPTIONS-environment-variable.patch,
  Revert-service-drop-support-for-SysV-scripts-for-the-early.patch.
- Own more ghost files.
- Do not run pam-config in systemd-mini %%post.
- Add after-local.service to run after.local late during the boot
  process (bnc#778715).
* Tue Oct  1 2013 fcrozat@suse.com
- Update Fix-timeout-when-stopping-Type-notify-service.patch with
  upstream fix.
- No longer start ask-password-wall, was causing too much spam on
  terminals (bnc#747783).
* Mon Sep 30 2013 fcrozat@suse.com
- Add set-ignoreonisolate-noauto-cryptsetup.patch: ensure noauto
  encrypted mounts survives runlevel changes (bnc#843085).
- Add 0001-Fix-buffer-overrun-when-enumerating-files.patch: fix
  logind crash when /run/systemd/sessions was too big (bnc#840055,
  initial fix from hpj@suse.com).
- Update sysctl-handle-boot-sysctl.conf-kernel_release.patch to
  only check for /boot/sysctl.conf-<uname -r> presence.
- Add service wrapper for after.local (bnc#778715).
* Fri Sep 27 2013 fcrozat@suse.com
- Update use-usr-sbin-sulogin-for-emergency-service.patch to apply
  to all services using sulogin and remove generated files from
  upstream tarball (bnc#841398).
* Mon Sep 23 2013 arvidjaar@gmail.com
- Fix-timeout-when-stopping-Type-notify-service.patch
  Make sure MAINPID is watched when it becomes known (bnc#841544)
* Mon Sep 23 2013 fcrozat@suse.com
- Remove output and error redirection to /dev/null in install
  script, it might help tracing pam related issue (bnc#841573).
* Thu Sep 19 2013 fcrozat@suse.com
- Move symlink migration trigger to post (bnc#821800).
* Wed Sep 18 2013 crrodriguez@opensuse.org
- 0009-polkit-Avoid-race-condition-in-scraping-proc.patch
  VUL-0: polkit: process subject race condition [bnc#835827]
  CVE-2013-4288
* Wed Sep 18 2013 crrodriguez@opensuse.org
- Build with --disable-ima as the openSUSE kernel
  does not support IMA (CONFIG_IMA is not set)
* Wed Sep 18 2013 crrodriguez@opensuse.org
- Build with --disable-smack as the openSUSE kernel
  does not support smack (CONFIG_SECURITY_SMACK is not set)
* Wed Sep 18 2013 fcrozat@suse.com
- Don't use a trigger to create symlink for sysctl.conf, always run
  the test on %%post (bnc#840864).
- Update sysctl-handle-boot-sysctl.conf-kernel_release.patch to
  ensure /boot is mounted before reading /boot/sysctl.conf-*
  (bnc#809420).
* Mon Sep 16 2013 crrodriguez@opensuse.org
- 0008-swap-create-.wants-symlink-to-auto-swap-devices.patch
  really fixes the swap unit problem mentioned in previous
  commit & the opensuse-factory mailing list.
* Sat Sep 14 2013 crrodriguez@opensuse.org
- 0001-cgroup-add-the-missing-setting-of-variable-s-value.patch
  missing important check on return value.
- 0002-cgroup-correct-the-log-information.patch fix misleading
  log information.
- 0003-cgroup-fix-incorrectly-setting-memory-cgroup.patch fix
  setting memory cgroup
- 0004-random-seed-we-should-return-errno-of-failed-loop_wr.patch
  should fail if write fails.
- 0005-core-cgroup-first-print-then-free.patch use-after-free
  will trigger if there is an error condition.
- 0006-swap-fix-reverse-dependencies.patch reported in
  opensuse-factory list, topic "swap isn't activated"
- 0007-libudev-fix-move_later-comparison.patch libudev
  invalid usage of "move_later".
* Sat Sep 14 2013 crrodriguez@opensuse.org
- while testing this new release I get in the logs ocassionally
  at boot "systemd[1]: Failed to open private bus connection:
  Failed to connect to socket /var/run/dbus/system_bus_socket:
  No such file or directory" indeed DBUS_SYSTEM_BUS_DEFAULT_ADDRESS
  is defined to /var/run/dbus/system_bus_socket instead of
  /run/dbus/system_bus_socket and that does not fly when /var/run
  is not yet available. (systemd-dbus-system-bus-address.patch)
* Fri Sep 13 2013 fcrozat@suse.com
- Enable Predictable Network interface names (bnc#829526).
* Fri Sep 13 2013 crrodriguez@opensuse.org
- version 207, distribution specific changes follow, for overall
  release notes see NEWS.
- Fixed:
  * Failed at step PAM spawning /usr/lib/systemd/systemd:
  Operation not permitted
  * Fix shutdown hang "a stop job is running for Session 1 of user root"
    that was reported in opensuse-factory list.
- systemd-sysctl no longer reads /etc/sysctl.conf however backward
  compatbility is to be provides by a symlink created at %%post.
- removed previously disabled upstream patches (merged):
  0002-core-mount.c-mount_dump-don-t-segfault-if-mount-is-n.patch,
  0004-disable-the-cgroups-release-agent-when-shutting-down.patch,
  0005-cgroups-agent-remove-ancient-fallback-code-turn-conn.patch,
  0006-suppress-status-message-output-at-shutdown-when-quie.patch,
- removed upstream merged patches:
  exclude-dev-from-tmpfiles.patch,
  logind_update_state_file_after_generating_....patch
- Add systemd-pam_config.patch: use correct include name for PAM
  configuration on openSUSE.
* Mon Sep  9 2013 fcrozat@suse.com
- Add exclude-dev-from-tmpfiles.patch: allow to exclude /dev from
  tmpfiles (bnc#835813).
* Fri Sep  6 2013 fcrozat@suse.com
- Remove
  force-lvm-restart-after-cryptsetup-target-is-reached.patch and
  remove additional dependencies on LVM in other patches: LVM has
  now systemd support, no need to work around it anymore in
  systemd.
* Wed Aug 21 2013 idonmez@suse.com
- Add patch logind_update_state_file_after_generating_the_session_fifo_not_before.patch
  to fix https://bugs.freedesktop.org/show_bug.cgi?id=67273
* Tue Aug  6 2013 lnussel@suse.de
- explicitly enable getty@tty1.service instead of getty@.service as
  the tty1 alias has been removed from the file (bnc#833494)
* Thu Aug  1 2013 fcrozat@suse.com
- Ensure /usr/lib/systemd/system/shutdown.target.wants is created
  and owned by systemd package.
* Mon Jul 29 2013 fcrozat@suse.com
- Fix drop-in for getty@tty1.service
* Thu Jul 25 2013 fcrozat@suse.com
- Move systemd-journal-gateway to subpackage to lower dependencies
  in default install.
* Tue Jul 23 2013 crrodriguez@opensuse.org
- version 206 , highlights:
  * Unit files now understand the new %%v specifier which
  resolves to the kernel version string as returned by "uname-r".
  * "journalctl -b" may now be used to look for boot output of a
  specific boot. Try "journalctl -b -1"
  * Creation of "dead" device nodes has been moved from udev
  into kmod and tmpfiles.
  * The udev "keymap" data files and tools to apply keyboard
  specific mappings of scan to key codes, and force-release
  scan code lists have been entirely replaced by a udev
  "keyboard" builtin and a hwdb data file.
- remove patches now in upstream
- systemd now requires libkmod >=14 and cryptsetup >= 1.6.0
- systemd now require the kmod tool in addition to the library.
* Sun Jul 14 2013 arvidjaar@gmail.com
- use-usr-sbin-sulogin-for-emergency-service.patch
  emergency.service failed to start because sulogin is in /usr/sbin now
* Fri Jul 12 2013 mls@suse.de
- fix build with rpm-4.11.1: /etc/xdg/system/user is a symlink,
  not a directory
* Fri Jul  5 2013 crrodriguez@opensuse.org
- 0002-core-mount.c-mount_dump-don-t-segfault-if-mount-is-n.patch
  fix segfault at shutdown
- 0004-disable-the-cgroups-release-agent-when-shutting-down.patch
  disable the cgroups release agent when shutting down.
- 0005-cgroups-agent-remove-ancient-fallback-code-turn-conn.patch
  remove ancient fallback code; turn connection error into warning
- 006-suppress-status-message-output-at-shutdown-when-quie.patch
  make shutdown honour "quiet" kernel cmdline.
* Fri Jul  5 2013 crrodriguez@opensuse.org
- fix broken symlink, service is called systemd-random-seed now.
* Thu Jul  4 2013 fcrozat@suse.com
- Update to release 205:
  + two new unit types have been introduced:
  - Scope units are very similar to service units, however, are
    created out of pre-existing processes -- instead of PID 1
    forking off the processes.
  - Slice units may be used to partition system resources in an
    hierarchial fashion and then assign other units to them. By
    default there are now three slices: system.slice (for all
    system services), user.slice (for all user sessions),
    machine.slice (for VMs and containers).
  + new concept of "transient" units, which are created at runtime
    using an API and not based on configuration from disk.
  + logind has been updated to make use of scope and slice units to
    manage user sessions. Logind will no longer create cgroups
    hierchies itself but will relying on PID 1.
  + A new mini-daemon "systemd-machined" has been added which
    may be used by virtualization managers to register local
    VMs/containers. machinectl tool has been added to query
    meta-data from systemd-machined.
  + Low-level cgroup configuration options ControlGroup=,
    ControlGroupModify=, ControlGroupPersistent=,
    ControlGroupAttribute= have been removed. High-level attribute
    settings or slice units should be used instead?
  + A new bus call SetUnitProperties() has been added to alter
    various runtime parameters of a unit, including cgroup
    parameters. systemctl gained set-properties command to wrap
    this call.
  + A new tool "systemd-run" has been added which can be used to
    run arbitrary command lines as transient services or scopes,
    while configuring a number of settings via the command
    line.
  + nspawn will now inform the user explicitly that kernels with
    audit enabled break containers, and suggest the user to turn
    off audit.
  + Support for detecting the IMA and AppArmor security
    frameworks with ConditionSecurity= has been added.
  + journalctl gained a new "-k" switch for showing only kernel
    messages, mimicking dmesg output; in addition to "--user"
    and "--system" switches for showing only user's own logs
    and system logs.
  + systemd-delta can now show information about drop-in
    snippets extending unit files.
  + systemd will now look for the "debug" argument on the kernel
    command line and enable debug logging, similar to
    "systemd.log_level=debug" already did before.
  + "systemctl set-default", "systemctl get-default" has been
    added to configure the default.target symlink, which
    controls what to boot into by default.
  + "systemctl set-log-level" has been added as a convenient
    way to raise and lower systemd logging threshold.
  + "systemd-analyze plot" will now show the time the various
    generators needed for execution, as well as information
    about the unit file loading.
  + libsystemd-journal gained a new sd_journal_open_files() call
    for opening specific journal files. journactl also gained a
    new switch to expose this new functionality (useful for
    debugging).
  + systemd gained the new DefaultEnvironment= setting in
    /etc/systemd/system.conf to set environment variables for
    all services.
  + If a privileged process logs a journal message with the
    OBJECT_PID= field set, then journald will automatically
    augment this with additional OBJECT_UID=, OBJECT_GID=,
    OBJECT_COMM=, OBJECT_EXE=, ... fields. This is useful if
    system services want to log events about specific client
    processes. journactl/systemctl has been updated to make use
    of this information if all log messages regarding a specific
    unit is requested.
- Remove 0001-journal-letting-interleaved-seqnums-go.patch,
  0002-journal-remember-last-direction-of-search-and-keep-o.patch,
  0004-journald-DO-recalculate-the-ACL-mask-but-only-if-it-.patch,
  0006-systemctl-core-allow-nuking-of-symlinks-to-removed-u.patch,
  0008-service-don-t-report-alien-child-as-alive-when-it-s-.patch,
  0160-mount-when-learning-about-the-root-mount-from-mounti.patch,
  0185-core-only-attempt-to-connect-to-a-session-bus-if-one.patch,
  Start-ctrl-alt-del.target-irreversibly.patch,
  systemctl-does-not-expand-u-so-revert-back-to-I.patch: merged
  upstream.
- Regenerate patches 1007-physical-hotplug-cpu-and-memory.patch,
  1008-add-msft-compability-rules.patch,
  Revert-service-drop-support-for-SysV-scripts-for-the-early.patch,
  fix-support-for-boot-prefixed-initscript-bnc-746506.patch,
  handle-SYSTEMCTL_OPTIONS-environment-variable.patch,
  handle-numlock-value-in-etc-sysconfig-keyboard.patch,
  insserv-generator.patch,
  optionally-warn-if-nss-myhostname-is-called.patch,
  remain_after_exit-initscript-heuristic-and-add-new-LSB-hea.patch,
  restore-var-run-and-var-lock-bind-mount-if-they-aren-t-sym.patch,
  service-flags-sysv-service-with-detected-pid-as-RemainAfte.patch.
- Update macros.systemd.upstream with latest upstream revision.
* Mon Jul  1 2013 fcrozat@suse.com
- Replace
  parse-etc-insserv.conf-and-adds-dependencies-accordingly.patch
  patch with insserv-generator.patch: no longer patch systemd main
  binary but generate systemd drop-in files using a generator, for
  insserv.conf compatibility.
* Mon Jul  1 2013 coolo@suse.com
- systemd-mini doesn't need dbus-1, only dbus-1-devel
* Wed Jun 26 2013 rmilasan@suse.com
- Re-add fixed udev MSFT compability rules (bnc#805059, bnc#826528).
  add: 1008-add-msft-compability-rules.patch
* Wed Jun 26 2013 rmilasan@suse.com
- Drop 1007-add-msft-compability-rules.patch, breaks boot and links
  in /dev/disk/by-id, will need proper rework (bnc#826528).
* Mon Jun 24 2013 crrodriguez@opensuse.org
- 0160-mount-when-learning-about-the-root-mount-from-mounti.patch Another
  case where we are trying to umount the root directory at shutdown.
- 0185-core-only-attempt-to-connect-to-a-session-bus-if-one.patch
  only attempt to connect to a session bus if one likely exists
* Fri Jun 21 2013 rmilasan@suse.com
- Automatically online CPUs/Memory on CPU/Memory hotplug add events
  (bnc#703100, fate#311831).
  add: 1008-physical-hotplug-cpu-and-memory.patch
* Wed Jun 19 2013 mhrusecky@suse.com
- Dropped backward compatibility
- Added check for upstream rpm macros changes
* Tue Jun 18 2013 mhrusecky@suse.com
- Split out RPM macros into separate package to simplify dependencies
* Tue Jun 18 2013 crrodriguez@opensuse.org
- 0001-journal-letting-interleaved-seqnums-go.patch and
  0002-journal-remember-last-direction-of-search-and-keep-o.patch
  fix possible infinite loops in the journal code, related to
  bnc #817778
* Sun Jun 16 2013 jengelh@inai.de
- Explicitly list libattr-devel as BuildRequires
- More robust make install call. Remove redundant %%clean section.
* Thu Jun 13 2013 sbrabec@suse.cz
- Cleanup NumLock setting code
  (handle-numlock-value-in-etc-sysconfig-keyboard.patch).
* Wed Jun 12 2013 fcrozat@suse.com
- Only apply 1007-add-msft-compability-rules.patch when not
  building systemd-mini.
* Tue Jun 11 2013 rmilasan@suse.com
- Add udev MSFT compability rules (bnc#805059).
  add: 1007-add-msft-compability-rules.patch
- Add sg3_utils requires, need it by 61-msft.rules (bnc#805059).
- Clean-up spec file, put udev patches after systemd patches.
- Rebase patches so they would apply nicely.
* Tue Jun 11 2013 crrodriguez@opensuse.org
- 0004-journald-DO-recalculate-the-ACL-mask-but-only-if-it-.patch
  fixes :
  * systemd-journald[347]: Failed to set ACL on
  /var/log/journal/11d90b1c0239b5b2e38ed54f513722e3/user-1000.journal,
  ignoring: Invalid argument
- 006-systemctl-core-allow-nuking-of-symlinks-to-removed-u.patch
  systemctl disable should remove dangling symlinks.
- 0008-service-don-t-report-alien-child-as-alive-when-it-s-.patch
  alien childs are reported as alive when they are really dead.
* Wed May 29 2013 fcrozat@suse.com
- Update to release 204:
  + systemd-nspawn creates etc/resolv.conf in container if needed.
  + systemd-nspawn will store metadata about container in container
    cgroup including its root directory.
  + cgroup hierarchy has been reworked, all objects are now suffxed
    (with .session for user sessions, .user for users, .nspawn for
    containers). All cgroup names are now escaped to preven
    collision of object names.
  + systemctl list-dependencies gained --plain, --reverse, --after
    and --before switches.
  + systemd-inhibit shows processes name taking inhibitor lock.
  + nss-myhostname will now resolve "localhost" implicitly.
  + .include is not allowed recursively anymore and only in unit
    files. Drop-in files should be favored in most cases.
  + systemd-analyze gained "critical-chain" command, to get slowest
    chain of units run during boot-up.
  + systemd-nspawn@.service has been added to easily run nspawn
    container for system services. Just start
    "systemd-nspawn@foobar.service" and container from
    /var/lib/container/foobar" will be booted.
  + systemd-cgls has new --machine parameter to list processes from
    one container.
  + ConditionSecurity= can now check for apparmor and SMACK.
  + /etc/systemd/sleep.conf has been introduced to configure which
    kernel operation will be execute when "suspend", "hibernate" or
    "hybrid-sleep" is requrested. It allow new kernel "freeze"
    state to be used too. (This setting won't have any effect if
    pm-utils is installed).
  + ENV{SYSTEMD_WANTS} in udev rules will now implicitly escape
    passed argument if applicable.
- Regenerate some patches for this new release.
- Rename hostname-setup-shortname.patch to
  ensure-shortname-is-set-as-hostname-bnc-820213.patch to  be git
  format-patch friendly.
- Update apply-ACL-for-nvidia-device-nodes.patch to apply ACL to
  /dev/nvidia* (bnc#808319).
- Remove Ensure-debugshell-has-a-correct-value.patch, doable with a
  configure option.
- Add systemctl-does-not-expand-u-so-revert-back-to-I.patch: avoids
  expansion errors.
- Add Start-ctrl-alt-del.target-irreversibly.patch: ctrl-alt-del
  should be irreversible for reliability.
* Tue May 28 2013 crrodriguez@opensuse.org
- Drop Add-bootsplash-handling-for-password-dialogs.patch bootsplash
  support has been removed from the kernel.
- Drop ensure-systemd-udevd-is-started-before-local-fs-pre-for-lo.patch
  fixed in systemd v199, commit 89d09e1b5c65a2d97840f682e0932c8bb499f166
- Apply rules-add-lid-switch-of-ARM-based-Chromebook-as-a-power-sw.patch
  only on ARM, patch rejected upstream because is too generic.
- no such define TARGET_SUSE exists but it is used in
  Revert-service-drop-support-for-SysV-scripts-for-the-early.patch
  use HAVE_SYSV_COMPAT instead.
* Fri May 24 2013 fcrozat@suse.com
- Do no ship defaults for sysctl, they should be part of aaa_base
  (currently in procps).
- Add hostname-setup-shortname.patch: ensure shortname is set as
  hostname (bnc#820213).
* Fri May 17 2013 fcrozat@suse.com
- Rebase
  parse-etc-insserv.conf-and-adds-dependencies-accordingly.patch to
  fix memory corruption (thanks to Michal Vyskocil) (bnc#820454).
* Fri May 17 2013 fcrozat@suse.com
- Add sysctl-handle-boot-sysctl.conf-kernel_release.patch: ensure
  /boot/sysctl.conf-<kernel_release> is handled (bnc#809420).
* Wed May 15 2013 fcrozat@suse.com
- Update handle-SYSTEMCTL_OPTIONS-environment-variable.patch: don't
  free variable whose content is still be used (bnc#819970).
* Tue May 14 2013 fcrozat@suse.com
- Add configure flags to ensure boot.local/halt.local are run on
  startup/shutdown.
* Mon May 13 2013 rmilasan@suse.com
- Fix firmware loading by enabling --with-firmware-path (bnc#817551).
* Mon Apr 29 2013 dschung@cs.uni-kl.de
- Fix systemd-sysv-convert, so empty runlevel folders don't lead
  to "line 44: [: too many arguments"
* Fri Apr 26 2013 fcrozat@suse.com
- Fix handle-etc-HOSTNAME.patch to properly set hostname at startup
  when using /etc/HOSTNAME.
* Thu Apr 25 2013 rmilasan@suse.com
- Rename remaning udev patches (clean-up).
- Generate %%{_libexecdir}/modules-load.d/sg.conf so we load sg module at
  boot time not from udev (bnc#761109).
- Drop unused patches:
  1001-Reinstate-TIMEOUT-handling.patch
  1005-udev-fix-sg-autoload-regression.patch
  1026-re-add-persistent-net.patch
* Tue Apr 23 2013 fcrozat@suse.com
- Use drop-in file to fix bnc#804158.
* Tue Apr 23 2013 coolo@suse.com
- add some more conflicts to make bootstrap work
* Mon Apr 22 2013 fcrozat@suse.com
- Do not provide %%{release} for systemd-analyze
- Add more conflicts to -mini packages
- Disable Predictable Network interface names until it has been
  reviewed by network team, with /usr/lib/tmpfiles.d/network.conf.
- Don't package /usr/lib/firmware/update (not used)
* Sun Apr 21 2013 crrodriguez@opensuse.org
- Fix packaging error, there is no syslog.target anymore
  do not pretend there is one.
* Fri Apr 19 2013 fcrozat@suse.com
- Update to release 202:
  + 'systemctl list-jobs' got some polishing. '--type=' argument
    may now be passed more than once. 'systemctl list-sockets' has
    been added.
  + systemd gained a new unit 'systemd-static-nodes.service'
    that generates static device nodes earlier during boot, and
    can run in conjunction with udev.
  + systemd-nspawn now places all containers in the new /machine
    top-level cgroup directory in the name=systemd hierarchy.
  + bootchart can now store its data in the journal.
  + journactl can now take multiple --unit= and --user-unit=
    switches.
  + The cryptsetup logic now understands the "luks.key=" kernel
    line switch. If a configured key file is missing, it
    will fallback to prompting the user.
- Rebase some patches
- Update handle-SYSTEMCTL_OPTIONS-environment-variable.patch to
  properly handle SYSTEMCTL_OPTIONS
* Fri Apr 19 2013 max@suse.com
- Fix regression in the default for tmp auto-deletion
  (systemd-tmp-safe-defaults.patch, FATE#314974).
* Fri Apr 12 2013 fcrozat@suse.com
- Update to release 201:
  + udev now supports different nameng policies for network
    interface for predictable names.
  + udev gained support for loading additional device properties
    from an indexed database. %%udev_hwdb_update macro should be
    used by packages adding entries to this database.
  + Journal gained support for "Message Catalog", indexed database
    to link up additional information with journal entries.
    %%journal_catalog_update macro should be used by packages adding
    %%entries to this database.
  + "age" field for tmpfiles entries can be set to 0, forcing
    removal of files matching this entry.
  + coredumpctl gained "gdb" verb to invoke gdb on selected
    coredump.
  + New rpm macros has been added: %%udev_rules_update(),
    %%_udevhwdbdir, %%_udevrulesdir, %%_journalcatalogdir,
    %%_tmpfilesdir, %%_sysctldir.
  + In service files, %%U can be used for configured user name of
    the service.
  + nspawn can be invoked without a controlling TTY.
  + systemd and nspawn can accept socket file descriptors when
    started for socket activation. This allow socket activated
    nspawn containers.
  + logind can now automatically suspend/hibernate/shutdown system
    on idle.
  + ConditionACPower can be used in unit file to detect if AC power
    source is connected or if system is on battery power.
  + EnvironmentFile= in unit files supports file globbing.
  + Behaviour of PrivateTmp=, ReadWriteDirectories=,
    ReadOnlyDirectories= and InaccessibleDirectories= has
    changed. The private /tmp and /var/tmp directories are now
    shared by all processes of a service (which means
    ExecStartPre= may now leave data in /tmp that ExecStart= of
    the same service can still access). When a service is
    stopped its temporary directories are immediately deleted
    (normal clean-up with tmpfiles is still done in addition to
    this though).
  + Resource limits (as exposed by cgroup controlers) can be
    controlled dynamically at runtime for all units, using
    "systemctl set-cgroup-attr foobar.server cgroup.attribute
    value". Those settings are stored persistenly on disk.
  + systemd-vconsole-setup will now copy all fonts settings to all
    allocated VTs.
  + timedated now exposes CanNTP property to indicate if a local
    NTP service is available.
  + pstore file system is mounted by default, if available.
  + SMACK policies are loaded at early boot, if available.
  + Timer units now support calendar time events.
  + systemd-detect-virt detect xen PVs.
  + Some distributions specific LSB targets has been dropped:
    $x-display-manager, $mail-transfer-agent,
    $mail-transport-agent, $mail-transfer-agent, $smtp, $null. As
    well mail-transfer-agent.target and syslog.target has been
    removed.
  + systemd-journal-gatewayd gained SSL support and now runs as
    unprivileged user/group
    "systemd-journal-gateway:systemd-journal-gateway"
  + systemd-analyze will read, when available, boot time
    performance from EFI variable from boot loader supporting it.
  + A new generator for automatically mounting EFI System Partition
    (ESP) to /boot (if empty and no other file system has been
    configured in fstab for it).
  + logind will now send out PrepareForSleep(false) out
    unconditionally, after coming back from suspend.
  + tmpfiles gained a new "X" line type, that allows
    configuration of files and directories (with wildcards) that
    shall be excluded from automatic cleanup ("aging").
  + udev default rules set the device node permissions now only
    at "add" events, and do not change them any longer with a
    later "change" event.
  + A new bootctl tool has been added that is an interface for
    certain EFI boot loader operations.
  + A new tool kernel-install has been added to install kernel
    images according to Boot Loader Specification.
  + A new tool systemd-activate can be used to test socket
    activation.
  + A new group "systemd-journal" is now owning journal files,
    replacing "adm" group.
  + journalctl gained "--reverse" to show output in reverse order,
    "--pager-end" to jump at the end of the journal in the
    pager (only less is supported) and "--user-unit" to filter for
    user units.
  + New unit files has been addedto ease for systemd usage in
    initrd.
  + "systemctl start" now supports "--irreversible" to queue
    operations which can be reserved. It is now used to make
    shutdown requests more robust.
  + Auke Kok's bootchart has been merged and relicensed to
    LGPLv2.1+.
  + nss-myhostname has been merged in systemd codebase.
  + some defaults sysctl values are now set by default: the safe
    sysrq options are turned on, IP route verification is turned
    on, and source routing disabled. The recently added hardlink
    and softlink protection of the kernel is turned on.
  + Add support for predictable network naming logic. It can be
    turned off with kernel command line switch: net.ifnames=0
  + journald will now explicitly flush journal files to disk at the
    latest 5 min after each write and will mark file offline until
    next read. This should increase reliability in case of crash.
  + remote-fs-setup.target target has been added to pull in
    specific services when at least one remote file system is to be
    mounted.
  + timers.target and paths.target have been added as canonical
    targets to pull user timer and path units, similar to
    sockets.targets.
  + udev daemon now sets default number of worker processes in
    parallel based on number of CPUs instead of RAM.
  + Most unit file settings which takes likst of items can now be
  reset by assigning empty string to them, using drop-in.
  + Add support for drop-in configuration file for units.
  + Most unit file settings which takes likst of items can now be
    reset by assigning empty string to them, using drop-in.
  + improve systemg-cgtop output.
  + improve 'systemctl status' output for socket, drop-in for units.
  + 'hostnamectl set-hostname' allows setting FQDN hostnames.
  + fractional time intervals are now parsed properly.
  + localectl can list available X11 keymaps.
  + systemd-analyze dot can filter for specific units and has been
    rewritten in C.
  + systemctl gained "list-dependencies" command.
  + Inhibitors are now honored no only in GNOME.
- Many patches has been dropped, being merged upstream.
- Many patches has been renamed and regenerated with git, to have
  consistent naming, authorship and comments embedded.
- Add
  Revert-service-drop-support-for-SysV-scripts-for-the-early.patch:
  re-add support for boot.* initscripts until they are all migrated
  to systemd unit files.
- Merge patches for nss-myhostname package to this package.
* Fri Apr 12 2013 rschweikert@suse.com
- Add chromebook lid switch as a power switch to logind rule to
  enable suspend on lid close
* Mon Apr  8 2013 fcrozat@suse.com
- Add improve-readahead-spinning.patch: improve readahead
  performance on spinning media with ext4.
- Add fix-journal-vacuum-logic.patch: fix vacuum logic in journal
  (bnc#789589).
- Add fix-lsb-provides.patch: ensure LSB provides are correctly
  handled if also referenced as dependencies (bnc#809646).
- Add fix-loopback-mount.patch: ensure udevd is started (and
  therefore static devices are created) before mounting
  (bnc#809820).
- Update systemd-sysv-convert to search services files in new
  location (bnc#809695).
- Add logind-nvidia-acl.diff: set ACL on nvidia devices
  (bnc#808319).
- Add do-no-isolate-on-fsck-failure.patch: do not turn off services
  if fsck fails (bnc#812874)
- Add wait-for-processes-killed.patch: wait for processes killed by
  SIGTERM before killing them with SIGKILL.
- Update systemctl-options.patch to only apply SYSTEMCTL_OPTIONS to
  systemctl command (bnc#801878).
* Tue Apr  2 2013 sbrabec@suse.cz
- Fixed disabling CapsLock and enabling NumLock (bnc#746595,
  0001-handle-disable_caplock-and-compose_table-and-kbd_rat.patch,
  systemd-numlock-suse.patch).
- Explicitly require libgcrypt-devel to fix build failure.
* Thu Mar 28 2013 rmilasan@suse.com
- udev: ensure that the network interfaces are renamed even if they
  exist (bnc#809843).
  add: 1027-udev-always-rename-network.patch
* Wed Mar 20 2013 rmilasan@suse.com
- udev: re-add persistent network rules (bnc#809843).
  add: 1026-re-add-persistent-net.patch
- rebase all patches, ensure that they apply properly.
* Thu Feb 21 2013 fcrozat@suse.com
- Add rbind-mount.patch: handle rbind mount points correctly
  (bnc#804575).
* Tue Feb 19 2013 fcrozat@suse.com
- Ensure journal is flushed on disk when systemd-logger is
  installed for the first time.
- Add improve-journal-perf.patch: improve journal performance on
  query.
- Add support-hybrid-suspend.patch: add support for hybrid suspend.
- Add forward-to-pmutils.patch: forward suspend/hibernation calls
  to pm-utils, if installed (bnc#790157).
* Tue Feb 19 2013 rmilasan@suse.com
- udev: usb_id: parse only 'size' bytes of the 'descriptors' buffer
  add: 1024-udev-usb_id-parse-only-size-bytes-of-the-descriptors.patch
- udev: expose new ISO9660 properties from libblkid
  add: 1025-udev-expose-new-ISO9660-properties-from-libblkid.patch
* Mon Feb 18 2013 jengelh@inai.de
- Create getty@tty1.service to restore traditional SUSE behavior
  of not clearing tty1. (bnc#804158)
- Better use of find -exec
* Fri Feb 15 2013 fcrozat@suse.com
- Add early-sync-shutdown.patch: start sync just when
  shutdown.target is beginning
- Update parse-multiline-env-file.patch to better handle continuing
  lines.
- Add handle-HOSTNAME.patch: handle /etc/HOSTNAME (bnc#803653).
- Add systemctl-print-wall-on-if-successful.patch: only print on
  wall if successful.
- Add improve-bash-completion.patch: improve bash completion.
* Fri Feb 15 2013 lnussel@suse.de
- disable nss-myhostname warning (bnc#783841)
  => disable-nss-myhostname-warning-bnc-783841.diff
* Wed Feb 13 2013 rmilasan@suse.com
- rework patch:
  1020-usb_id-some-strange-devices-have-a-very-bogus-or-strage-serial.patch
- udev: use unique names for temporary files created in /dev.
  add: 1022-udev-use-unique-names-for-temporary-files-created-in.patch
- cdrom_id: add data track count for bad virtual drive.
  add: 1023-cdrom_id-add-data-track-count-for-bad-virtual-drive.patch
* Tue Feb 12 2013 rmilasan@suse.com
- usb_id: ensure we have a valid serial number as a string (bnc#779493).
  add: 1020-usb_id-some-strange-devices-have-a-very-bogus-or-strage-serial.patch
- cdrom_id: created links for the default cd/dvd drive (bnc#783054).
  add: 1021-create-default-links-for-primary-cd_dvd-drive.patch
* Fri Feb  1 2013 fcrozat@suse.com
- Add cryptsetup-accept-read-only.patch: accept "read-only" in
  addition to "readonly" in crypttab
- Update parse-multiline-env-file.patch to correctly handle
  commented lines (bnc#793411)
* Tue Jan 29 2013 rmilasan@suse.com
- udev: Fix device matching in the accelerometer
  add: 1019-udev-Fix-device-matching-in-the-accelerometer.patch
- keymap: add aditional support for some keyboard keys
  add: 1018-keymap-add-aditional-support.patch
- journalctl: require argument for --priority
  add: journalctl-require-argument-for-priority
- dropped useless patches:
  libudev-validate-argument-udev_enumerate_new.patch
  kmod-fix-builtin-typo.patch
- rename udev-root-symlink.service to systemd-udev-root-symlink.service.
- fix in udev package missing link in basic.target.wants for
  systemd-udev-root-symlink.service
* Mon Jan 28 2013 fcrozat@suse.com
- Add tmpfiles-X-type.patch: allow to clean directories with
  removing them.
- Add systemd-fix-merge-ignore-dependencies.patch: fix merging with
  - -ignore-dependencies waiting for dependencies (bnc#800365).
- Update systemd-numlock-suse.patch: udev-trigger.service is now
  called systemd-udev-trigger.service.
- Add improve-man-environment.patch: improve manpage regarding
  Environment value.
* Tue Jan 22 2013 fcrozat@suse.com
- Add systemctl-options.patch: handle SYSTEMCTL_OPTIONS internaly
  (bnc#798620).
- Update crypt-loop-file.patch to correctly detect crypto loop
  files (bnc#799514).
- Add journalctl-remove-leftover-message.patch: remove debug
  message in systemctl.
- Add job-avoid-recursion-when-cancelling.patch: prevent potential
  recursion when cancelling a service.
- Add sysctl-parse-all-keys.patch: ensure sysctl file is fully
  parsed.
- Add journal-fix-cutoff-max-date.patch: fix computation of cutoff
  max date for journal.
- Add reword-rescue-mode-hints.patch: reword rescue prompt.
- Add improve-overflow-checks.patch: improve time overflow checks.
- Add fix-swap-behaviour-with-symlinks.patch: fix swap behaviour
  with symlinks.
- Add hostnamectl-fix-set-hostname-with-no-argument.patch: ensure
  hostnamectl requires an argument when called with set-hostname
  option.
- Add agetty-overrides-term.patch: pass correctly terminal type to
  agetty.
- Add check-for-empty-strings-in-strto-conversions.patch: better
  check for empty strings in strto* conversions.
- Add strv-cleanup-error-path-loops.patch: cleanup strv on error
  path.
- Add cryptsetup-handle-plain.patch: correctly handle "plain"
  option in cryptsetup.
- Add fstab-generator-improve-error-message.patch: improve error
  message in fstab-generator.
- Add delta-accept-t-option.patch: accept -t option in
  systemd-delta.
- Add highlight-ordering-cycle-deletions.patch: highlight ordering
  cycle deletions in logs.
- Add core-interpret-escaped-semicolon-as-escaped.patch: accept \;
  in ExecStart.
- Add hostnamectl-fix-parsing-no-ask-password.patch: accept
  no-ask-password in hostnamectl.
- Add systemd-cgls-fix-piping-output.patch: fix piping output of
  systemd-cgls.
- Add core-load-fragment-improve-error-message.patch: improve error
  message when parsing fragments.
- Add fix-potential-bad-mem-access.patch: fix potential bad memory
  access.
- Add socket-improve-error-message.patch: improve error message in
  socket handling.
- Add journal-send-always-send-syslog_identifier.patch: always send
  syslog_identifier if available for journal.
- Add crypsetup-handle-nofail.patch: handle nofail in cryptsetup.
- Add crypsetup-generator-state-file-name-in-error-message.patch:
  add filename in error message from crypsetup-generator.
- Add fstab-generator-error-message-on-duplicates.patch: improve
  error message on duplicate in fstab-generator.
- Add systemctl-verbose-message-on-missing-install.patch: reword
  missing install error message in systemctl.
- Add shutdown-improvements.patch: various improvements at
  shutdown.
- Add localectl-fix-assertion.patch: fix assertion in localectl.
- Add path-util-fix-potential-crash.patch: fix potential crash in
  path-util.
- Add coredumpctl-fix-crash.patch: fix crash in coredumpctl.
- Add socket-verbose-error-message.patch: add more verbose error
  message in socket handling.
- Add pam-properly-handle-ssh-logins-without-pam-tty-field.patch:
  handle properly ssh-logins without pam tty field.
- Add fstab-generator-properly-detect-bind-mounts.patch: properly
  detect bind-mounts in fstab-generator.
- Add localectl-support-systems-without-locale-archive.patch:
  localectl now supports systemd without locale-archive file.
- Add logind-capability-making-seats-without-fb.patch: allows
  capability of making seats without fb.
- Add service-forking-ignore-exit-status-main-process.patch: ignore
  exit-statis of main process when forking, if specified in unit
  file.
- Add systemctl-no-assert-on-reboot-without-dbus.patch: don't
  assert on reboot if dbus isn't there.
- Add logind-ignore-non-tty-non-x11-session-on-shutdown.patch:
  ignore non tty non-x11 session on shutdown.
- Add journalctl-quit-on-io-error.patch: fix journalctl quit on io
  error.
- Add do-not-make-sockets-dependent-on-lo.patch: do not make
  sockets dependent on lo interface.
- Add shutdown-dont-force-mnt-force-on-final-umount.patch: don't
  force MNT_FORCE on final umount at shutdown.
- Add shutdown-ignore-loop-devices-without-backing-file.patch:
  ignore loop devices without backing file at shutdown.
- Add fix-bad-mem-access.patch: fix bad memory access
- Add parse-multiline-env-file.patch: correctly parse multiline
  environment files (bnc#793411).
* Thu Jan 10 2013 fcrozat@suse.com
- Add multiple-sulogin.patch: allows multiple sulogin instance
  (bnc#793182).
* Wed Jan  9 2013 rmilasan@suse.com
- udev: path_id - handle Hyper-V devices
  add: 1008-udev-path_id-handle-Hyper-V-devices.patch
- keymap: Update the list of Samsung Series 9 models
  add: 1009-keymap-Update-the-list-of-Samsung-Series-9-models.patch
- keymap: Add Samsung 700T
  add: 1010-keymap-Add-Samsung-700T.patch
- libudev: avoid leak during realloc failure
  add: 1011-libudev-avoid-leak-during-realloc-failure.patch
- libudev: do not resolve $attr{device} symlinks
  add: 1012-libudev-do-not-resolve-attr-device-symlinks.patch
- libudev: validate 'udev' argument to udev_enumerate_new()
  add: 1013-libudev-validate-udev-argument-to-udev_enumerate_new.patch
- udev: fix whitespace
  add: 1014-udev-fix-whitespace.patch
- udev: properly handle symlink removal by 'change' event
  add: 1015-udev-properly-handle-symlink-removal-by-change-event.patch
- udev: builtin - do not fail builtin initialization if one of
  them returns an error
  add: 1016-udev-builtin-do-not-fail-builtin-initialization-if-o.patch
- udev: use usec_t and now()
  add: 1017-udev-use-usec_t-and-now.patch
* Tue Jan  8 2013 rmilasan@suse.com
- udevd: add missing ':' to getopt_long 'e'.
  add: 1007-udevd-add-missing-to-getopt_long-e.patch
- clean up systemd.spec, make it easy to see which are udev and
  systemd patches.
- make 'reload' and 'force-reload' LSB compliant (bnc#793936).
* Tue Dec 11 2012 crrodriguez@opensuse.org
- detect-btrfs-ssd.patch: Fix btrfs detection on SSD.
- timedated-donot-close-bogus-dbus-connection.patch: Avoid
  closing an non-existent dbus connection and getting assertion
  failures.
* Mon Dec 10 2012 coolo@suse.com
- add conflicts between udev-mini and udev-mini-devel to libudev1
* Thu Dec  6 2012 crrodriguez@opensuse.org
- revert-of-9279749b84cc87c7830280b7895a48bed03c9429.patch:
  do not consider failure to umount / and /usr an error.
* Wed Dec  5 2012 fcrozat@suse.com
- Add fix-devname-prefix.patch: fix modules.devname path, it isn't
  in /usr.
- Move post script to fix symlinks in /etc/systemd/system to a
  trigger to run it after old systemd is uninstalled.
* Tue Dec  4 2012 fcrozat@suse.com
- Add fix-debugshell.patch: use /bin/bash if sushell isn't
  installed (bnc#789052).
- Add handle-root-uses-lang.patch: handle ROOT_USES_LANG=ctype
  (bnc#792182).
- Ensure libudev1 and libudev-mini1 conflicts.
* Thu Nov 22 2012 rmilasan@suse.com
- Fix creation of /dev/root link.
* Tue Nov 20 2012 fcrozat@suse.com
- Add remount-ro-before-unmount.patch: always remount read-only
  before unmounting in final shutdown loop.
- Add switch-root-try-pivot-root.patch: try pivot_root before
  overmounting /
* Tue Nov 20 2012 fcrozat@suse.com
- links more manpages for migrated tools (from Christopher
  Yeleighton).
- disable boot.localnet service, ypbind service will do the right
  thing now (bnc#716746)
- add xdm-display-manager.patch: pull xdm.service instead of
  display-manager.service (needed until xdm initscript is migrated
  to native systemd service).
- Add fix-permissions-btmp.patch: ensure btmp is owned only by root
  (bnc#777405).
- Have the udev package create a tape group, as referenced by
  50-udev-default.rules and 60-persistent-storage-tape.rules
  (DimStar).
- Add fix-bad-memory-access.patch: fix crash in journal rotation.
- Add fix-dbus-crash.patch: fix D-Bus caused crash.
- Add sync-on-shutdown.patch: ensure sync is done when initiating
  shutdown.
- Add mount-efivars.patch: mount efivars if booting on UEFI.
* Thu Nov 15 2012 fcrozat@suse.com
- Ship a empty systemd-journald initscript in systemd-logger to
  stop insserv to complain about missing syslog dependency.
- Update
  0001-service-Fix-dependencies-added-when-parsing-insserv..patch
  with bug fixes from Debian.
* Wed Nov 14 2012 fcrozat@suse.com
- /var/log/journal is now only provided by systemd-logger (journal
  won't be persistent for people using another syslog
  implementation).
- install README in /var/log (in systemd-logger) and /etc/init.d
- create adm group when installing systemd.
- fix path in udev-root-symlink.systemd.
- Enforce Requires(post) dependency on libudev in main systemd
  package (help upgrade).
- Ensure configuration is reloaded when upgrading and save random
  seed when installing.
- Create /lib/udev symlink, if we do a fresh install.
- Add fix-build-glibc217.patch: fix build with latest glibc.
- Add libgcrypt.m4: copy of autoconf macro from libgcrypt, only
  used to bootstrap systemd-mini.
* Tue Nov  6 2012 coolo@suse.com
- adding a package systemd-logger that blocks syslog implementations
  from installation to make an installation that only uses the journal
* Mon Nov  5 2012 fcrozat@suse.com
- Don't hardcode path for systemctl in udev post script.
- Ensure systemd-udevd.service is shadowing boot.udev when booting
  under systemd.
- Fix udev daemon upgrade under both systemd and sysvinit.
- Add fix-logind-pty-seat.patch: fix logind complaining when doing
  su/sudo in X terminal.
* Sat Nov  3 2012 coolo@suse.com
- add libudev1 to baselibs.conf
* Fri Nov  2 2012 coolo@suse.com
- udev is GPL-2.0, the rest remains LGPL-2.1+ (bnc#787824)
* Mon Oct 29 2012 fcrozat@suse.com
- Add var-run-lock.patch: make sure /var/run and /var/lock are
  handled as bind mount if they aren't symlinks.
- Update storage-after-cryptsetup.patch with new systemctl path.
- Migrate broken symlinks in /etc/systemd/system due to new systemd
  location.
* Fri Oct 26 2012 fcrozat@suse.com
- Update to release 195:
  + journalctl agained --since and --until, as well as filtering
    for units with --unit=/-u.
  + allow ExecReload properly for Type=oneshot (needed for
    iptables.service, rpc-nfsd.service).
  + journal daemon supports time-based rotation and vaccuming.
  + journalctl -F allow to list all values of a certain field in
    journal database.
  + new commandline clients for timedated, locald and hostnamed
  + new tool systemd-coredumpctl to list and extract coredumps from
    journal.
  + improve gatewayd: follow mode, filtering, support for
    HTML5/JSON Server-Sent-Events.
  + reload support in SysV initscripts is now detected when file is
    parted.
  + "systemctl status --follow" as been removed, use "journalctl -fu
    instead"
  + journald.conf RuntimeMinSize and PersistentMinSize settings
    have been removed.
- Add compatibility symlink for systemd-ask-password and systemctl
  in /bin.
* Thu Oct 18 2012 fcrozat@suse.com
- Create and own more systemd drop-in directories.
* Tue Oct 16 2012 fcrozat@suse.com
- Improve mini packages for bootstrapping.
- do not mount /tmp as tmpfs by default.
* Tue Oct 16 2012 fcrozat@suse.com
- Fix install script when there is no inittab
* Mon Oct 15 2012 fcrozat@suse.com
- Create a systemd-mini specfile to prevent cycle in bootstrapping
* Thu Oct  4 2012 fcrozat@suse.com
- udev and its subpackages are now generated by systemd source
  package.
- migrate udev and systemd to /usr
- Update to version 194:
  + if /etc/vconsole.conf is non-existent or empty and if
    /etc/sysconfig/console:CONSOLE_FONT (resp
    /etc/sysconfig/keyboard:KEYTABLE) set, console font (resp
    keymap) is not modified.
- Changes from version 44 to 193:
  + journalctl gained --cursor= to show entries starting from a
    specified location in journal.
  + Size limit enforced to 4K for fields exported with "-o json" in
    journalctl. Use --all to disable this behavior.
  + Optional journal gateway daemon
    (systemd-journal-gatewayd.service) to access journal via HTTP
    and JSON. Use "wget http://localhost:19531/entries" to get
    /var/log/messages compatible format and
    'curl -H"Accept: application/json"
    http://localhost:19531/entries' for JSON formatted content.
    HTML5 static page is also available as explained on
    http://0pointer.de/public/journal-gatewayd
  + do not mount cpuset controler, doesn't work well by default
    ATM.
  + improved nspawn behaviour with /etc/localtime
  + journald logs its maximize size on disk
  + multi-seat X wrapper (partially merged in upstream X server).
  + HandleSleepKey has been splitted into HandleSuspendKey and
    HandleHibernateKey.
  + systemd and logind now handle system sleep states, in
    particular suspending and hibernating.
  + new cgroups are mounted by default (cpu, cpuacct,
    net_cls, net_pri)
  + sync at shutdown is now handled by kernel
  + imported journalctl output (colors, filtering, pager, bash
    completion).
  + suffix ".service" may now be ommited on most systemctl command
    involving service unit names.
  + much improved nspawn containers support.
  + new conditions added : ConditionFileNotEmpty, ConditionHost,
    ConditionPathIsReadWrite
  + tmpfiles "w" supports file globbing
  + logind handles lid switch, power and sleep keys all the time,
    unless systemd-inhibit
  - -what=handle-power-key:handle-sleep-key:handle-lid-switch is
    run by Desktop Environments.
  + support for reading structured kernel message is used by
    default (need kernel >= 3.5). /proc/kmsg is now used only by
    classic syslog daemons.
  + Forward Secure Sealing is now support for Journal files.
  + RestartPrevenExitStatus and SuccessExitStatus allow configure
    of exit status (exit code or signal).
  + handles keyfile-size and keyfile-offset in /etc/crypttab.
  + TimeoutSec settings has been splitted into TimeoutStartSec and
    TimeoutStopSec.
  + add SystemCallFilters option to add blacklist/whitelist to
    system calls, using SECCOMP mode 2 of kernel >= 3.5.
  + systemctl udevadm info now takes a /dev or /sys path as argument:
  - udevadm info /dev/sda
  + XDG_RUNTIME_DIR now uses numeric UIDs instead of usernames.
  + systemd-loginctl and systemd-journalctl have been renamed
    to loginctl and journalctl to match systemctl.
  + udev: RUN+="socket:..."  and udev_monitor_new_from_socket() is
    no longer supported. udev_monitor_new_from_netlink() needs to
    be used to subscribe to events.
  + udev: when udevd is started by systemd, processes which are left
    behind by forking them off of udev rules, are unconditionally
    cleaned up and killed now after the event handling has finished.
    Services or daemons must be started as systemd services.
    Services can be pulled-in by udev to get started, but they can
    no longer be directly forked by udev rules.
  + For almost all files, license is now LGPL2.1+ (from previous
    GPL2.0+). Exception are some minor stuff in udev (will be
    changed to LGPL2.1 eventually) and MIT license sd-daemon.[ch]
    library.
  + var-run.mount and var-lock.mount are no longer provided
    (should be converted to symlinks).
  + A new service type Type=idle to avoid ugly interleaving of
    getty output and boot status messages.
  + systemd-delta has been added, a tool to explore differences
    between user/admin configuration and vendor defaults.
  + /tmp mouted as tmpfs by default.
  + /media is now longer mounted as tmpfs
  + GTK tool has been split off to systemd-ui package.
  + much improved documentation.
- Merge BuildRequires from udev package:
  gobject-introspection-devel, gtk-doc, libsepol-devel,
  libusb-devel, pkgconfig(blkid), pkgconfig-glib-2.0),
  pjgconfig(libcryptsetup), pkgconfig(libpci),
  pkgconfig(libqrencode), pkgconfig(libselinux),
  pkgconfig(usbutils).
- Add pkgconfig(libqrencode) and pkgconfig(libmicrohttpd)
- Merge sources from udev package: boot.udev, write_dev_root.rules,
  udev-root-symlink.systemd.
- Merge patches from udev package: numbered started from 1000):
  0001-Reinstate-TIMEOUT-handling.patch,
  0013-re-enable-by_path-links-for-ata-devices.patch,
  0014-rules-create-by-id-scsi-links-for-ATA-devices.patch,
  0026-udev-netlink-null-rules.patch,
  0027-udev-fix-sg-autoload-regression.patch.
- Remove following patches, merged upstream:
  0001-util-never-follow-symlinks-in-rm_rf_children.patch,
  fixppc.patch, logind-logout.patch, fix-getty-isolate.patch,
  fix-swap-priority.patch, improve-restart-behaviour.patch,
  fix-dir-noatime-tmpfiles.patch, journal-bugfixes.patch,
  ulimit-support.patch, change-terminal.patch,
  fix-tty-startup.patch, fix-write-user-state-file.patch,
  fix-analyze-exception.patch, use_localtime.patch,
  journalctl-pager-improvement.patch,
  avoid-random-seed-cycle.patch,
  0001-add-sparse-support-to-detect-endianness-bug.patch,
  drop-timezone.patch.
- Rebase the following patches:
  0001-Add-bootsplash-handling-for-password-dialogs.patch,
  0001-handle-disable_caplock-and-compose_table-and-kbd_rat.patch,
  0001-service-Fix-dependencies-added-when-parsing-insserv..patch,
  0001-service-flags-sysv-service-with-detected-pid-as-Rema.patch,
  crypt-loop-file.patch,
  delay-fsck-cryptsetup-after-md-lvm-dmraid.patch,
  dm-lvm-after-local-fs-pre-target.patch, fastboot-forcefsck.patch,
  fix-enable-disable-boot-initscript.patch, modules_on_boot.patch,
  new-lsb-headers.patch, storage-after-cryptsetup.patch,
  support-suse-clock-sysconfig.patch, support-sysvinit.patch,
  sysctl-modules.patch, systemd-numlock-suse.patch, tty1.patch.
* Thu Aug 23 2012 fcrozat@suse.com
- Add use_localtime.patch: use /etc/localtime instead of
  /etc/timezone (bnc#773491)
- Add support-suse-clock-sysconfig.patch: read SUSE
  /etc/sysconfig/clock file.
- Add drop-timezone.patch: drop support for /etc/timezone, never
  supported on openSUSE.
- Add journalctl-pager-improvement.patch: better handle output when
  using pager.
- Add fix-enable-disable-boot-initscript.patch: support boot.*
  initscripts for systemctl enable /disable (bnc#746506).
* Mon Jul 30 2012 fcrozat@suse.com
- Ensure systemd macros never fails (if systemd isn't install)
* Mon Jul 23 2012 fcrozat@suse.com
- Add fix-analyze-exception.patch: prevent exception if running
  systemd-analyze before boot is complete (bnc#772506)
* Fri Jul 20 2012 sbrabec@suse.cz
- Fix NumLock detection/set race condition (bnc#746595#c47).
* Wed Jul 18 2012 fcrozat@suse.com
- Move systemd-analyse to a subpackage, to remove any python
  dependencies from systemd main package (bnc#772039).
* Tue Jul 10 2012 fcrozat@suse.com
- Add fastboot-forcefsck.patch: ensure fastboot and forcefsck on
  kernel commandline are handled.
- Add fix-write-user-state-file.patch: write logind state file
  correctly.
- Disable logind-logout.patch: cause too many issues (bnc#769531).
* Mon Jul  9 2012 fcrozat@suse.com
- Add fix-tty-startup.patch: don't limit tty VT to 12 (bnc#770182).
* Tue Jul  3 2012 sbrabec@suse.cz
- Fix SUSE specific sysconfig numlock logic for 12.2 (bnc#746595).
* Tue Jul  3 2012 fcrozat@suse.com
- Add fix-dir-noatime-tmpfiles.patch: do not modify directory
  atime, which was preventing removing empty directories
  (bnc#751253, rh#810257).
- Add improve-restart-behaviour.patch: prevent deadlock during
  try-restart (bnc#743218).
- Add journal-bugfixes.patch: don't crash when rotating journal
  (bnc#768953) and prevent memleak at rotation time too.
- Add ulimit-support.patch: add support for system wide ulimit
  (bnc#744818).
- Add change-terminal.patch: use vt102 instead of vt100 as terminal
  for non-vc tty.
- Package various .wants directories, which were no longer packaged
  due to plymouth units being removed from systemd package.
- Fix buildrequires for manpages build.
* Mon Jul  2 2012 fcrozat@suse.com
- Do not ship plymouth units, they are shipped by plymouth package
  now (bnc#769397).
- Fix module loading (bnc#769462)
* Thu Jun  7 2012 fcrozat@suse.com
- Add fix-swap-priority: fix default swap priority (bnc#731601).
* Fri May 25 2012 fcrozat@suse.com
- Re-enable logind-logout.patch, fix in xdm-np PAM file is the real
  fix.
* Thu May 24 2012 fcrozat@suse.com
- Update new-lsb-headers.patch to handle entries written after
  description tag (bnc#727771, bnc#747931).
* Thu May  3 2012 fcrozat@suse.com
- Disable logind-logout.patch: it crashes sudo session (if called
  after su -l) (bnc#746704).
* Tue Apr 24 2012 fcrozat@suse.com
- Add fix-getty-isolate.patch: don't quit getty when changing
  runlevel (bnc#746594)
* Fri Apr 20 2012 sbrabec@suse.cz
- Implemented SUSE specific sysconfig numlock logic (bnc#746595).
* Thu Apr 19 2012 fcrozat@suse.com
- Add dbus-1 as BuildRequires to fix build.
* Tue Apr  3 2012 dvaleev@suse.com
- apply ppc patch to systemd-gtk too (fixes build)
* Thu Mar 22 2012 fcrozat@suse.com
- Update fixppc.patch with upstream patches
- Add comments from upstream in
  0001-util-never-follow-symlinks-in-rm_rf_children.patch.
- Add logind-logout.patch: it should fix sudo / su with pam_systemd
  (bnc#746704).
* Mon Mar 19 2012 fcrozat@suse.com
- Add 0001-add-sparse-support-to-detect-endianness-bug.patch: fix
  endianness error, preventing journal to work properly on ppc.
- Add fixppc.patch: fix build and warnings on ppc.
* Mon Mar 19 2012 fcrozat@suse.com
- Add 0001-util-never-follow-symlinks-in-rm_rf_children.patch: fix
  CVE-2012-1174 (bnc#752281).
* Fri Mar 16 2012 fcrozat@suse.com
- Update to version 43:
  + Support optional initialization of the machine ID from the KVM
    or container configured UUID.
  + Support immediate reboots with "systemctl reboot -ff"
  + Show /etc/os-release data in systemd-analyze output
  + Many bugfixes for the journal, including endianess fixes and
    ensuring that disk space enforcement works
  + non-UTF8 strings are refused if used in configuration and unit
    files.
  + Register Mimo USB Screens as suitable for automatic seat
    configuration
  + Reorder configuration file lookup order. /etc now always
    overrides /run.
  + manpages for journal utilities.
- Drop fix-c++-compat.patch, no-tmpfs-fsck.patch,
  systemd-journald-fix-endianess-bug.patch.
- Requires util-linux >= 2.21 (needed to fix fsck on tmpfs).
* Mon Mar 12 2012 fcrozat@suse.com
- Add fix-c++-compat.patch: fix C++ compatibility error in header.
* Wed Feb 29 2012 fcrozat@suse.com
- Add systemd-journald-fix-endianess-bug.patch: fix journald not
  starting on ppc architecture.
- Add correct_plymouth_paths_and_conflicts.patch: ensure plymouth
  is correctly called and conflicts with bootsplash.
* Tue Feb 21 2012 fcrozat@suse.com
- Remove rsyslog listen.conf, handled directly by rsyslog now
  (bnc#747871).
* Mon Feb 20 2012 fcrozat@suse.com
- Update to version 43:
  + requires /etc/os-release, support for /etc/SuSE-release is no
    longer present.
  + Track class of PAM logins to distinguish greeters from normal
    user logins.
  + Various bug fixes.
* Sun Feb 19 2012 jengelh@medozas.de
- Use pkgconfig symbols for BuildRequires and specify version
* Fri Feb 17 2012 tittiatcoke@gmail.com
- Enable Plymouth integration.
  * Bootsplash related files will be moved to the bootsplash
    package
* Mon Feb 13 2012 fcrozat@suse.com
- Update to version 42:
  + Various bug fixes
  + Watchdog support for supervising services is now usable
  + Service start rate limiting is now configurable and can be
    turned off per service.
  + New CanReboot(), CanPowerOff() bus calls in systemd-logind
- Dropped fix-kmod-build.patch, fix-message-after-chkconfig.patch,
  is-enabled-non-existing-service.patch (merged upstream)
- Add libxslt1 / docbook-xsl-stylesheets as BuildRequires for
  manpage generation
* Thu Feb  9 2012 fcrozat@suse.com
- Update to version 41:
  + systemd binary is now installed in /lib/systemd (symlink for
  /bin/systemd is available now)
  + kernel modules are now loaded through libkmod
  + Watchdog support is now useful (not complete)
  + new kernel command line available to set system wide
    environment variable: systemd.setenv
  + journald capabilities set is now limited
  + SIGPIPE is ignored by default. This can be disabled with
    IgnoreSIGPIPE=no in unit files.
- Add fix-kmod-build.patch: fix build with libkmod
- Drop remote-fs-after-network.patch (merged upstream)
- Add dm-lvm-after-local-fs-pre-target.patch: ensure md / lvm
  /dmraid is started before mounting partitions, if fsck was
  disabled for them (bnc#733283).
- Update lsb-header patch to correctly disable heuristic if
  X-Systemd-RemainAfterExit is specified (whatever its value)
- Add fix-message-after-chkconfig.patch: don't complain if only
  sysv services are called in systemctl.
- Add is-enabled-non-existing-service.patch: fix error message when
  running is-enabled on non-existing service.
* Tue Feb  7 2012 fcrozat@suse.com
- Update to version 40:
  + reason why a service failed is now exposed in the"Result" D-Bus
    property.
  + Rudimentary service watchdog support (not complete)
  + Improve bootcharts, by immediatly changing argv[0] after
    forking to to reflect which process will be executed.
  + Various bug fixes.
- Add remote-fs-after-network.patch and update insserv patch:
  ensure remote-fs-pre.target is enabled and started before network
  mount points (bnc#744293).
- Ensure journald doesn't prevent syslogs to read from /proc/kmsg.
* Tue Jan 31 2012 fcrozat@suse.com
- Ensure systemd show service status when started behind bootsplash
  (bnc#736225).
- Disable core dump redirection to journal, not stable atm.
* Thu Jan 26 2012 fcrozat@suse.com
- Update modules_on_boot.patch to not cause failed state for
  systemd-modules-load.service (bnc#741481).
* Wed Jan 25 2012 fcrozat@suse.com
- Update to version 39:
  + New systemd-cgtop tool to show control groups by their resource
    usage.
  + Linking against libacl for ACLs is optional again.
  + If a group "adm" exists, journal files are automatically owned
    by them, thus allow members of this group full access to the
    system journal as well as all user journals.
  + The journal now stores the SELinux context of the logging
    client for all entries.
  + Add C++ inclusion guards to all public headers.
  + New output mode "cat" in the journal to print only text
    messages, without any meta data like date or time.
  + Include tiny X server wrapper as a temporary stop-gap to teach
    XOrg udev display enumeration (until XOrg supports udev
    hotplugging for display devices).
  + Add new systemd-cat tool for executing arbitrary programs with
    STDERR/STDOUT connected to the journal. Can also act as BSD
    logger replacement, and does so by default.
  + Optionally store all locally generated coredumps in the journal
    along with meta data.
  + systemd-tmpfiles learnt four new commands: n, L, c, b, for
    writing short strings to files (for usage for /sys), and for
    creating symlinks, character and block device nodes.
  + New unit file option ControlGroupPersistent= to make cgroups
    persistent.
  + Support multiple local RTCs in a sane way.
  + No longer monopolize IO when replaying readahead data on
    rotating disks.
  + Don't show kernel threads in systemd-cgls anymore, unless
    requested with new -k switch.
- Drop systemd-syslog_away_early_on_shutdown.patch: fixed upstream.
- Add fdupes to BuildRequires and use it at build time.
* Thu Jan 19 2012 tittiatcoke@gmail.com
- Make the systemd journal persistent by creating the
  /var/log/journal directory
* Wed Jan 18 2012 tittiatcoke@gmail.com
- Update to version 38 :
  - Bugfixes
  - Implementation of a Journal Utility Library
  - Implementation of a 128 Bit ID Utility Library
- 11 Patches integrated upstream
- Add systemd-syslog_away_early_on_shutdown.patch: make sure
  syslog socket goes away early during shutdown.
- Add listen.conf for rsyslog. This will ensure that it will still
  work fine with rsyslog and the new journal.
* Mon Jan  9 2012 fcrozat@suse.com
- Add fix-is-enabled.patch: ensure systemctl is-enabled work
  properly when systemd isn't running.
- Add logind-console.patch: do not bail logind if /dev/tty0 doesn't
  exist (bnc#733022, bnc#735047).
- Add sysctl-modules.patch: ensure sysctl is started after modules
  are loaded (bnc#725412).
- Fix warning in insserv patch.
- Update avoid-random-seed-cycle.patch with better upstream
  approach.
- Update storage-after-cryptsetup.patch to restart lvm before
  local-fs.target, not after it (bnc#740106).
- Increase pam-config dependency (bnc#713319).
* Wed Dec  7 2011 fcrozat@suse.com
- Remove storage-after-cryptsetup.service, add
  storage-after-cryptsetup.patch instead to prevent dependency
  cycle (bnc#722539).
- Add delay-fsck-cryptsetup-after-md-lvm-dmraid.patch: ensure
  fsck/cryptsetup is run after lvm/md/dmraid have landed
  (bnc#724912).
- Add cron-tty-pam.patch: Fix cron filling logs (bnc#731358).
- Add do_not_warn_pidfile.patch: Fix PID warning in logs
  (bnc#732912).
- Add mount-swap-log.patch: Ensure swap and mount output is
  redirected to default log target (rhb#750032).
- Add color-on-boot.patch: ensure colored status are displayed at
  boot time.
- Update modules_on_boot.patch to fix bnc#732041.
- Replace private_tmp_crash.patch with log_on_close.patch, better
  upstream fix for bnc#699829 and fix bnc#731719.
- Update vconsole patch to fix memleaks and crash (bnc#734527).
- Add handle-racy-daemon.patch: fix warnings with sendmail
  (bnc#732912).
- Add new-lsb-headers.patch: support PIDFile: and
  X-Systemd-RemainAfterExit: header in initscript (bnc#727771).
- Update bootsplash services to not start if vga= is missing from
  cmdline (bnc#727771)
- Add lock-opensuse.patch: disable /var/lock/{subsys,lockdev} and
  change default permissions on /var/lock (bnc#733523).
- Add garbage_collect_units: ensure error units are correctly
  garbage collected (rhb#680122).
- Add crypt-loop-file.patch: add support for crypt file loop
  (bnc#730496).
* Sat Nov 19 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Fri Nov  4 2011 fcrozat@suse.com
- Fix rpm macros to only call presets on initial install
  (bnc#728104).
* Thu Oct 27 2011 fcrozat@suse.com
- Add no-tmpfs-fsck.patch: don't try to fsck tmpfs mountpoint
  (bnc#726791).
* Wed Oct 19 2011 fcrozat@suse.com
- Add avoid-random-seed-cycle.patch: fix dependency cycle between
  cryptsetup and random-seed-load (bnc#721666).
- Add crash-isolating.patch: fix crash when isolating a service.
- Fix bootsplash being killed too early.
- Fix some manpages not being redirected properly.
- Add storage-after-cryptsetup.service to restart lvm after
  cryptsetup. Fixes lvm on top of LUKS (bnc#724238).
* Fri Oct 14 2011 fcrozat@suse.com
- Recommends dbus-1-python, do not requires python (bnc#716939)
- Add private_tmp_crash.patch: prevent crash in debug mode
  (bnc#699829).
- Add systemctl-completion-fix.patch: fix incorrect bash completion
  with some commands (git).
* Wed Oct 12 2011 fcrozat@suse.com
- Shadow single sysv service, it was breaking runlevel 1.
- Add modules_on_boot.patch to handle /etc/sysconfig/kernel
  MODULES_ON_BOOT variable (bnc#721662).
* Wed Oct 12 2011 fcrozat@suse.com
- Update to release 37:
  - many bugfixes
  - ConditionCapability added, useful for containers.
  - locale mechanism got extend to kbd configuration for
    both X and the console
  - don't try to guess PID for SysV services anymore (bnc#723194)
- Drop detect-non-running.patch, logind-warning.patch.
- Rewrite systemd-sysv-convert in bash (bnc#716939)
* Tue Oct 11 2011 coolo@suse.com
- make sure updaters get in the /sbin/init from here - the sub package
  of the split package will decide which init wins in update case
* Tue Oct 11 2011 coolo@suse.com
- under openSUSE if it's not systemd, chances are good it's
  sysvinit
* Tue Oct 11 2011 coolo@suse.com
- do not list specific sbin_init providers
* Wed Oct  5 2011 fcrozat@suse.com
- Add logind-warning.patch: fix pam warning (bnc#716384)
* Fri Sep 30 2011 fcrozat@suse.com
- Update to version 36 :
  - many bugfixes
  - systemd now requires socket-activated syslog implementations
  - After=syslog.target is no longer needed in .service files
  - X-Interactive is ignored in LSB headers (was not working)
- Enable back insserv.conf parsing in systemd core and fix added
  dependencies (bnc#721428).
- Fix detection of LSB services status when running daemon
  (bnc#721426).
- Drop 0001-execute-fix-bus-serialization-for-commands.patch,
  fix-reload.patch
* Thu Sep 29 2011 fcrozat@suse.com
- Add services to stop bootsplash at end of startup and start it at
  beginning of shutdown.
- Fix bootsplash call and ensure dependencies are set right.
* Thu Sep 29 2011 fcrozat@suse.com
- Add detect-non-running.patch: fix assertion when running
  systemctl under non systemd system (git).
- Requires presets branding package.
- Improve macros a little bit.
* Mon Sep 26 2011 fcrozat@suse.com
- Merge migration rpm macros into service_add/service_del macros.
- Use systemd presets in rpm macros
- Add fix-reload.patch: handle daemon-reload and start condition
  properly (bnc#719221).
* Fri Sep 23 2011 fcrozat@suse.com
- Add systemd-splash / bootsplash-startup.service: enable
  bootsplash at startup.
* Fri Sep 16 2011 fcrozat@suse.com
- Create -32bit package (bnc#713319)
* Mon Sep 12 2011 fcrozat@suse.com
- Do not mask localnet service, it is not yet handled by systemd.
  (bnc#716746)
* Fri Sep  9 2011 fcrozat@suse.com
- Add revert_insserv_conf_parsing.patch and systemd-insserv_conf:
  remove insserv.conf parsing from systemd and use generator
  instead.
- put back default.target creation at package install and remove
  inittab generator, Yast2 is now able to create it.
* Thu Sep  1 2011 fcrozat@novell.com
- Update to version 34:
  * Bugfixes
  * optionaly apply cgroup attributes to cgroups systemd creates
  * honour sticky bit when trimming cgroup trees
  * improve readahead
- Add libacl-devel as BuildRequires (needed for systemd-uaccess)
- Add some %%{nil} to systemd.macros to fix some build issues.
- Fix dbus assertion
- move gtk part to its own package, to reduce bootstrapping
  (bnc#713981).
* Fri Aug 26 2011 fcrozat@suse.com
- Update compose_table patch to use two separate loadkeys call,
  compose table overflows otherwise (spotted by Werner Fink).
* Wed Aug 24 2011 fcrozat@novell.com
- Add tty1.patch: ensure passphrase are handled before starting
  gettty on tty1.
- Add inittab generator, creating default.target at startup based
  on /etc/inittab value.
- No longer try to create /etc/systemd/system/default.target at
  initial package install (bnc#707418)
- Fix configuration path used for systemd user manager.
- Ensure pam-config output is no display in install script.
- Remove buildrequires on vala, no longer needed.
* Fri Aug 19 2011 fcrozat@suse.com
- Handle disable_capslock, compose table and kbd_rate
- Add rpm macros.systemd file.
- Do not disable klogd, it has its own service now.
- Handle kexec correctly (bnc#671673).
- Disable preload services, they are conflicting with systemd.
* Fri Aug 19 2011 fcrozat@suse.com
- enable pam_systemd module, using pam-config.
* Thu Aug 18 2011 aj@suse.de
- Fix crash with systemctl enable.
* Tue Aug 16 2011 fcrozat@suse.com
- Fix localfs.service to no cause cycle and starts it after
  local-fs.target.
* Thu Aug  4 2011 fcrozat@suse.com
- Remove root-fsck.patch, mkinitrd will use the same path as
  dracut.
- Add systemd-cryptsetup.patch: don't complain on "none" option in
  crypttab.
- Add systemd-cryptsetup-query.patch: block boot until passphrase
  is typed.
* Wed Aug  3 2011 fcrozat@suse.com
- Add root-fsck.patch: do not run fsck on / if it is rw
- Ship a non null localfs.service, fixes static mount points not
  being mounted properly.
* Wed Aug  3 2011 aj@suse.de
- Update to version 33:
  * optimizations and bugfixes.
  * New PrivateNetwork= service setting which allows you to shut off
    networking for a specific service (i.e. all routable network
    interfaces will disappear for that service).
  * Merged insserv-parsing.patch and bash-completion-restart.patch
    patches.
* Tue Aug  2 2011 fcrozat@suse.com
- Add insserv-parsing.patch: read/parse insserv.conf.
- Add bash-completion-restart.patch: fix restart service list
  (bnc#704782).
* Mon Aug  1 2011 aj@suse.de
- Split up devel package.
- restart logind after upgrade.
- Adjust rpmlintrc for changes.
* Fri Jul 29 2011 aj@suse.de
- Update to version 32:
  * bugfixes
  * improve selinux setup
* Thu Jul 28 2011 aj@suse.de
- Update to version 31:
  * rewrite of enable/disable code: New features systemctl --runtime,
    systemctl mask, systemctl link and presets.
  * sd-daemon is now shared library.
* Tue Jul 19 2011 aj@suse.de
- Update to version 30:
  + Logic from pam_systemd has been moved to new systemd-login.
  + VT gettys are autospawn only when needed
  + Handle boot.local/halt.local on SUSE distribution
  + add support for systemctl --root
* Wed Jun 29 2011 fcrozat@suse.com
- Make sure to not start kbd initscript, it is handled by systemd
  natively.
* Fri Jun 17 2011 fcrozat@novell.com
- version 29:
  + enable chkconfig support in systemctl for openSUSE.
  + systemctl: plug a leak upon create_symlink mismatch
  + mount /run without MS_NOEXEC
  + dbus: fix name of capability property
  + systemctl: fix double unref of a dbus message
  + cryptsetup-generator: fix /etc/cryptsetup options
  + selinux: selinuxfs can be mounted on /sys/fs/selinux
  + readahead-common: fix total memory size detection
  + systemctl: fix 'is-enabled' for native units under /lib
  + systemctl: fix a FILE* leak
  + pam-module: add debug= parameter
  + remote-fs.target: do not order after network.target
- update tarball url.
* Wed Jun 15 2011 saschpe@suse.de
- Use RPM macros instead of $RPM_FOO variables
- Don't require %%{version}-%%{release} of the base package,
  %%{version} is sufficient
* Tue Jun 14 2011 kay.sievers@novell.com
- new snapshot
  - mount /run without MS_NOEXEC
  - readahead-common: fix total memory size detection
  - enable chkconfig support in systemctl for openSUSE
  - selinux: selinuxfs can be mounted on /sys/fs/selinux
  - cryptsetup-generator: fix /etc/cryptsetup options
  - systemctl: fix double unref of a dbus message
- drop merged chkconfig patch
* Tue Jun 14 2011 fcrozat@novell.com
- Add sysv chkconfig patch to be able to enable / disable sysv
  initscripts with systemctl.
- Ensure plymouth support is buildable conditionnally.
* Thu May 26 2011 kay.sievers@novell.com
- version 28
  - drop hwclock-save.service
  - fix segfault when a DBus message has no interface
  - man: update the list of unit search locations
  - readahead-collect: ignore EACCES for fanotify
  - rtc in localtime: use settimeofday(NULL, tz)
    instead of hwclock(8)
* Sat May 21 2011 kay.sievers@novell.com
- new snapshot
  - fix crash in D-Bus code
* Sat May 21 2011 kay.sievers@novell.com
- new snapshot
  - socket: always use SO_{RCV,SND}BUFFORCE to allow larger values
  - util: use new VT ESC sequence to clear scrollback buffer
  - sd-daemon: move _sd_hidden_ from .h to .c file
  - missing: add IP_TRANSPARENT
* Sat May 21 2011 kay.sievers@novell.com
- version 27
  - util: use open_terminal() in chvt() too
  - socket: expose SO_BROADCAST
  - git: add .mailmap
  - exec: expose tty reset options in dbus introspection data
  - socket: expose IP_TRANSPARENT
  - exec: hangup/reset/deallocate VTs in gettys
  - socket: use 666 socket mode by default since neither fifos,
    nor sockets, nor mqueues need to be executable
  - socket: add POSIX mqueue support
  - README: document relation to nss-myhostname
  - hostnamed: check that nss-myhostname is installed
* Tue May 17 2011 kay.sievers@novell.com
- new snapshot
  - sysctl: apply /etc/sysctl.conf last
  - systemd-analyze: print hostname, kernelversion and arch at
    the top of the plot
  - pam: downgrade a few log msgs
  - hostnamed: SetPrettyHostname() should check PK action
    org.freedesktop.hostname1.set-static-hostname
  - user-sessions: ignore EROFS when unlinking /etc/nologin if
    the file doesn't exist anyway
  - unit: make ignoring in snapshots a per unit property,
    instead of a per unit type property
  - vconsole: use open_terminal() instead of open()
  - units: enable automount units only if the kernel supports them
* Thu May  5 2011 coolo@opensuse.org
- remove policy filter
* Thu May  5 2011 meissner@suse.de
- add missing buildrequires dbus-1-devel, vala, libxslt-devel
- touch vala files for rebuilding to unbreak Factory
* Mon May  2 2011 kay.sievers@novell.com
- also delete plymouth files
* Mon May  2 2011 kay.sievers@novell.com
- disable plymouth sub-package until plymouth gets into Factory
* Sun May  1 2011 kay.sievers@novell.com
- new snapshot
  - binfmt, modules-load, sysctl, tmpfiles: add missing
    ConditionDirectoryNotEmpty=
  - binfmt, modules-load, sysctl, tmpfiles: read /usr/local/lib
    and where appropriate /lib directories
* Sat Apr 30 2011 kay.sievers@novell.com
- version 26
  - plymouth: introduce plymouth.enable=0 kernel command line
  - util: don't AND cx with cx
  - man: typo in sd_daemon reference
  - util: conf_files_list() return list as parameter
  - dbus: make daemon reexecution synchronous
* Thu Apr 28 2011 kay.sievers@novell.com
- new snapshot
  - service: properly notice when services with a main process
    that isn't a child of init die
  - unit: fix assert when trying to load unit instances for
    uninstanciable types
  - def: lower default timeout to 90s
  - manager: fix serialization counter
* Wed Apr 27 2011 kay.sievers@novell.com
- new snapshot
  - dbus: don't hit assert when dumping properties
  - cryptsetup: fix keyfile size option processing
  - socket: improve warning message when we get POLLHUP
  - mount: failure to mount cgroup hierarchies should not be fatal
  - configure: add AC_SYS_LARGEFILE
* Mon Apr 25 2011 kay.sievers@novell.com
- new snapshot
  - tmpfiles.d: switch to stacked config dirs in /lib, /etc, /run
  - sysctl.d, binfmt.d, modules-load.d: switch to stacked config
    dirs in /lib, /etc, /run
  - manager: mkdir /run/systemd/system when starting up
  - man: Spelling fixes
* Thu Apr 21 2011 kay.sievers@novell.com
- version 25
  - mount: Allow creating mount units for /var/lib/nfs/rpc_pipefs
    and /proc/fs/nfsd.
  - socket: support ListeSpecial= sockets
  - vconsole: don't set console font/keymap if settings are empty
  - nspawn: don't fail when we receive SIGCHLD
  - cgroup: don't accidentaly trim on reload
  - units: set capability bounding set for syslog services
  - socket: log more information about invalid poll events
  - man: fix specification of default timeouts
  - mount,crypto: rework meaning of noauto/nofail
  - fsck: don't fsck against basic.target in order to properly
    allow automount /home
  - manager: when running in test mode, do not write generated
    unit files to /run/systemd/generator
  - mount: properly parse timeouts options in the middle of
    the string
  - hostnamed: drop all caps but CAP_SYS_ADMIN
  - execute: when we run as PID 1 the kernel doesn't give us
    CAP_SETPCAP by default. Get that temporarily when dropping
    capabilities for good
  - mount: make device timeout configurable
  - cryptsetup: do not order crypto DM devices against the
    cryptsetup service
  - socket: reuse existing FIFOs
  - socket: guarantee order in which sockets are passed to be
    the one of the configuration file
  - systemctl: always consider unit files with no
    [Install] section but stored in /lib enabled
  - job: also print status messages when we successfully started
    a unit
  - hostnamed: add reference to SMBIOS specs
  - man: runlevel 5 is usually more comprehensive, so use it
    instead of 3 to detect whether a sysv service is enabled
  - polkit: follow the usual syntax for polkit actions
  - hostnamed: introduce systemd-hostnamed
  - units: order quotacheck after remount-rootfs
  - hostname: split out hostname validation into util.c
  - dbus: split out object management code into dbus-common,
    and simplify it
  - strv: properly override settings in env_append()
  - strv: detect non-assignments in env blocks properly in
    env_append()
  - strv: handle empty lists in strv_copy() properly
  - util: truncate newline inside of read_one_line_file()
  - util: modernize get_parent_of_pid() a bit
  - crypto: let the cryptsetup binary handles its own
    configurable timeouts
  - logger,initctl: use global exit timeout
  - ask-password: use default timeout
  - manager: drop all pending jobs when isolating
  - manager: introduce IgnoreOnIsolate flag so that we can keep
    systemd-logger around when isolating
  - units: never pull in sysinit from utmp, so that we can
    shutdown from emergency mode without pulling in sysinit
  - manager: downgrade a few log messages
  - units: require syslog.socket from the logger because we
    simply fail if we don't have it
  - logger: adjust socket description to match service
  - units: set stdout of kmsg syslogd to /dev/null
  - units: add --no-block when starting normal service after
    shell exited
  - ask-password: use kill(PID, 0) before querying a password
  - ask-password: support passwords without timeouts
  - ask-password: always send final NUL char
  - ask-password: properly accept empty passwords from agent
  - unit: skip default cgroup setup if we have no hierarchy
  - units: isolate emergency.target instead of emergency.service
    when we fail to mount all file systems
  - mount: don't pull in stdio logger for root mount unit
  - cgroup: be nice to Ingo Molnar
  - pam: use /proc/self/sessionid only with CAP_AUDIT_CONTROL
  - pam: use /proc/self/loginuid only with CAP_AUDIT_CONTROL
  - socket: try creating a socket under our own identity if we
    have no perms to consult the selinux database
  - socket: fix check for SEQPACKET
  - execute: don't fail if we cannot fix OOM in a container
  - unit: fix dump output
  - socket: be a bit more verbose when refusing to start a
    socket unit
  - socket: support netlink sockets
  - local-fs: invoke emergency.service mounting at boot fails
  - path: optionally, create watched directories in .path units
  - tmpfiles: don't warn if two identical lines are configured
  - man: add man page for ask-password
  - dbus: expose monotonic timestamps on the bus
  - manager: no need to use randomized generator dir when running
    as system manager
  - don't make up buffer sizes, use standard LINE_MAX instead
  - unit: disallow configuration of more than one on_failure
    dependencies if OnFailureIsolate= is on
  - unit: pull in logger unit only when running in system mode
  - manager: serialize/deserialize max job id and /usr taint flag
  - manager: don't garbage collect jobs when isolating, to change
    global state
  - unit: introduce OnFailureIsolate=
  - mount: relabel both before and after a mount, just in case
  - cmdline: we actually want to parse the kernel cmdline in VMs,
    just not in containers
  - units: rename rtc-set.target to time-sync.target and pull it
    in by hwclock-load.service
  - job: fix deserialization of jobs: do not ignore ordering
  - systemctl: properly parse JobNew signals
  - service: fix units with more than one socket
  - systemctl: make most operations NOPs in a chroot
  - manager: don't show PID for incoming signals if it is 0
  - man: fix description of systemctl reload-or-try-restart
  - mount: block creation of mount units for API file systems
  - units: call the logger a bridge too
  - build-sys: always place user units in /usr/lib/systemd
  - pkgconfig: update .pc file accordingly
  - lookup: always also look into /usr/lib for units
  - exec: support unlimited resources
  - selinux: relabel /run the same way as /dev after loading
    the policy since they both come pre-filled and unlabelled
  - manager: fd must be int, not char
  - change remaining /var/run to /run
  - units: move user units from /usr/share to /usr/lib since
    they might be arch-dependent
  - man: document /etc/sysctl.d/
  - binfmt: add binfmt tool to set up binfmt_misc at boot
  - tmpfiles: create leading directories for d/D instructions
  - condition: add ConditionSecurity
  - load-fragment: unify config_parse_condition_{kernel, virt}
  - condition: fix dumping of conditions
  - initctl: /dev/initctl is a named pipe, not a socket
  - kmsg-syslogd: pass facility value into kmsg
  - move /var/lock to HAVE_SYSV_COMPAT
  - tmpfiles: split off rules for legacy systems into legacy.conf
  - general: replace a few uses of /var/run by /run
  - tmpfiles: enforce new /var/lock semantics
  - man: document ConditionPathIsDirectory=
  - mount: also relabel pre-mounted API dirs
  - log: don't strip facility when writing to kmsg
  - build-sys: create a number of drop-in config dirs
  - random: do not print warning if random seed doesn't exist
  - plymouth: use PID file to detect whether ply is running
  - build-sys: install systemd-analyze by default
  - analyze: improve output
  - analyze: add plotter
  - unit: when deserializing do reconnect to dbus/syslog when
    they show up
  - analyze: beautify output a bit
  - add systemd-analyze tool
  - unit: don't override timestamps due to state changes when
    deserializing
  - plymouth: don't explicitly enable status message when
    plymouth is up
  - status: show status messages unconditionally if plymouth
    is around
  - taint: add missing cgroups taint flag
  - locale: don't access misinitialized variable
  - quota: do not pull in quota tools for mounts that do not
    originate in neither /etc/fstab nor fragment files
  - manager: fix taint check for /usr
  - unit: never apply /etc/rcN.d/ priority to native services
  - unit: fix parsing of condition-result
  - unit: don't complain about failed units when deserializing
  - exec: drop process group kill mode since it has little use
    and confuses the user
  - cgroup: explain when we cannot initialize the cgroup stuff
  - systemctl: don't truncate description when using pager
  - ask-password: also accept Backspace as first keypress as
    silent mode switch
  - unit: when deserializing jobs, don't pull in dependencies
  - locale: fix LC_MESSAGES variable name
  - plymouth: Remove the calls to plymouth message
  - udev: systemd-tag all ttys
  - tmpfiles fix /run/lock permissions
  - ask-password: use TAB to disable asterisk password echo
  - execute: socket isn't abstract anymore
  - use /run instead of /dev/.run
  - man: explain a couple of default dependencies
  - mount: pull in quota services from local mountpoints with
    usr/grpquota options
  - service: pull in sysv facility targets from the sysv units,
    not the other way round
  - units: pull in syslog.target from syslog.socket
  - units: don't ever pull in SysV targets from other SysV
    targets
  - units: document that some targets exists only for compat
    with SysV
  - man: document pidns containers
  - units: deemphesize Names= settings, and explain why nobody
    whould use them
  - units: on mandriva/fedora create single.service alias via
    symlink, not Names=
  - units: get rid of runlevel Names=, the symlinks in
    /lib/systemd/system are much more useful
  - rework syslog detection so that we need no compile-time
    option what the name of the syslog implementation is
  - man: document .requires/ directories
  - special: get rid of dbus.target
  - exec: properly apply capability bounding set, add inverted
    bounding sets
  - dbus: add service D-Bus property "Sockets"
  - dbus: consolidate service SysV conditionals
  - unit: serialize condition test results
  - def: centralize definition of default timeout in one place
  - chkconfig: check against runlevel 5 instead of 3, since it is
    a superset of the latter
  - systemctl: accept condstop as alias for stop
  - dbus: allow LoadUnit to unprivileged users
  - umount: make sure skip_ro is always correctly initialized
- create /run (link it to /var/run)
- refresh splash password patch
- conflict with old mkinitrd version (we need /run)
- conflict with old udev (we need /run)
* Wed Mar 16 2011 kay.sievers@novell.com
- new snapshot
  - man: fix systemctl try-restart description
  - Add Frugalware display-manager service
  - main: revert recognition of "b" argument
  - main: interpret all argv[] arguments unconditionally when
    run in a container
  - loopback: downgrade an error to warning
  - nspawn: bind mount /etc/localtime
  - nspawn: make tty code more robust against closed/reopened
    /dev/console
  - util: make touched files non-writable by default
  - nspawn: allocate a new pty instead of passing ours through
    to avoid terminal settings chaos
  - main: parse the whole arv[] as kernel command line
  - main: check if we have a valid PID before getting the name
  - ask-password: reset signal mask after we are done
  - cgroup: don't recheck all the time whether the systemd
    hierarchy is mounted, to make strace outputs nicer and save
    a few stat()s
  - man: document systemd-nspawn
  - cgls: don't strip user processes and kernel threads from
    default output
  - umount: don't try to remount bind mounts ro during shutdown
  - getty: move automatic serial getty logic into generator
  - container: skip a few things when we are run in a container
    such as accessing /proc/cmdline
  - cgls: by default start with group of PID 1
  - pam: determine user cgroup tree from cgroup of PID 1
  - nspawn: move container into its own name=systemd cgroup
  - manager: don't show kernel boot-up time for containers
  - manager: show who killed us
  - units: add console-shell.service which can be used insted of
    the gettys to get a shell on /dev/console
* Mon Mar 14 2011 kay.sievers@novell.com
- new snapshot
  - build-sys: move remaining tools from sbin/ to bin/ since they
    might eventually be useful for user execution
  - hostname: don't override the hostname with localhost if it
    is already set and /etc/hostname unset
  - audit: give up sending auditing messages when it failed due
    to EPERM
  - nspawn: don't require selinux on if it is compiled in
  - main: remove AF_UNIX sockets before binding
  - shutdown: print a nice message when terminating a container
  - nspawn: mount /selinux if needed
  - shutdown: just call exit() if we are in a container
  - umount: assume that a non-existing /dev/loop device means it
    is already detached
  - socket: use 777 as default mode for sockets
  - main: log to the console in a container
  - main: don't parse /proc/cmdline in containers
  - util: add detect_container()
  - nspawn: reset environment and load login shell
  - core: move abstract namespace sockets to /dev/.run
  - nspawn: add simple chroot(1) like tool to execute commands
    in a namespace container
  - util: return exit status in wait_for_terminate_and_warn()
  - util: properly identify pty devices by their major
* Sat Mar 12 2011 kay.sievers@novell.com
- new snapshot
  - polkit: autogenerate polkit policy with correct paths
  - systemctl: support remote and privileged systemctl access
    via SSH and pkexec
  - gnome-ask-password-agent: fix path to watch
* Fri Mar 11 2011 kay.sievers@novell.com
- fix broken sysctl.service linking
* Fri Mar 11 2011 kay.sievers@novell.com
- new snapshot
  - units: move the last flag files to /dev/.run
  - util: close all fds before freezing execution
  - dbus: timeout connection setup
  - main: properly handle -b boot option
  - pam: do not leak file descriptor if flock fails
- disable sysv services natively provided by systemd
* Thu Mar 10 2011 kay.sievers@novell.com
- new snapshot
  - main: refuse system to be started in a chroot
  - main: don't check if /usr really is a mount point, since it is
    fine if it is passed pre-mounted to us from the initrd
  - condition: take a timestamp and store last result of conditions
  - dev: use /dev/.run/systemd as runtime directory, instead of
    /dev/.systemd
  - machine-id: move machine-id-setup to /sbin
  - pkconfig: export full search path as .pc variable
  - selinux: bump up error level when in non-enforcing mode
  - dbus: fix dbus assert due to uninitialized error
  - dbus: properly generate UnknownInterface, UnknownProperty
    and PropertyReadOnly errors
  - mount: use /dev/.run as an early boot alias for /var/run
* Tue Mar  8 2011 kay.sievers@novell.com
- version 20
  - service: prefix description with LSB only if script has LSB header,
    use 'SysV:' otherwise
  - unit: don't accidently create ordering links to targets when
    default deps are off for either target and unit
  - mount: support less cumbersome x-systemd-xxx mount options
  - unit: distuingish mandatory from triggering conditions
  - dbus: return DBUS_ERROR_UNKNOWN_OBJECT when an object
    is unknown
  - systemctl: when forwarding is-enabled to chkconfig
    hardcode runlevel 3
  - job: introduce new job result code 'skipped' to use when pre
    conditions of job did not apply
  - job: convert job type as early as we can, to simplify things
  - Keep emacs configuration in one configuration file.
  - syslog: make sure the kmsg bridge is always pulled in and
    never terminated automatically
  - mount: make /media a tmpfs
* Mon Mar  7 2011 kay.sievers@novell.com
- new snapshot
  - add org.freedesktop.DBus.Properies.Set method
  - main: introduce /etc/machine-id
  - systemctl: fix exit code when directing is-enabled
    to chkconfig
  - dbus: add 'Tainted' property to Manager object
  - dbus: expose distribution name and features on manager
    object as properties
  - man: document changed EnvironmentFile= behaviour
  - main: add link to wiki page with longer explanation of the
    /usr madness
  - execute: load environment files at time of execution, not
    when we load the service configuration
  - path: after installing inotify watches, recheck file again
    to fix race
  - path: don't use IN_ATTRIB on parent dirs when watching a
    file, since those cannot be removed without emptying the dir
    first anyway and we need IN_ATTRIB only to detect the link
    count dropping to 0
  - kill: always send SIGCONT after SIGTERM
  - readahead: disable collector automatically on read-only media
  - sysctl: use scandir() instead of nftw() to guarantee
    systematic ordering
  - support DT_UNKNOWN where necessary for compat with reiserfs
  - systemctl: always null-terminate the password
- call systemd-machine-id-setup at installation
* Tue Mar  1 2011 kay.sievers@novell.com
- version 19
  - udev: don't ignore non-encrypted block devices with no
    superblock
  - udev: expose ttyUSB devices too
  - udev: mark hvc devices for exposure in systemd
  - cryptsetup: add a terse help
  - agent: don't print warnings if a password was removed or
    timed out
  - systemctl: shutdown agent explicitly so that it can reset
    the tty properly
  - never clean up a service that still has a process in it
  - label: udev might be making changes in /dev while we
    iterate through it
  - systemctl: properly handle job results
  - job: also trigger on-failure dependencies when jobs faile
    due to dependencies, timeout
  - job: when cancelling jobs, make sure to propagate this
    properly to depending jobs
  - job: start job timeout on enqueuing not when we start to
    process a job
  - unit: increase default timeout to 3min
  - logger: leave the logger longer around and allow it do
    handle more connections
  - dbus: pass along information why a job failed when it
    failed (dbus api change!)
  - general: unify error code we generate on timeout
  - units: synchronize gettys to plymouth even if plymouth is
    killed by gdm
  - job: start job timer when we begin running the job, not
    already when we add it to the queue of jobs
  - cryptsetup: try to show the mount point for a crypto disk
    if we can
  - rescue: terminate plymouth entirely when going into
    rescue mode
  - ask-password: fix handling of timeouts when waiting
    for password
  - ask-password: supported plymouth cached passwords
  - main: print warning if /usr is on a seperate partition
  - ensure we start not a single getty before plymouth is
    gone because we never know which ttys plymouth still controls
  - unit: introduce ConditionVirtualization=
* Mon Feb 21 2011 kay.sievers@novell.com
- new snapshot
  - dbus: don't rely that timer/path units have an initialized
    unit field (bnc#671561)
* Mon Feb 21 2011 kay.sievers@novell.com
- new snapshot
  - order network mounts after network.target (bnc#672855)
* Mon Feb 21 2011 kay.sievers@novell.com
- new snapshot
  - kmsg-syslogd: increase terminate timeout to 5min to generte
    less debug spew
  - shutdown(8) - call kexec if kexec kernel is loaded (bnc#671673)
  - unit: don't timeout fsck
  - man: fixed typo in SyslogIdentifier=
  - tmpfiles: never clean up block devices
  - main: refuse --test as root
* Fri Feb 18 2011 kay.sievers@novell.com
- new snapshot
  - units: order fsck@.service before basic.target
    instead of local-fs.target to relax things a little
  - readahead: remove misleading error messages
  - man: don't do more reloads than necessary in spec files
  - util: retry opening a TTY on EIO
  - util: beef up logic to find ctty name
  - tmpfiles: kill double slashes in unix socket names
- drop vhangup patch, it is fixed in login(3) by forwarding the
  SIGHUP to the child process
* Fri Feb 18 2011 coolo@novell.com
- revert back to conflicts: sysvinit
* Thu Feb 17 2011 werner@suse.de
- Add temporary workaround for bnc#652633, that is do a vhangup
  to all processes on a tty line used for a getty
* Wed Feb 16 2011 kay.sievers@novell.com
- version 18
  - systemctl: introduce --ignore-dependencies
  - systemctl: introduce --failed to show only failed services
  - systemctl: introduce --failed to show only failed services
  - rescue: make 'systemctl default' fail if there is already
    something running when the shell exited
  - util: seperate welcome line from other output by empty lines
  - manager: don't consider transaction jobs conflicting with
    queued jobs redundant
  - udev: ignore block devices which no known contents, to avoid
    trying of mounts/swapons when devices aren't set up full yet
  - swap: handle "nofail" from fstab
  - mount,swap: properly add dependencies to logger if needed
  - service: change default std output to inherit
  - exec: introduce global defaults for the standard output
    of services
  - udev: use SYSTEMD_READY to mask uninitialized DM devices
  - fsck: output to /dev/console by default in addition to syslog
  - execute: optionally forward program output to /dev/console in
    addition to syslog/kmsg
  - socket: refuse socket activation for SysV services
  - fsck: do not fail boot if fsck returns with an error code that
    hasn't 2 or 6 set
  - shutdown: execute all binaries in /lib/systemd/system-shutdown
    as last step before invoking reboot()
  - job: make status message printing more verbose
  - cryptsetup: fix unit file description
  - tmpfiles: never delete AF_UNIX sockets that are alive
  - getty: don't parse console= anymore, use
    /sys/class/tty/console/active instead
  - properly resolve /dev/console if more than once console=
    argument was passed on the kernel command line
  - getty: do not auto-spawn getty's on VC ttys if console=ttyN
  - fsck: skip root fsck if dracut already did it
  - util: when determining the right TERM for /dev/console
    consult /sys/class/tty/console/active
  - pam: introduce whitelist and blacklist user list feature
  - systemctl: minor optimizations
  - systemctl: don't unnecessarily close stdin/stdout/stderr for
    tty agent so that locking by tty works
  - readahead: disable readahead in virtual machines
  - tmpfiles: move binary to /bin to make it publicly available
  - tmpfiles: take names of tmpfiles configuration files on the
    command line
  - tmpfiles: log to stderr if possible
  - tmpfiles: support globs
  - units: introduce and hook up sound.target
  - dbus: allow all clients access to org.freedesktop.DBus.Peer
  - consider udev devices with SYSTEMD_READY=0 as unplugged
  - systemctl: don't start agent for --user
  - systemctl: make sure the tty agent does not retain a copy
    of stdio
* Tue Feb  8 2011 kay.sievers@novell.com
- new snapshot
  - plymouth: move plymouth out of TARGET_FEDORA
  - build-sys: fix AC_COMPILE_IFELSE tests
  - build-sys: ensure selinux configure check follows logic of
    other optional features
  - build-sys: autodetect and use pkg-config for libselinux
  - dbus: use ControlGroup as property name to match config option
  - pam: optionally reset cgroup memberships for login sessions
  - load-fragment: properly parse Nice= value
  - automount: use unit_pending_inactive() where appropriate
* Tue Feb  8 2011 jeffm@suse.de
- Removed unecessary workaround for plymouth startup.
* Fri Feb  4 2011 jeffm@suse.de
- Split plymouth support into systemd-plymouth package.
* Sat Jan 22 2011 kay.sievers@novell.com
- new snapshot
  - clang: fix some issues found with clang-analyzer
  - gcc: make gcc shut up
* Sat Jan 22 2011 kay.sievers@novell.com
- version 17
  - vala 0.10 seem to work fine
  - cryptsetup: fix ordering loop when dealing with encrypted
    swap devices
  - main: don't warn if /etc/mtab is a symlink to /proc/mounts
  - socket: don't crash if the .service unit for a .socket unit
    is not found
  - mount: ignore if an fsck is requested for a bind mount,
    so that we don't wait for the bind 'device' to show up
  - automount: fix segfault when shutting down
  - man: give an example for vconsole.conf
  - dbus: don't try to connect to the system bus before it is
    actually up
  - service: make chain of main commands and control commands
    independent of each other, so that both can be executed
    simultaneously and independently
  - service: don't allow reload operations for oneshot services
  - vala: convert from dbus-glib to gdbus
  - systemctl: highlight failed processes in systemctl status
  - systemctl: show process type along process exit codes
  - service: when reloading a service fails don't fail the entire
    service but just the reload job
* Wed Jan 19 2011 kay.sievers@novell.com
- new snapshot
  - shutdown: use correct kexec options
  - serial-getty: do not invoke /sbin/securetty; recent
    pam_securetty looks for console= in /proc/cmdline
  - systemctl: before spawning pager cache number of columns
  - pam: optionally keep processes of root user around
  - service: if a reload operation fails, don't shut down
    the service
  - execute: make sending of SIGKILL on shutdown optional
  - mount: do not translate uuids to lowercase
  - man: document missing KillSignal= and swap options
- require recent util-linux
- drop mtab symlink creation which is done in util-linux
* Sat Jan  8 2011 kay.sievers@novell.com
- version 16
  - device: don't warn if we cannot bump the udev socket buffer
  - logger: when passing on PID info, fall back to our own if
    originating process is already gone
  - service: don't hit an assert if information in LSB headers is
    incorrectly formatted
  - execute,util: fix two small memory leaks
  - getty: unset locale before execution
  - execute: drop empty assignments from env blocks on execution
    but keep them around otherwise to make them visible
  - umount: don't try to detach the dm device the root dir is on,
    to minimize warning messages
  - locale: fix variable names
  - fragment: allow prefixing of the EnvironmentFile=
    path with - to ignore errors
  - util: don't pass invalid fd to fdopendir() on error to avoid
    corruption of errno
  - tmpfiles: nicer message when two or more conflicting lines
    are configured for the same file
  - fragment: properly handle quotes in assignments in
    EnvironmentFile= files
  - sysctl: don't warn if sysctls are gone
  - readahead: ignore if files are removed during collection or
    before replay
  - serial: use TERM=vt100 instead of TERM=vt100-nav
  - cryptsetup: call mkswap on dm device, not on source device
  - mount-setup: mount /dev/pts with mode=620,gid=5 by default
    and make GID overridable via configure switch
  - systemctl: implement auto-pager a la git
  - shutdown: drop redundant sync() invocation
  - util: invoke sync() implicitly on freeze()
  - tmpfiles: do no follow symlinks when cleaning up dirs
* Tue Dec 28 2010 jeffm@suse.de
- Add support for building plymouth support with openSUSE
* Mon Dec 27 2010 kay.sievers@novell.com
- new snapshot
  - pam: do not sort user sessions into their own cgroups in
    the 'cpu' hierarchy
  - mount-setup: drop noexec flag from default mount options
    for /dev/shm
  - systemd.pc: change 'session' to 'user'
* Thu Dec 16 2010 kay.sievers@novell.com
- new snapshot
  - ifdef suse-only sysv script lookup code
* Thu Dec 16 2010 seife@opensuse.org
- add bootsplash handling patch to be able to enter e.g.
  crypto passphrases (bnc#659885)
* Thu Dec  9 2010 kay.sievers@novell.com
- new snapshot
  - add LSB 'smtp' alias for mail-transport-agent.target
* Wed Dec  8 2010 kay.sievers@novell.com
- new snapshot
  - path: fix watching the root directory
  - update README
* Fri Nov 26 2010 kay.sievers@novell.com
- new snapshot
  - gnome-ask-password-agent: also support libnotify < 0.7 for now
  - udev: increase event buffer size
- require fsck -l
* Thu Nov 25 2010 kay.sievers@novell.com
- version 15
  - dbus: use the right data slot allocator
  - manager: bump up max number of units to 128K
  - build-sys: allow cross-compilation
- revert too new libnotify code/requirement
- revert fsck -l option requirement
* Tue Nov 23 2010 kay.sievers@novell.com
- new snapshot
  - units: simplify shutdown scripts
  - logger: fix error handling
  - swap: order file-based swap devices after remount-rootfs
- revert too new libnotify code/requirement
- revert fsck -l option requirement
* Mon Nov 22 2010 kay.sievers@novell.com
- new snapshot
  - systemctl: don't return LSB status error codes for 'show'
  - mount: do not try to mount disabled cgroup controllers
  - man: document /etc/modules-load.d/, /etc/os-release,
    locale.conf, /etc/vconsole.conf, /etc/hostname
  - units: move a couple of units from base.target to
    sysinit.target
  - man: reorder things to follow the same order everywhere
- revert too new libnotify code/requirement
- revert fsck -l option requirement
* Sat Nov 20 2010 kay.sievers@novell.com
- version 13
  - cryptsetup: actually show disk name
  - cryptsetup: show udev device name when asking for password
  - sysctl: implement native tool and support /etc/sysctl.d
  - units: enable console ask-password agent by default
  - introduce /etc/os-release distro description
  - job: make sure we don't fail umount.target if a mount unit
    failed to stop
  - cgroup: after killing cgroup processes, ensure the group is
    really dead gone. wait for 3s at max
  - cgroup: if we couldn't remove a cgroup after killing
    evertyhing in it then it's fine
  - cryptsetup: automatically order crypt partitions before
    cryptsetup.target
  - man: trivial BindTo description fix
  - manager: make list of default controllers configurable
  - build: expose libcryptsetup dependency in build string
  - pam: document controllers= switch
  - cgroup: by default, duplicate service cgroup in the cpu hierarchy
  - pam: duplicate cgroup tree in the cpu hierarchy by default,
    optionally more
- enable native crypto handling instead of boot.crypto
- revert too new libnotify code/requirement
- revert fsck -l option requirement
* Wed Nov 17 2010 kay.sievers@novell.com
- version 12
  - ask-password: add --console mode to ask /dev/console
- revert too new libnotify code/requirement
* Tue Nov 16 2010 kay.sievers@novell.com
- new snapshot
  - cryptsetup: reword questions a little
  - units: order hwclock after readahead
  - path: don't mention too many inotify msgs
  - cryptsetup: include device name in password question
  - cryptsetup: lock ourselves into memory as long as we deal
    with passwords
  - plymouth: use updated socket name
  - units: set TERM for gettys again, since they acquire a TTY
  - units: allow start-up of plymouth ask-password agent very early
  - units: enable ask-paswword .path units early enough to be useful
    for early mounts
  - units: delay getty until logins are allowed
  - pam: always rely on loginuid instead of uid to determine cgroup
    and XDG_RUNTIME_DIR name
  - cgroup: call root cgroup system instead of systemd-1
  - exec: determine right TERM= setting based on tty name
  - pam: rename master user cgroup to 'master'
  - drop support for MANAGER_SESSION, introduce MANAGER_USER
  - units: use ConditionDirectoryNotEmpty= where applicable
  - unit: introduce ConditionDirectoryNotEmpty=
  - delete tmp.mount which may conflict with an unrelated fstab
    entry
- revert too new libnotify code/requirement
- disable native crypto handling
* Mon Nov 15 2010 kay.sievers@novell.com
- new snapshot
  - load-dropin: add support for .requires directories
  - manager: consider jobs already installed as redundant when
    reducing new transactions
  - manager: always pull 'following' units into transaction
  - util: always highlight distro name
  - units: make use of agetty mandatory
  - manager: don't fail transaction if adding CONFLICTED_BY job fails
  - job: make it possible to wait for devices to be unplugged
  - tmpfiles: ignore files marked with the sticky bit
  - cryptsetup: handle password=none properly
  - cryptsetup: properly parse cipher= switch
  - cryptsetup: support non-LUKS crypto partitions
  - ask-password: enable password agent
  - automatically start cryptsetup when looking for mount source
  - log: add automatic log target
  - cryptsetup: hook up tool with ask-password
  - manager: hookup generators
  - split mount_point_is_api() and mount_point_ignore()
- replace boot.crypto job with systemd native crypto handling
- enable readahead (requires 2.6.37+ kernel's fanotify to work)
* Thu Nov 11 2010 kay.sievers@novell.com
- new snapshot
  - tmpfiles: include reference to man page in tmpfiles files
  - vconsole: support additional keymap for toggling layouts
  - main: warn if /etc/mtab is not a symlink
  - add bash completion for systemctl --system
  - man: minor tmpfiles(5) updates and reindenting
  - main: rename process on startup to 'systemd' to avoid confusion
  - unit: add ConditionNull= condition
  - ac-power: make ac-power a proper binary that scripts can call
  - manager: parse RD_TIMESTAMP passed from initrd
  - modules-load: fix minor race
  - label: use internal utility functions wher epossible
  - cryptsetup: minimal cryptsetup unit generator
  - selinux: relabel /dev after loading policy
  - log: downgrade syslog connection failure message
  - service: delay automatic restart if job is pending
  - manager: when isolating undo all pending jobs, too
  - manager: only minimize impact if we are in fail mode
- replace /etc/mtab with link to /proc/self/mounts
* Thu Nov  4 2010 kay.sievers@novell.com
- new snapshot
  - man/tmpfiles.d.xml: add a manpage for tmpfiles
  - do not overwrite other udev tags
  - readahead: shortcut replay if /.readahead doesn't exist
* Fri Oct 29 2010 kay.sievers@novell.com
- new snapshot
  - fsck: return SUCCESS when we skip the check
  - fsck: skip checking / if it is writable
  - units: fix variable expansion
  - mount: don't pull in nofail mounts by default, but use them
    if they are around
  - job: recursively fail BoundBy dependencies
  - fsck: fix target name to check for
  - units: rename fedora/single.service to rescue.service
  - units: introduce plymouth-start and plymouth-kexec
  - unit: get rid of IgnoreDependencyFailure=
  - use util-linux:agetty instead of mingetty
  - unit: replace StopRetroactively= by BindTo= dependencies
  - automount: show who's triggering an automount
  - units: run sysctl only if /etc/sysctl.conf exists
  - systemctl: always show what and where for mount units
  - shutdown: reword a few messages a little
  - manager: show which jobs are actually installed after a transaction
  - timer: when deserializing timer state stay elapsed
  - device: set recursive_stop=true by default
  - unit: suppress incorrect deserialization errors
  - swap: there's no reason not order swap after sysinit
  - socket: fix IPv6 availability detection
* Wed Oct 27 2010 kay.sievers@novell.com
- new snapshot
  - create /dev/stderr and friends early on boot
  - run sysv related scripts with TERM=linux
  - add only swaps listed in /etc/fstab automatically to swap.target
  - errors: refer to systemctl status when useful
  - swap: add default cgroup to swap exec env
  - readahead: bump a device's request_nr when enabling readahead
  - shutdown: properly handle sigtimedwait() timing out
  - main: fix typo in kernel cmdline parameters help
  - ord-tty: properly handle SIGINT/SIGTERM
  - systemctl: automatically spawn temporary password agent
  - ask-password: properly handle multiple pending passwords
  - ask-password: enable plymouth agent by default
  - ask-password: add minimal plymouth password agent
* Tue Oct 26 2010 kay.sievers@novell.com
- new snapshot
  - make sure to pass TERM=linux to all sysv scripts
  - don't unset HOME/TERM when run in session mode
  - mount: add nosuid,nodev,noexec switches to /var/lock and /var/run
  - tmpfiles: Don't clean /var/lock/subsys
  - tmpfiles: Make wtmp match utmp perms, and add btmp
  - umount: Make sure / is remounted ro on shutdown
  - unset HOME and TERM set from the kernel
  - activate wall agent automatically
  - ask-password: add basic tty agent
* Sat Oct 23 2010 kay.sievers@novell.com
- new snapshot
  - rename ask-password-agent to gnome-ask-password-agent
  - fsck: suppress error message if we cannot change into single
    user mode since
  - dbus: epose FsckPassNo property for service objects
  - man: document systemctl --force
  - introduce 'systemctl kill'
* Sat Oct 23 2010 kay.sievers@novell.com
- new snapshot
  - syslog: enable kmsg bridge by default
  - fsck: add initial version of fsck and quotacheck wrappers
  - tmpfiles: remove forcefsck/fastboot flag files after boot
  - swap: listen for POLLPRI events on /proc/swaps if availabled
  - tmpfiles: integrate native tmpwatch
  - shutdown: loop only as long as we manage to unmount/detach devices
  - umount: disable dm devices by devnode, not by path name
  - introduce final.target
  - replace distro-specific shutdown scripts with native services
  - try to get rid of DM devices
  - log to console by default
  - introduce kexec.service, kexec.target and exit.target
  - hook in fsck@.service instance for all mount points with passno > 0
  - systemctl: warn if user enables unit with no installation instructions
  - dbus: add introspection to midlevel paths
  - look for dynamic throw-away units in /dev/.systemd/system
  - major rework, use /sbin/swapon for setting up swaps
  - introduce Restart=on-failure and Restart=on-abort
  - units: enable utmp for serial gettys too
  - rename 'banned' load state to 'masked'
  - optionally, create INIT_PROCESS/DEAD_PROCESS entries for a service
- use systemd-native fsck/mount
- use systemd-native tmpfiles.d/ instead of tmpwatch
* Fri Oct  8 2010 kay.sievers@novell.com
  new snapshot
  - fix 'systemctl enable getty@.service'
  - properly support 'banning' of services
  - handle nologin
  - add native reboot/shutdown implementation
* Thu Oct  7 2010 kay.sievers@novell.com
- version 11
* Wed Oct  6 2010 kay.sievers@novell.com
- new snapshot
  - readahead fixes
* Sun Oct  3 2010 aj@suse.de
- /etc/modules.d was renamed to modules-load.d
- only include tmpfiles.d/*conf files
* Wed Sep 29 2010 kay.sievers@novell.com
- don't create sysv order deps on merged units
- fix Provides: handling in LSB headers (network.target)
- native (optional) readahead
* Sun Sep 26 2010 aj@suse.de
- Do not package man pages twice.
* Wed Sep 22 2010 kay.sievers@novell.com
- new snapshot
  - basic services are enabled by default now
* Tue Sep 21 2010 kay.sievers@novell.com
- new snapshot
  - vconsole and locale setup
  - hook up tmpwatch
* Fri Sep 17 2010 kay.sievers@novell.com
- new snapshot
  - add new utility to initialize the virtual console
  - initialize locale from /etc/locale by default
  - ask-password: allow services query SSL/harddisk passphrases
* Fri Sep 17 2010 kay.sievers@novell.com
- version 10
  - logger: support SOCK_STREAM /dev/log sockets
  - make sure the file system is writable before we write utmp data
  - systemctl: use isolate when called as telinit for a runlevel
  - initctl: properly use isolate when activating runlevels
  - set HOME=/root when running shells
  - make sure we don't crash if there's an automount unit without
    mount unit
  - start logger only after syslog is up
* Fri Sep  3 2010 kay.sievers@novell.com
- version 9
  - units: don't add shutdown conflicts dep to umount.target
  - dbus: don't send cgroup agent messages directly to system bus
  - dbus: don't accept activation requests anymore if we are going
    down anyway
  - systemctl: fix return value of systemctl start and friends
  - service: wait for process exit only if we actually killed
    somebody
* Thu Aug 26 2010 kay.sievers@novell.com
- version 8
  - KERNEL 2.6.36+ REQUIRED!
  - mount cgroup file systems to /sys/fs/cgroup instead of /cgroup
  - invoke sulogin instead of /bin/sh
  - systemctl: show timestamps for state changes
  - add global configuration options for handling of auto mounts
* Fri Aug 20 2010 kay.sievers@novell.com
- apply /etc/fstab mount options to all api mounts
- properly handle LABEL="" in fstab
- do not consider LSB exit codes 5 and 6 as failure
* Tue Aug 17 2010 kay.sievers@novell.com
- prefix sysv job descriptions with LSB:
- add native sysctl + hwclock + random seed service files
- properly fallback to rescue.target if default.target is hosed
- rename ValidNoProcess= to RemainAfterExit=
- add systemd-modules-load tool to handle /etc/modules.d/
* Tue Aug 17 2010 kay.sievers@novell.com
- add support for delayed shutdown, similar to sysv in style
- rename Type=finish to Type=oneshot and allow multiple ExecStart=
- don't show ENOENT for non exitent configuration files
- log build time features on startup
- rearrange structs to make them smaller
- move runlevel[2-5] links to /lib
- create default.target link to /lib not /etc
- handle random-seed
- write utmp record before we kill all processes
- create /var/lock/subsys, /var/run/utmp
* Wed Aug 11 2010 kay.sievers@novell.com
- add audit messages for service changes
- update utmp with external program
- all to refuse manual service starting/stopping
* Tue Aug 10 2010 kay.sievers@novell.com
- version 7
  - hide output if quiet is passed on the kernel cmdline
  - fix auto restarting of units after a configuration reload
  - don't call bus_path_escape() with NULL unit name
* Fri Aug  6 2010 kay.sievers@novell.com
- version 6
  - man page update
* Fri Aug  6 2010 kay.sievers@novell.com
- new snapshot
  - downgrade a few log messages
  - properly handle devices which are referenced before they exist
* Thu Aug  5 2010 kay.sievers@novell.com
- new snapshot
  - fix dependency cycle of boot.* by splitting fsck.target
  - sort boot.* before other sysv services
    from sysinint.target
  - start getty for serial console
* Thu Aug  5 2010 kay.sievers@novell.com
- add licence to subpackages
* Wed Aug  4 2010 kay.sievers@novell.com
- version 5
  - selinux fixes
- fix hanging 'reboot' started from vc
* Mon Aug  2 2010 kay.sievers@novell.com
- enable getty.target by default
* Sat Jul 24 2010 kay.sievers@novell.com
- at install, read old inittab for the defaul target/runlevel
- disable services on package uninstall
* Sat Jul 24 2010 kay.sievers@novell.com
- version 4
  - merge systemd-install into systemctl
* Fri Jul 23 2010 kay.sievers@novell.com
- create config files in /etc in %%post
- mark files in /etc as config
- remove nodev from /dev/pts
- add selinux support
* Thu Jul 22 2010 kay.sievers@novell.com
- version 4 (pre)
  - require newer vala
  - add [Install] section to getty.target and remote-fs.target
- re-enable post-build check
* Wed Jul 21 2010 kay.sievers@novell.com
- do not add sysv services that are not enabled in /etc/rcN.d/
- allow symlinking unit files to /dev/null
- remove only pam sessions we ourselves created
- unit files in /etc/ always take precedence, even over link targets
* Tue Jul 20 2010 kay.sievers@novell.com
- fix access mode verification of FIFOs
* Sun Jul 18 2010 kay.sievers@novell.com
- fix default mode of /var/run and /var/lock
- force /var/run and /var/lock to be on tmpfs
* Wed Jul 14 2010 kay.sievers@novell.com
- always enable udev and dbus until we can require systemd from
  packages providing systemd service files
* Tue Jul 13 2010 kay.sievers@novell.com
- drop systemd-units.rpm
* Tue Jul 13 2010 kay.sievers@novell.com
- version 3
  - treat non-existing cgroups like empty ones, to deal with races
  - replace --running-as= by --session and --system
  - always allow stopping of units that failed to load
* Tue Jul 13 2010 kay.sievers@novell.com
- update
* Mon Jul 12 2010 kay.sievers@novell.com
- drop libcgroup
* Mon Jul 12 2010 kay.sievers@novell.com
- trim cgroups for services that are "active" but "exited"
- drop /bin/init hack and require now fixed mkinitrd
* Sun Jul 11 2010 kay.sievers@novell.com
- fix reboot issue
- fix abstract namespace name handling (needs udev update)
- prefer private D-Bus socket wherever possible
* Sat Jul 10 2010 kay.sievers@novell.com
- D-Bus 1.3.2 support
- use COLD_BOOT=1 on reboot to skip sysv boot.d/ handling
* Fri Jul  9 2010 kay.sievers@novell.com
- fix typo in spec file
* Fri Jul  9 2010 kay.sievers@novell.com
- provide /bin/init to be found by 'too simple' mkinitrd, and work
  around mindless relinking of relative links in the buildsystem
- add rpmlintrc to silent warnings about intentional behavior
* Fri Jul  9 2010 kay.sievers@novell.com
- version 2
* Thu Jul  8 2010 kay.sievers@novell.com
- fix 'reboot -w' to skip the actual reboot
- fix segfault in D-Bus code
- use unique instead of multiple keys in config file
- support continuation lines in config files
- support multiple commands in a single key in config files
- adapt log level of some messages
* Wed Jul  7 2010 kay.sievers@novell.com
- version 1
  - default log level to INFO
  - show welcome message
* Tue Jul  6 2010 kay.sievers@novell.com
- add systemd-install --start option
- add more documentation
* Mon Jul  5 2010 kay.sievers@novell.com
- new snapshot with extended D-Bus support
* Sun Jul  4 2010 kay.sievers@novell.com
- new snapshot with default unit dependency handling
* Sat Jul  3 2010 kay.sievers@novell.com
- new snapshot
* Fri Jul  2 2010 kay.sievers@novell.com
- add more documentation
* Thu Jul  1 2010 kay.sievers@novell.com
- new snapshot
* Thu Jun 24 2010 kay.sievers@novell.com
- split off systemd-units.rpm which can be pulled-in by other
  packages without further dependencies
* Thu Jun 24 2010 kay.sievers@novell.com
- add more documentation
* Tue Jun 22 2010 kay.sievers@novell.com
- more man pages and documentation
* Tue Jun 22 2010 kay.sievers@novell.com
- conflict with upstart
- include all installed doc files
* Tue Jun 22 2010 kay.sievers@novell.com
- provide pam module
* Mon Jun 21 2010 kay.sievers@novell.com
- use private D-Bus connection
- properly handle replacing a running upstart
* Fri Jun 18 2010 kay.sievers@novell.com
- implement wall message in halt/reboot/...
- speak /dev/initctl to old /sbin/init after installing
* Thu Jun 17 2010 kay.sievers@novell.com
- drop no longer needed -fno-strict-aliasing
- add README and examples
* Thu Jun 17 2010 kay.sievers@novell.com
- enable pam and libwrap
* Thu Jun 17 2010 kay.sievers@novell.com
- provide systemd-sysvinit.rpm with /sbin/init and friends
* Thu Jun 17 2010 kay.sievers@novell.com
- libwrap / pam support
* Wed Jun 16 2010 kay.sievers@novell.com
- initial packaging of experimental version 0
